@@ -9,6 +9,7 @@
 
 #include <qevent.h>
 #include <qstring.h>
+#include <qclipboard.h>
 #include "krfbconnection.h"
 #include "krfboptions.h"
 #include "krfbserverinfo.h"
@@ -52,6 +53,7 @@ static CARD8 SetEncodingsId = 2;
 static CARD8 UpdateRequestId = 3;
 static CARD8 KeyEventId = 4;
 static CARD8 PointerEventId = 5;
+static CARD8 ClientCutTextId = 6;
 
 //
 // Server -> Client Message Identifiers
@@ -613,9 +615,25 @@ void KRFBDecoder::sendMouseEvent( QMouseEvent *e )
 }
 
 
-void KRFBDecoder::sendCutEvent( const QString & )
+void KRFBDecoder::sendCutEvent( const QString &unicode )
 {
+  //
+  // Warning: There is a bug in the RFB protocol because there is no way to find
+  // out the codepage in use on the remote machine. This could be fixed by requiring
+  // the remote server to use utf8 etc. but for now we have to assume they're the
+  // same. I've reported this problem to the ORL guys, but they apparantly have no
+  // immediate plans to fix the issue. :-( (rich)
+  //
 
+  CARD8 padding[3];
+  QCString text = unicode.local8Bit();
+  CARD32 length = text.length();
+  length = Swap32IfLE( length );
+
+  con->write( &ClientCutTextId, 1 );
+  con->write( &padding, 3 );
+  con->write( &length, 4 );
+  con->write( text.data(), length );
 }
 
 void KRFBDecoder::gotServerCut()
@@ -651,6 +669,14 @@ void KRFBDecoder::gotServerCutText()
   disconnect( con, SIGNAL( gotEnoughData() ),
               this, SLOT( gotServerCutText() ) );
 
+  //
+  // Warning: There is a bug in the RFB protocol because there is no way to find
+  // out the codepage in use on the remote machine. This could be fixed by requiring
+  // the remote server to use utf8 etc. but for now we have to assume they're the
+  // same. I've reported this problem to the ORL guys, but they apparantly have no
+  // immediate plans to fix the issue. :-( (rich)
+  //
+
   char *cutbuf = new char[ serverCutTextLen + 1 ];
   CHECK_PTR( cutbuf );
 
@@ -659,6 +685,9 @@ void KRFBDecoder::gotServerCutText()
 
   qWarning( "Server cut: %s", cutbuf );
 
+  QString cutText( cutbuf ); // DANGER!!
+  qApp->clipboard()->setText( cutText );
+
   delete cutbuf;
 
   // Now wait for the update (again)
