@@ -21,6 +21,7 @@ void KRFBOptions::readSettings( KConfig *config )
   colors256 = config->readBoolEntry( "Colors256" );
   shared = config->readBoolEntry( "Shared" );
   readOnly = config->readBoolEntry( "ReadOnly" );
+  updateRate = config->readNumEntry( "UpdateRate", 200 );
 }
 
 void KRFBOptions::writeSettings( KConfig *config )
@@ -32,6 +33,7 @@ void KRFBOptions::writeSettings( KConfig *config )
   config->writeEntry( "Colors256", colors256 );
   config->writeEntry( "Shared", shared );
   config->writeEntry( "ReadOnly", readOnly );
+  config->writeEntry( "UpdateRate", updateRate );
   config->sync();
 }
 
