@@ -13,7 +13,7 @@ class QPushButton;
  * Top level window for Keystone.
  *
  * @author Richard Moore, rich@kde.org
- * @version $Id: kvnc.h,v 1.4 2000/09/03 00:43:12 waba Exp $
+ * @version $Id: kvnc.h,v 1.5 2000/12/04 23:10:08 rich Exp $
  */
 class KVNC : public KMainWindow
 {
@@ -25,6 +25,7 @@ public:
 public slots:
   void toggleFullScreen();
   void toggleShowStatus();
+  void toggleShowToolbar();
   void toggleShowMenu();
   void openURL( const KURL &url );
   void showOptions();
@@ -42,7 +43,9 @@ private:
   KRFBCanvas *canvas;
   KPopupMenu *cornerMenu;
   QPushButton *cornerButton;
+  KAction *fullScreenAction;
   KToggleAction *menubarAction;
+  KToggleAction *toolbarAction;
   KToggleAction *statusbarAction;
 };
 
