@@ -39,10 +39,7 @@ inline bool sanityCheck(TAim &aim)
 	else return true;
 }
 
-// ****************************
-// * class TWindow -- utility *
-// ****************************
-void updateTreeItem(QListViewItem *item, TBuddy &currentBuddy, int listColumns)
+void TWindow::updateTreeItem(QListViewItem *item, TBuddy &currentBuddy, int listColumns)
 {
 	QString bName, iTime, wLevel, sTime, uClass;
 
@@ -88,10 +85,11 @@ void updateTreeItem(QListViewItem *item, TBuddy &currentBuddy, int listColumns)
 	// we have the information, now stuff it into the item
 	item->setText(COL_NAME, bName);
 	int i = 1;
+	if(listColumns & (1 << COL_NICK)) item->setText(i++, profile->data()->nicknames[bName]);
 	if(listColumns & (1 << COL_IDLE)) item->setText(i++, iTime);
 	if(listColumns & (1 << COL_WARN)) item->setText(i++, wLevel);
 	if(listColumns & (1 << COL_SIGNON)) item->setText(i++, sTime);
-	if(listColumns & (1 << COL_CLASS)) item->setText(i, uClass);
+	if(listColumns & (1 << COL_CLASS)) item->setText(i++, uClass);
 }
 
 // ***************************
@@ -349,6 +347,7 @@ void TWindow::initTree(void)
 	
 	// add columns as necessary, and headers
 	treelist->addColumn("Screen Name", -1);
+	if(profile->data()->listColumns & (1 << COL_NICK)) treelist->addColumn(i18n("Nickname"), -1);
 	if(profile->data()->listColumns & (1 << COL_IDLE)) treelist->addColumn(i18n("Idle"), -1);
 	if(profile->data()->listColumns & (1 << COL_WARN)) treelist->addColumn(i18n("Warn"), -1);
 	if(profile->data()->listColumns & (1 << COL_SIGNON)) treelist->addColumn(i18n("Signon"), -1);
@@ -479,6 +478,22 @@ void TWindow::directoryTree(QListViewItem *listItem)
 	// send the request
 	aim.requestDirectory( listItem->text(COL_NAME) );
 }
+void TWindow::nickTree(QListViewItem *listItem)
+{
+	// if the item has no parent, then it's a group, and I don't care if it is selected
+	if(!listItem || !listItem->parent()) return;
+
+	QString name = listItem->text(COL_NAME);
+
+	QString msg(i18n("Enter a nickname for %1"));
+	msg = msg.arg(name);
+	
+	KLineEditDlg nameDialog(msg, profile->data()->nicknames[name], this);
+	if(nameDialog.exec() != KLineEditDlg::Accepted) return;
+
+	profile->data()->nicknames[name] = nameDialog.text();
+	initTree();
+}
 void TWindow::clickedTree(QListViewItem *item, const QPoint &point, int)
 {
 	if(aim.getStatus() == TAIM_OFFLINE) return;
@@ -500,6 +515,9 @@ void TWindow::clickedTreeMenu(int item)
 {
 	switch(item)
 	{
+	case ID_TNICK:
+		nickTree(treeCurrent);
+		break;
 	case ID_TDIRECTORY:
 		directoryTree(treeCurrent);
 		break;
@@ -536,7 +554,7 @@ void TWindow::setStatus(int status)
 	case TAIM_ONLINE:
 		dockWindow->setPixmap( SmallIcon("kit_online") );
 		statusButton->setCurrentItem(0);
-		KNotifyClient::event(i18n("Go Online"), i18n("You are online."));
+		KNotifyClient::event("Online");
 		break;
 	case TAIM_AWAY:
 		dockWindow->setPixmap( SmallIcon("kit_away") );
@@ -546,7 +564,7 @@ void TWindow::setStatus(int status)
 		dockWindow->setPixmap( SmallIcon("kit_offline") );
 		statusButton->setCurrentItem(2);
 		initTree();
-		KNotifyClient::event(i18n("Go Offline"), i18n("You are offline."));
+		KNotifyClient::event("Offline");
 		break;
 	};
 }
@@ -625,7 +643,7 @@ void TWindow::displayWarning(int percent, QString victim)
 	
 	QString message2;
 	message2 = i18n("\nYour new warning level is %1%.").arg(percent);
-	KNotifyClient::event(i18n("Warning Received"), message + message2);
+	KNotifyClient::event("Warning Received", message + message2);
 }
 void TWindow::profileUpdated(void)
 {
@@ -652,6 +670,7 @@ void TWindow::profileUpdated(void)
 	emit globalTimestamping(profile->data()->timestamping);
 	emit globalMyName(profile->data()->name);
 	emit globalColors(profile->data()->foregroundColor, profile->data()->backgroundColor, profile->data()->bold);
+	emit globalICQ(profile->data()->icqMode);
 
 	dockMenu->removeItemAt(0);
 	dockMenu->insertTitle(profile->data()->name, -1, 0);
@@ -685,15 +704,17 @@ void TWindow::initMenu(void)
 	help->insertSeparator();
 	help->insertItem( i18n("&Report Bug..."), ID_TBUG );
 	help->insertSeparator();
-	help->insertItem( SmallIconSet("kit"), i18n("&About..."), ID_TABOUT );
+	help->insertItem( SmallIconSet("kit"), i18n("&About Kit..."), ID_TABOUT );
 	help->insertItem( i18n("About &KDE..."), ID_TABOUTKDE );
 	connect( help, SIGNAL(activated(int)), SLOT(commandCallback(int)) );
 	
 	treeMenu = new KPopupMenu(this);
 	treeMenu->insertTitle(("Howdy Doody"));
-	treeMenu->insertItem( SmallIconSet("send"), i18n("Open chat..."), ID_TMESSAGE );
-	treeMenu->insertItem( SmallIconSet("kit_status"), i18n("Information"), ID_TINFO );
-	treeMenu->insertItem( i18n("Directory"), ID_TDIRECTORY);
+	treeMenu->insertItem( i18n("Set nickname..."), ID_TNICK );
+	treeMenu->insertSeparator();
+	treeMenu->insertItem( SmallIconSet("mail_send"), i18n("Open chat..."), ID_TMESSAGE );
+	treeMenu->insertItem( SmallIconSet("kit_info"), i18n("Information"), ID_TINFO );
+	treeMenu->insertItem( SmallIconSet("find"), i18n("Directory"), ID_TDIRECTORY);
 	treeMenu->insertSeparator();
 	treeMenu->insertItem( i18n("Delete Buddy..."), ID_TDELBUDDY );
 	treeMenu->insertSeparator();
@@ -807,6 +828,7 @@ TMessage &TWindow::messageWindow(const QString &name)
 	{
 		targetWindow = new TMessage(name, normedName, profile->data()->name,
 			profile->data()->logging, profile->data()->timestamping,
+			profile->data()->icqMode,
 			profile->data()->foregroundColor, profile->data()->backgroundColor,
 			profile->data()->bold);
 		messageWindows.insert(normedName, targetWindow);
@@ -820,6 +842,7 @@ TMessage &TWindow::messageWindow(const QString &name)
 		connect(this, SIGNAL(globalTimestamping(bool)), targetWindow, SLOT(setTimestamping(bool)) );
 		connect(this, SIGNAL(globalMyName(const QString &)), targetWindow, SLOT(setMyName(const QString &)) );
 		connect(this, SIGNAL(globalColors(const QColor &, const QColor &, bool)), targetWindow, SLOT(setColors(const QColor &, const QColor &, bool)) );
+		connect(this, SIGNAL(globalICQ(bool)), targetWindow, SLOT(setICQ(bool)) );
 		if(awayMessage != QString::null) targetWindow->setAway(true, awayMessage);
 	}
 	return *targetWindow;
