@@ -18,19 +18,21 @@
  *
  */
 
+#include <qbuttongroup.h>
 #include <qcheckbox.h>
 #include <qcombobox.h>
 #include <qlabel.h>
 #include <qlineedit.h>
 #include <qlayout.h>
-#include <qspinbox.h>
-#include <qvalidator.h> 
+#include <qradiobutton.h>
+#include <qvalidator.h>
 
 #include <kapp.h>
 #include <kconfig.h>
 #include <kfiledialog.h>
 #include <klocale.h>
 #include <kmessagebox.h>
+#include <knuminput.h>
 
 #include <netdb.h>
 #include <netinet/in.h>
@@ -44,11 +46,12 @@
 #include "kmglobal.h"
 
 #include "accountdialog.moc"
+#undef None
 
 AccountDialog::AccountDialog( KMAccount *account, const QStringList &identity,
 			      QWidget *parent, const char *name, bool modal )
-  :KDialogBase( parent, name, modal, i18n("Configure Account"), 
-		Ok|Cancel|Help, Ok, true ), mAccount(account), 
+  :KDialogBase( parent, name, modal, i18n("Configure Account"),
+		Ok|Cancel|Help, Ok, true ), mAccount(account),
   mIdentityList( identity )
 {
   QString accountType = mAccount->type();
@@ -75,9 +78,9 @@ AccountDialog::AccountDialog( KMAccount *account, const QStringList &identity,
 void AccountDialog::makeLocalAccountPage()
 {
   QFrame *page = makeMainWidget();
-  QGridLayout *topLayout = new QGridLayout( page, 10, 3, 0, spacingHint() );
+  QGridLayout *topLayout = new QGridLayout( page, 11, 3, 0, spacingHint() );
   topLayout->addColSpacing( 1, fontMetrics().maxWidth()*15 );
-  topLayout->setRowStretch( 9, 10 );
+  topLayout->setRowStretch( 10, 10 );
   topLayout->setColStretch( 1, 10 );
 
   mLocal.titleLabel = new QLabel( i18n("Account type: Local account"), page );
@@ -102,33 +105,47 @@ void AccountDialog::makeLocalAccountPage()
   choose->setAutoDefault( false );
   connect( choose, SIGNAL(clicked()), this, SLOT(slotLocationChooser()) );
   topLayout->addWidget( choose, 3, 2 );
- 
-  mLocal.excludeCheck = 
-    new QCheckBox( i18n("Exclude from \"Check Mail\""), page );
-  topLayout->addMultiCellWidget( mLocal.excludeCheck, 4, 4, 0, 2 );
 
-  mLocal.intervalCheck = 
+  QButtonGroup *group = new QButtonGroup( 1, Qt::Horizontal,
+    i18n("Locking method"), page );
+  mLocal.lockMutt = new QRadioButton(
+    i18n("Mutt dotlock (recommended)"), group);
+  mLocal.lockMuttPriv = new QRadioButton(
+    i18n("Mutt dotlock privileged"), group);
+  mLocal.lockProcmail = new QRadioButton(
+    i18n("Procmail lockfile"), group);
+  mLocal.lockFcntl = new QRadioButton(
+    i18n("FCNTL"), group);
+  mLocal.lockNone = new QRadioButton(
+    i18n("none (use with care)"), group);
+  topLayout->addMultiCellWidget( group, 4, 4, 0, 2 );
+
+  mLocal.excludeCheck =
+    new QCheckBox( i18n("Exclude from \"Check Mail\""), page );
+  topLayout->addMultiCellWidget( mLocal.excludeCheck, 5, 5, 0, 2 );
+
+  mLocal.intervalCheck =
     new QCheckBox( i18n("Enable interval mail checking"), page );
-  topLayout->addMultiCellWidget( mLocal.intervalCheck, 5, 5, 0, 2 );
+  topLayout->addMultiCellWidget( mLocal.intervalCheck, 6, 6, 0, 2 );
   connect( mLocal.intervalCheck, SIGNAL(toggled(bool)),
 	   this, SLOT(slotEnableLocalInterval(bool)) );
   mLocal.intervalLabel = new QLabel( i18n("Check interval (minutes):"), page );
-  topLayout->addWidget( mLocal.intervalLabel, 6, 0 );
-  mLocal.intervalSpin = new QSpinBox( page );
-  mLocal.intervalSpin->setRange( 1, 10000 );
+  topLayout->addWidget( mLocal.intervalLabel, 7, 0 );
+  mLocal.intervalSpin = new KIntNumInput( page );
+  mLocal.intervalSpin->setRange( 1, 10000, 1, FALSE );
   mLocal.intervalSpin->setValue( 1 );
-  topLayout->addWidget( mLocal.intervalSpin, 6, 1 );
+  topLayout->addWidget( mLocal.intervalSpin, 7, 1 );
 
   label = new QLabel( i18n("Destination folder:"), page );
-  topLayout->addWidget( label, 7, 0 );
+  topLayout->addWidget( label, 8, 0 );
   mLocal.folderCombo = new QComboBox( false, page );
-  topLayout->addWidget( mLocal.folderCombo, 7, 1 );
+  topLayout->addWidget( mLocal.folderCombo, 8, 1 );
 
   /* -sanders Probably won't support this way, use filters insteada
   label = new QLabel( i18n("Default identity:"), page );
-  topLayout->addWidget( label, 8, 0 );
+  topLayout->addWidget( label, 9, 0 );
   mLocal.identityCombo = new QComboBox( false, page );
-  topLayout->addWidget( mLocal.identityCombo, 8, 1 );
+  topLayout->addWidget( mLocal.identityCombo, 9, 1 );
   // GS - this was moved inside the commented block 9/30/2000
   //      (I think Don missed it?)
   label->setEnabled(false);
@@ -137,9 +154,9 @@ void AccountDialog::makeLocalAccountPage()
   //mLocal.identityCombo->setEnabled(false);
 
   label = new QLabel( i18n("Precommand:"), page );
-  topLayout->addWidget( label, 8, 0 );
+  topLayout->addWidget( label, 9, 0 );
   mLocal.precommand = new QLineEdit( page );
-  topLayout->addWidget( mLocal.precommand, 8, 1 );
+  topLayout->addWidget( mLocal.precommand, 9, 1 );
 
   connect(kapp,SIGNAL(kdisplayFontChanged()),SLOT(slotFontChanged()));
 }
@@ -149,11 +166,11 @@ void AccountDialog::makeLocalAccountPage()
 void AccountDialog::makePopAccountPage()
 {
   QFrame *page = makeMainWidget();
-  QGridLayout *topLayout = new QGridLayout( page, 17, 2, 0, spacingHint() );
+  QGridLayout *topLayout = new QGridLayout( page, 16, 2, 0, spacingHint() );
   topLayout->addColSpacing( 1, fontMetrics().maxWidth()*15 );
-  topLayout->setRowStretch( 16, 10 );
+  topLayout->setRowStretch( 15, 10 );
   topLayout->setColStretch( 1, 10 );
-  
+
   mPop.titleLabel = new QLabel( page );
   if( QString(mAccount->type()) == "pop" )
   {
@@ -185,69 +202,67 @@ void AccountDialog::makePopAccountPage()
   topLayout->addWidget( label, 4, 0 );
   mPop.passwordEdit = new QLineEdit( page );
   mPop.passwordEdit->setEchoMode( QLineEdit::Password );
-  topLayout->addWidget( mPop.passwordEdit, 4, 1 );  
+  topLayout->addWidget( mPop.passwordEdit, 4, 1 );
 
   label = new QLabel( i18n("Host:"), page );
   topLayout->addWidget( label, 5, 0 );
   mPop.hostEdit = new QLineEdit( page );
-  topLayout->addWidget( mPop.hostEdit, 5, 1 );  
+  topLayout->addWidget( mPop.hostEdit, 5, 1 );
 
   label = new QLabel( i18n("Port:"), page );
   topLayout->addWidget( label, 6, 0 );
   mPop.portEdit = new QLineEdit( page );
   mPop.portEdit->setValidator( new QIntValidator(this) );
-  topLayout->addWidget( mPop.portEdit, 6, 1 ); 
+  topLayout->addWidget( mPop.portEdit, 6, 1 );
 
   mPop.useSSLCheck =
-    new QCheckBox( i18n("Use SSL for secure mail download"), page);
+    new QCheckBox( i18n("Use SSL for secure mail download") + " " +
+      i18n("(experimental)"), page);
   topLayout->addMultiCellWidget( mPop.useSSLCheck, 7, 7, 0, 1);
   connect(mPop.useSSLCheck, SIGNAL(clicked()), this, SLOT(slotSSLChanged()));
+  mPop.useSSLCheck->hide();
 
-  mPop.storePasswordCheck = 
+  mPop.storePasswordCheck =
     new QCheckBox( i18n("Store POP password in configuration file"), page );
   topLayout->addMultiCellWidget( mPop.storePasswordCheck, 8, 8, 0, 1 );
-  
-  mPop.deleteMailCheck = 
+
+  mPop.deleteMailCheck =
     new QCheckBox( i18n("Delete mail from server"), page );
   topLayout->addMultiCellWidget( mPop.deleteMailCheck, 9, 9, 0, 1 );
 
-  mPop.retriveAllCheck = 
-    new QCheckBox( i18n("Retrieve all mail from server"), page );
-  topLayout->addMultiCellWidget( mPop.retriveAllCheck, 10, 10, 0, 1 );  
-
-  mPop.excludeCheck = 
+  mPop.excludeCheck =
     new QCheckBox( i18n("Exclude from \"Check Mail\""), page );
-  topLayout->addMultiCellWidget( mPop.excludeCheck, 11, 11, 0, 1 );
+  topLayout->addMultiCellWidget( mPop.excludeCheck, 10, 10, 0, 1 );
 
-  mPop.intervalCheck = 
+  mPop.intervalCheck =
     new QCheckBox( i18n("Enable interval mail checking"), page );
-  topLayout->addMultiCellWidget( mPop.intervalCheck, 12, 12, 0, 1 );
+  topLayout->addMultiCellWidget( mPop.intervalCheck, 11, 11, 0, 1 );
   connect( mPop.intervalCheck, SIGNAL(toggled(bool)),
 	   this, SLOT(slotEnablePopInterval(bool)) );
   mPop.intervalLabel = new QLabel( i18n("Check interval (minutes):"), page );
-  topLayout->addWidget( mPop.intervalLabel, 13, 0 );
-  mPop.intervalSpin = new QSpinBox( page );
-  mPop.intervalSpin->setRange( 1, 10000 );
+  topLayout->addWidget( mPop.intervalLabel, 12, 0 );
+  mPop.intervalSpin = new KIntNumInput( page );
+  mPop.intervalSpin->setRange( 1, 10000, 1, FALSE );
   mPop.intervalSpin->setValue( 1 );
-  topLayout->addWidget( mPop.intervalSpin, 13, 1 );
+  topLayout->addWidget( mPop.intervalSpin, 12, 1 );
 
   label = new QLabel( i18n("Destination folder:"), page );
-  topLayout->addWidget( label, 14, 0 );
+  topLayout->addWidget( label, 13, 0 );
   mPop.folderCombo = new QComboBox( false, page );
-  topLayout->addWidget( mPop.folderCombo, 14, 1 );
+  topLayout->addWidget( mPop.folderCombo, 13, 1 );
   /*
   label = new QLabel( i18n("Default identity:"), page );
-  topLayout->addWidget( label, 15, 0 );
+  topLayout->addWidget( label, 14, 0 );
   mPop.identityCombo = new QComboBox( false, page );
-  topLayout->addWidget( mPop.identityCombo, 15, 1 );
+  topLayout->addWidget( mPop.identityCombo, 14, 1 );
   label->setEnabled(false);
   */
   //  mPop.identityCombo->setEnabled(false);
 
   label = new QLabel( i18n("Precommand:"), page );
-  topLayout->addWidget( label, 16, 0 );
+  topLayout->addWidget( label, 15, 0 );
   mPop.precommand = new QLineEdit( page );
-  topLayout->addWidget( mPop.precommand, 16, 1 ); 
+  topLayout->addWidget( mPop.precommand, 15, 1 );
 
   connect(kapp,SIGNAL(kdisplayFontChanged()),SLOT(slotFontChanged()));
 }
@@ -263,7 +278,18 @@ void AccountDialog::setupSettings()
   {
     mLocal.nameEdit->setText( mAccount->name() );
     mLocal.locationEdit->setText( ((KMAcctLocal*)mAccount)->location() );
-    mLocal.intervalSpin->setValue( QMAX(1, interval) ); 
+    if (((KMAcctLocal*)mAccount)->mLock == mutt_dotlock)
+      mLocal.lockMutt->setChecked(true);
+    else if (((KMAcctLocal*)mAccount)->mLock == mutt_dotlock_privileged)
+      mLocal.lockMuttPriv->setChecked(true);
+    else if (((KMAcctLocal*)mAccount)->mLock == procmail_lockfile)
+      mLocal.lockProcmail->setChecked(true);
+    else if (((KMAcctLocal*)mAccount)->mLock == FCNTL)
+      mLocal.lockFcntl->setChecked(true);
+    else if (((KMAcctLocal*)mAccount)->mLock == None)
+      mLocal.lockNone->setChecked(true);
+
+    mLocal.intervalSpin->setValue( QMAX(1, interval) );
     mLocal.intervalCheck->setChecked( interval >= 1 );
     mLocal.excludeCheck->setChecked( mAccount->checkExclude() );
     mLocal.precommand->setText( mAccount->precommand() );
@@ -279,11 +305,10 @@ void AccountDialog::setupSettings()
     mPop.loginEdit->setText( ap.login() );
     mPop.passwordEdit->setText( ap.passwd());
     mPop.hostEdit->setText( ap.host() );
-    mPop.portEdit->setText( QString("%1").arg( ap.port() ) ); 
+    mPop.portEdit->setText( QString("%1").arg( ap.port() ) );
     mPop.useSSLCheck->setChecked( ap.useSSL() );
     mPop.storePasswordCheck->setChecked( ap.storePasswd() );
     mPop.deleteMailCheck->setChecked( !ap.leaveOnServer() );
-    mPop.retriveAllCheck->setChecked( ap.retrieveAll() );
     mPop.intervalCheck->setChecked( interval >= 1 );
     mPop.intervalSpin->setValue( QMAX(1, interval) );
     mPop.excludeCheck->setChecked( mAccount->checkExclude() );
@@ -301,23 +326,25 @@ void AccountDialog::setupSettings()
   if( acctFolder == 0 )
   {
     acctFolder = (KMFolder*)fdir->first();
-  }  
+  }
   if( acctFolder == 0 )
   {
     folderCombo->insertItem( i18n("<none>") );
   }
   else
-  { 
+  {
     uint i=0;
     for( KMFolder *folder = (KMFolder*)fdir->first(); folder != 0;
 	 folder = (KMFolder*)fdir->next() )
     {
-      if( folder->isDir() || 
-	  (folder->isSystemFolder() && (folder->name() != "inbox" ))) 
+      if( folder->isDir() ||
+	  (folder->isSystemFolder() && (folder->name() != "inbox" )))
       {
 	continue;
       }
-      folderCombo->insertItem( folder->name() );
+      if (folder->name() == "inbox")
+        folderCombo->insertItem( i18n("inbox") );
+      else folderCombo->insertItem( folder->name() );
       if( folder == acctFolder )
       {
 	folderCombo->setCurrentItem(i);
@@ -327,7 +354,7 @@ void AccountDialog::setupSettings()
 
     // -sanders hack for startup users. Must investigate this properly
     if (folderCombo->count() == 0)
-      folderCombo->insertItem( "inbox" );
+      folderCombo->insertItem( i18n("inbox") );
   }
 }
 
@@ -352,91 +379,83 @@ void AccountDialog::slotSSLChanged()
     } else {
       mPop.portEdit->setText("110");
     }
-  } 
+  }
 }
 
 
 void AccountDialog::slotOk()
 {
-  if( saveSettings() )
-  {
-    accept();
-  }
+  saveSettings();
+  accept();
 }
 
 
-bool AccountDialog::saveSettings()
+void AccountDialog::saveSettings()
 {
   QString accountType = mAccount->type();
   if( accountType == "local" )
-  {    
-    //
-    // The system can not handle empty name strings (espen 2000-10-30)
-    //
-    QString name = mLocal.nameEdit->text().stripWhiteSpace();
-    if( name.isEmpty() )
-    {
-      QString msg = i18n("You must specify an account name");
-      KMessageBox::information( topLevelWidget(), msg, i18n("Save Account") );
-      return false;
-    }
-    mAccount->setName( name );
+  {
+    mAccount->setName( mLocal.nameEdit->text() );
     ((KMAcctLocal*)mAccount)->setLocation( mLocal.locationEdit->text() );
-    mAccount->setCheckInterval( mLocal.intervalCheck->isChecked() ? 
+    if (mLocal.lockMutt->isChecked())
+      ((KMAcctLocal*)mAccount)->mLock = mutt_dotlock;
+    else if (mLocal.lockMuttPriv->isChecked())
+      ((KMAcctLocal*)mAccount)->mLock = mutt_dotlock_privileged;
+    else if (mLocal.lockProcmail->isChecked())
+      ((KMAcctLocal*)mAccount)->mLock = procmail_lockfile;
+    else if (mLocal.lockNone->isChecked())
+      ((KMAcctLocal*)mAccount)->mLock = None;
+    else ((KMAcctLocal*)mAccount)->mLock = FCNTL;
+
+    mAccount->setCheckInterval( mLocal.intervalCheck->isChecked() ?
 			     mLocal.intervalSpin->value() : 0 );
     mAccount->setCheckExclude( mLocal.excludeCheck->isChecked() );
- 
+
     mAccount->setPrecommand( mLocal.precommand->text() );
 
-    KMFolder *folder 
-      = kernel->folderMgr()->find( mLocal.folderCombo->currentText() );
+    KMFolder *folder;
+    if (mLocal.folderCombo->currentText() == i18n("inbox"))
+      folder = kernel->folderMgr()->find("inbox");
+    else
+      folder = kernel->folderMgr()->find( mLocal.folderCombo->currentText() );
     mAccount->setFolder( folder );
 
   }
   else if( accountType == "pop" )
   {
-    //
-    // The system can not handle empty name strings (espen 2000-10-30)
-    //
-    QString name = mPop.nameEdit->text().stripWhiteSpace();
-    if( name.isEmpty() )
-    {
-      QString msg = i18n("You must specify an account name");
-      KMessageBox::information( topLevelWidget(), msg, i18n("Save Account") );
-      return false;
-    }
-
-    mAccount->setName( name );
-    mAccount->setCheckInterval( mPop.intervalCheck->isChecked() ? 
+    mAccount->setName( mPop.nameEdit->text() );
+    mAccount->setCheckInterval( mPop.intervalCheck->isChecked() ?
 			     mPop.intervalSpin->value() : 0 );
     mAccount->setCheckExclude( mPop.excludeCheck->isChecked() );
 
-    KMFolder *folder 
-      = kernel->folderMgr()->find( mPop.folderCombo->currentText() );
+    KMFolder *folder;
+    if (mPop.folderCombo->currentText() == i18n("inbox"))
+      folder = kernel->folderMgr()->find("inbox");
+    else
+      folder = kernel->folderMgr()->find( mPop.folderCombo->currentText() );
     mAccount->setFolder( folder );
-    
+
     KMAcctExpPop &epa = *(KMAcctExpPop*)mAccount;
     epa.setHost( mPop.hostEdit->text() );
     epa.setPort( mPop.portEdit->text().toInt() );
     epa.setLogin( mPop.loginEdit->text() );
     epa.setPasswd( mPop.passwordEdit->text(), true );
-    epa.setUseSSL( mPop.useSSLCheck->isChecked() );
+//    epa.setUseSSL( mPop.useSSLCheck->isChecked() );
+    epa.setUseSSL( FALSE );
     epa.setStorePasswd( mPop.storePasswordCheck->isChecked() );
     epa.setPasswd( mPop.passwordEdit->text(), epa.storePasswd() );
     epa.setLeaveOnServer( !mPop.deleteMailCheck->isChecked() );
-    epa.setRetrieveAll( mPop.retriveAllCheck->isChecked() ); 
     epa.setPrecommand( mPop.precommand->text() );
 
   }
   kernel->acctMgr()->writeConfig(TRUE);
-  return true;
 }
 
 
 void AccountDialog::slotLocationChooser()
 {
   static QString directory( "/" );
-  
+
   KFileDialog dialog( directory, "*", this, 0, true );
   dialog.setCaption( i18n("Choose Location") );
 
@@ -446,7 +465,7 @@ void AccountDialog::slotLocationChooser()
     return;
   }
 
-  KURL url = dialog.selectedURL();  
+  KURL url = dialog.selectedURL();
   if( url.isEmpty() )
   {
     return;
@@ -456,7 +475,7 @@ void AccountDialog::slotLocationChooser()
     KMessageBox::sorry( 0L, i18n( "Only local files supported yet." ) );
     return;
   }
-  
+
   mLocal.locationEdit->setText( url.path() );
   directory = url.directory();
 }
