@@ -2,6 +2,7 @@
 // Author: Stefan Taferner <taferner@kde.org>
 // This code is under GPL
 
+#include <config.h>
 #include "kmaddrbook.h"
 #include <kapp.h>
 #include <kconfig.h>
@@ -30,7 +31,7 @@ KMAddrBook::KMAddrBook(): KMAddrBookInherited()
 //-----------------------------------------------------------------------------
 KMAddrBook::~KMAddrBook()
 {
-  if (mModified) 
+  if (mModified)
   {
     if(store() == IO_FatalError)
     {
@@ -44,9 +45,9 @@ KMAddrBook::~KMAddrBook()
 //-----------------------------------------------------------------------------
 void KMAddrBook::insert(const QString aAddress)
 {
-  if (find(aAddress)<0)
+  if (find((const char *)aAddress.local8Bit())<0)
   {
-    inSort(aAddress);
+    inSort((const char *)aAddress.local8Bit());
     mModified=TRUE;
   }
 }
@@ -107,12 +108,12 @@ int KMAddrBook::load(const QString &aFileName)
   clear();
 
   QTextStream t( &file );
+  t.setEncoding(QTextStream::Locale);
 
   while ( !t.eof() )
   {
     line = t.readLine();
-    kdDebug() << QString("load ") + line << endl;
-      if (line[0]!='#' && !line.isNull()) inSort(line);
+      if (line[0]!='#' && !line.isNull()) inSort((const char *)line.local8Bit());
   }
   rc = file.status();
   file.close();
@@ -135,12 +136,13 @@ int KMAddrBook::store(const QString &aFileName)
   if (!file.open(IO_ReadWrite|IO_Truncate)) return fileError(file.status());
   file.resetStatus(); // Work around suspected QT pre 2.2 snapshot bug
   QTextStream ts( &file );
+  ts.setEncoding(QTextStream::Locale);
 
   addr = "# kmail addressbook file\n";
   ts << addr;
   if (file.status() != IO_Ok) return fileError(file.status());
 
-  for (addr=first(); addr; addr=next())
+  for (addr=QString::fromLocal8Bit(first()); addr; addr=QString::fromLocal8Bit(next()))
   {
     ts << addr << "\n";
     if (file.status() != IO_Ok) return fileError(file.status());
@@ -189,17 +191,18 @@ int KMAddrBook::compareItems(Item aItem1, Item aItem2)
 void KabBridge::addresses(QStringList* result, QValueList<KabKey> *keys)
 {
   QString addr;
+  QString email;
   KabKey key;
   AddressBook::Entry entry;
   if (keys)
     keys->clear();
   int num = kernel->KABaddrBook()->addressbook()->noOfEntries();
-  
+
   for (int i = 0; i < num; ++i) {
-    if (AddressBook::NoError != 
+    if (AddressBook::NoError !=
 	kernel->KABaddrBook()->addressbook()->getKey( i, key ))
       continue;
-    if (AddressBook::NoError != 
+    if (AddressBook::NoError !=
 	kernel->KABaddrBook()->addressbook()->getEntry( key, entry ))
       continue;
     if ((entry.emails.count() > 0) && !entry.emails[0].isEmpty()) {
@@ -207,7 +210,13 @@ void KabBridge::addresses(QStringList* result, QValueList<KabKey> *keys)
 	addr = "";
       else
 	addr = "\"" + entry.fn + "\" ";
-      addr += "<" + entry.emails[0] + ">";
+      email = entry.emails[0];
+      if (!addr.isEmpty() && (email.find( "<" ) == -1)
+	  && (email.find( ">" ) == -1)
+	  && (email.find( "," ) == -1))
+	  addr += "<" + email + ">";
+      else
+	  addr += email;
       addr.stripWhiteSpace();
       result->append( addr );
       if (keys)
@@ -245,7 +254,7 @@ bool KabBridge::add(QString address, KabKey &kabkey)
     kdDebug() << "Error occurred trying to update database: operation insert.0" << endl;
     return false;
   }
-  if (kernel->KABaddrBook()->addressbook()->save("", true) != 
+  if (kernel->KABaddrBook()->addressbook()->save("", true) !=
       AddressBook::NoError) {
     kdDebug() << "Error occurred trying to update database: opeation insert.1" << endl;
     return false;
@@ -260,8 +269,8 @@ bool KabBridge::remove(KabKey kabKey)
     kdDebug() << "Error occurred trying to update database: operation remove.0" << endl;
     return false;
   }
-  
-  if (kernel->KABaddrBook()->addressbook()->save("", true) != 
+
+  if (kernel->KABaddrBook()->addressbook()->save("", true) !=
       AddressBook::NoError) {
     kdDebug() << "Error occurred trying to update database: operation remove.1" << endl;
     return false;
@@ -272,7 +281,7 @@ bool KabBridge::remove(KabKey kabKey)
 bool KabBridge::replace(QString address, KabKey kabKey)
 {
   AddressBook::Entry old;
-  if (AddressBook::NoError != 
+  if (AddressBook::NoError !=
       kernel->KABaddrBook()->addressbook()->getEntry( kabKey, old )) {
     kdDebug() << "Error occurred trying to update database: operation replace.0" << endl;
     return false;
@@ -289,7 +298,7 @@ bool KabBridge::replace(QString address, KabKey kabKey)
     return false;
   }
 
-  if (kernel->KABaddrBook()->addressbook()->save("", true) != 
+  if (kernel->KABaddrBook()->addressbook()->save("", true) !=
       AddressBook::NoError) {
     kdDebug() << "Error occurred trying to update database: operation replace.2" << endl;
     return false;
@@ -303,10 +312,9 @@ void KMAddrBookExternal::addEmail(QString addr, QWidget *parent) {
   KConfig *config = kapp->config();
   config->setGroup("General");
   int ab = config->readNumEntry("addressbook", -1);
-  KURL::List list;
   if (ab == 3) {
-    KURL::List list;
-    KRun::run( "abbrowser -a \"" + addr + "\"", list );
+    KRun::runCommand( "abbrowser -a \"" + addr.replace(QRegExp("\""), "")
+      + "\"" );
     return;
   }
   if (!KMAddrBookExternal::useKAB()) {
@@ -324,7 +332,6 @@ void KMAddrBookExternal::launch(QWidget *parent) {
   KConfig *config = kapp->config();
   config->setGroup("General");
   int ab = config->readNumEntry("addressbook", -1);
-  KURL::List list;
   switch (ab)
   {
   case -1:
@@ -332,21 +339,21 @@ void KMAddrBookExternal::launch(QWidget *parent) {
   case 1:
     {
     KMAddrBookEditDlg dlg( kernel->addrBook(), parent );
-    dlg.exec();    
+    dlg.exec();
     break;
     }
   case 2:
-    KRun::run("kab", list);
+    KRun::runCommand("kab");
     break;
   case 3:
-    KRun::run("abbrowser", list);
+    KRun::runCommand("abbrowser");
     break;
   default:
     kdDebug() << "Unknown address book type" << endl;
   }
 }
 
-bool KMAddrBookExternal::useKAB() 
+bool KMAddrBookExternal::useKAB()
 {
   KConfig *config = kapp->config();
   config->setGroup("General");
