@@ -6,6 +6,10 @@
 #define KMAddrBook_h
 
 #include <qstrlist.h>
+#include <qstringlist.h> // for KabBridge
+#include <qvaluelist.h>  // for KabBridge
+#include <kabapi.h> // for KabBridge
+
 
 #define KMAddrBookInherited QStrList
 class KMAddrBook: protected QStrList
@@ -59,4 +63,21 @@ protected:
   bool mModified;
 };
 
+class KabBridge {
+public:
+  static void addresses(QStringList* result, QValueList<KabKey> *keys=0);
+  static QString fn(QString address);
+  static QString email(QString address);
+  static bool add(QString address, KabKey &kabkey);
+  static bool remove(KabKey);
+  static bool replace(QString address, KabKey);
+};
+
+class KMAddrBookExternal {
+public:
+  static void addEmail(QString addr, QWidget *parent);
+  static void launch(QWidget *parent);
+  static bool useKAB();
+};
+
 #endif /*KMAddrBook_h*/
