@@ -24,9 +24,9 @@
 #include "kmaddrbookdlg.h"
 #include "kmaddrbook.h"
 #include "kmidentity.h"
-#include <kabapi.h>
-#include <kfontutils.h>
+#include "kmfolder.h"
 
+#include <kabapi.h>
 #include <kaction.h>
 #include <kcharsets.h>
 #include <kcursor.h>
@@ -37,7 +37,7 @@
 
 #ifndef KRN
 #include "kmmainwin.h"
-#include "kmsettings.h"
+#include "configuredialog.h"
 #include "kfileio.h"
 #endif
 #include "kmreaderwin.h"
@@ -55,6 +55,7 @@
 #include <kwin.h>
 #include <kglobal.h>
 #include <kmessagebox.h>
+#include <kurldrag.h>
 
 #include <kspell.h>
 
@@ -102,25 +103,6 @@ WindowList* windowList=new WindowList;
 
 #include "kmcomposewin.moc"
 
-
-#define HDR_FROM     0x01
-#define HDR_REPLY_TO 0x02
-#define HDR_TO       0x04
-#define HDR_CC       0x08
-#define HDR_BCC      0x10
-#define HDR_SUBJECT  0x20
-#define HDR_NEWSGROUPS  0x40
-#define HDR_FOLLOWUP_TO 0x80
-#define HDR_IDENTITY 0x100
-#define HDR_TRANSPORT 0x200
-#define HDR_ALL      0x3ff
-
-#ifdef KRN
-#define HDR_STANDARD (HDR_SUBJECT|HDR_NEWSGROUPS)
-#else
-#define HDR_STANDARD (HDR_SUBJECT|HDR_TO|HDR_CC)
-#endif
-
 //-----------------------------------------------------------------------------
 KMComposeWin::KMComposeWin(KMMessage *aMsg, QString id )
   : KMTopLevelWidget (),
@@ -151,7 +133,9 @@ KMComposeWin::KMComposeWin(KMMessage *aMsg, QString id )
   mAtmList.setAutoDelete(TRUE);
   mAtmTempList.setAutoDelete(TRUE);
   mAutoDeleteMsg = FALSE;
+  mFolder = NULL;
   mEditor = NULL;
+  disableBreaking = false;
 
   mSpellCheckInProgress=FALSE;
 
@@ -220,6 +204,12 @@ KMComposeWin::KMComposeWin(KMMessage *aMsg, QString id )
 KMComposeWin::~KMComposeWin()
 {
   writeConfig();
+  if (mFolder && mMsg)
+  {
+    mAutoDeleteMsg = FALSE;
+    mFolder->addMsg(mMsg);
+    emit messageQueuedOrDrafted();
+  }
   if (mAutoDeleteMsg && mMsg) delete mMsg;
   QMap<KIO::Job*, atmLoadData>::Iterator it = mapAtmLoadData.begin();
   while ( it != mapAtmLoadData.end() )
@@ -231,6 +221,34 @@ KMComposeWin::~KMComposeWin()
   }
 }
 
+
+//-----------------------------------------------------------------------------
+void KMComposeWin::makeDescriptiveNames(QStringList &encodings)
+{
+  QStringList encodingNames = KGlobal::charsets()->availableEncodingNames();
+  QMap<QTextCodec*, QString> encodingMap;
+  for (QStringList::Iterator it = encodingNames.begin();
+    it != encodingNames.end(); it++)
+  {
+    QTextCodec *codec = KMMsgBase::codecForName(*it);
+    if (codec) encodingMap.insert(codec, *it);
+  }
+  for (QStringList::Iterator it = encodings.begin();
+    it != encodings.end(); it++)
+  {
+    QTextCodec *codec = KMMsgBase::codecForName(*it);
+    QMap<QTextCodec*, QString>::Iterator it2 = encodingMap.find(codec);
+    if (it2 == encodingMap.end()) 
+      (*it) = KGlobal::charsets()->languageForEncoding(*it)
+      + " ( " + *it + " )";
+    else
+      (*it) = KGlobal::charsets()->languageForEncoding(*it2)
+      + " ( " + *it + " )";
+  }
+}  
+
+
+//-----------------------------------------------------------------------------
 bool KMComposeWin::event(QEvent *e)
 {
   if (e->type() == QEvent::ApplicationPaletteChange)
@@ -282,13 +300,19 @@ void KMComposeWin::readConfig(void)
   config->setGroup("Composer");
 
   str = config->readEntry("charset", "");
-  if (str.isNull() || str=="default" || !KGlobal::charsets()->isAvailable(str))
-      mDefCharset = "default";
+  if (str.isNull() || str.isEmpty() || str=="default")
+    mDefCharset = defaultCharset();
   else
-      mDefCharset = str;
+  {
+    mDefCharset = str;
+    if ( !KGlobal::charsets()->isAvailable(
+      KGlobal::charsets()->charsetForEncoding(mDefCharset)) )
+        mDefCharset = "default";
+  }
 
   kdDebug() << "Default charset: " << (const char*)mDefCharset << endl;
 
+  mForceReplyCharset = config->readBoolEntry("force-reply-charset", false );
   mAutoSign = config->readEntry("signature","auto") == "auto";
   mDefEncoding = config->readEntry("encoding", "base64");
   mShowHeaders = config->readNumEntry("headers", HDR_STANDARD);
@@ -336,10 +360,15 @@ void KMComposeWin::readConfig(void)
 #endif
 
   config->setGroup("Fonts");
+  mUnicodeFont = config->readBoolEntry("unicodeFont",FALSE);
   if (!config->readBoolEntry("defaultFonts",TRUE)) {
-    QString mBodyFontStr;
-    mBodyFontStr = config->readEntry("body-font", "helvetica-medium-r-12");
-    mBodyFont = kstrToFont(mBodyFontStr);
+    mBodyFont = QFont("helvetica");
+    mBodyFont = config->readFontEntry("body-font", &mBodyFont);
+    QString bodyFamily = mBodyFont.family();
+    int pos = bodyFamily.find("-");
+    // We ignore the foundary, otherwise we can't set the charset
+    if (pos != -1)
+      mBodyFont.setFamily(bodyFamily.right(bodyFamily.length()-pos-1));
   }
   else
     mBodyFont = KGlobalSettings::generalFont();
@@ -388,9 +417,6 @@ void KMComposeWin::writeConfig(void)
   mTransportHistory.prepend(mTransport.currentText());
   config->writeEntry("transport-history", mTransportHistory );
 
-  config->writeEntry("charset",mDefCharset);
-
-
   config->setGroup("Geometry");
   str.sprintf("%d %d", width(), height());
   config->writeEntry("composer", str);
@@ -603,14 +629,13 @@ void KMComposeWin::rethinkHeaderLine(int aValue, int aMask, int& aRow,
     aEdt->setMaximumSize(1000, aLbl->height()+2);
     mEdtList.append(aEdt);
 
+    mGrid->addWidget(aEdt, aRow, 1);
     if (aBtn)
     {
-      mGrid->addWidget(aEdt, aRow, 1);
       mGrid->addWidget(aBtn, aRow, 2);
       aBtn->setFixedSize(aBtn->sizeHint().width(), aLbl->height());
       aBtn->show();
     }
-    else mGrid->addMultiCellWidget(aEdt, aRow, aRow, 1, 2);
     aRow++;
   }
   else
@@ -640,7 +665,6 @@ void KMComposeWin::rethinkHeaderLine(int aValue, int aMask, int& aRow,
     aCbx->show();
     aCbx->setMinimumSize(100, aLbl->height()+2);
     aCbx->setMaximumSize(1000, aLbl->height()+2);
-    mEdtList.append(aCbx);
 
     mGrid->addWidget(aCbx, aRow, 1);
     mGrid->addWidget(aChk, aRow, 2);
@@ -682,6 +706,9 @@ void KMComposeWin::setupActions(void)
                         actionCollection(), "send_alternative");
   }
 
+  (void) new KAction (i18n("Save in &drafts folder"), "", 0,
+		      this, SLOT(slotSaveDraft()),
+		      actionCollection(), "save_in_drafts");
   (void) new KAction (i18n("&Insert File..."), "fileopen", 0,
                       this,  SLOT(slotInsertFile()),
                       actionCollection(), "insert_file");
@@ -727,24 +754,19 @@ void KMComposeWin::setupActions(void)
 #endif
 
   //----- Message-Encoding Submenu
-  encodingAction = new KSelectAction( i18n( "Set &Encoding.." ), 0, this, SLOT(slotSetCharset() ), actionCollection(), "charsets" );
-  // availableCharsetNames seems more reasonable than availableEncodingNames
-  QStringList encodings = KGlobal::charsets()->availableCharsetNames();
-  encodings.remove(QString("*-*"));  //this doesn't make sense
-  encodings.prepend( "us-ascii" );
+  encodingAction = new KSelectAction( i18n( "Set &Encoding" ), 0, this, SLOT(slotSetCharset() ), actionCollection(), "charsets" );
+  wordWrapAction = new KToggleAction (i18n("&Wordwrap"), 0,
+		      actionCollection(), "wordwrap");
+  wordWrapAction->setChecked(mWordWrap);
+  connect(wordWrapAction, SIGNAL(toggled(bool)), SLOT(slotWordWrapToggled(bool)));
+
+  KConfig *config = kapp->config();
+  config->setGroup("Composer");
+  QStringList encodings = config->readListEntry("charsets");
+  makeDescriptiveNames( encodings );
+
   encodingAction->setItems( encodings );
-  //guess default from font charset
-  int i = 0;
-  bool found = false;
-  for ( QStringList::Iterator it = encodings.begin(); it != encodings.end(); ++it, i++ )
-    if ((*it) == KGlobal::charsets()->xCharsetName(mBodyFont.charSet()))
-    {
-      encodingAction->setCurrentItem(i);
-      found = true;
-      break;
-    }
-  if (!found)
-    encodingAction->setCurrentItem(0);
+  encodingAction->setCurrentItem( -1 );
 
   //these are checkable!!!
   allFieldsAction = new KToggleAction (i18n("&All Fields"), 0, this,
@@ -829,8 +851,7 @@ void KMComposeWin::setupActions(void)
     attachMPK->setEnabled(false);
     encryptAction->setEnabled(false);
     signAction->setEnabled(false);
-  }
-
+  } else
   signAction->setChecked(mAutoPgpSign);
 
   createGUI("kmcomposerui.rc");
@@ -964,7 +985,7 @@ void KMComposeWin::setMsg(KMMessage* newMsg, bool mayAutoSign)
 
   if (num > 0)
   {
-    QCString bodyDecoded;
+    QString bodyDecoded; // Workaroud for bug in QT-2.2.4, better use QCString
     mMsg->bodyPart(0, &bodyPart);
 
     mCharset = bodyPart.charset();
@@ -976,8 +997,18 @@ void KMComposeWin::setMsg(KMMessage* newMsg, bool mayAutoSign)
     bodyDecoded = bodyPart.bodyDecoded();
 
     verifyWordWrapLengthIsAdequate(bodyDecoded);
-    mEditor->setText(bodyDecoded);
+
+// Workaround for bug in QT-2.2.2
+if (mCharset == "utf-8") mEditor->setText(QString::fromUtf8(bodyDecoded));
+else
+{
+    QTextCodec *codec = KMMsgBase::codecForName(mCharset);
+    if (codec)
+      mEditor->setText(codec->toUnicode(bodyDecoded));
+    else
+      mEditor->setText(QString::fromLocal8Bit(bodyDecoded));
     mEditor->insertLine("\n", -1);
+}
 
     for(i=1; i<num; i++)
     {
@@ -992,22 +1023,21 @@ void KMComposeWin::setMsg(KMMessage* newMsg, bool mayAutoSign)
     if ((mCharset=="") || (mCharset == "default"))
       mCharset = defaultCharset();
 
-    QTextCodec *codec = KGlobal::charsets()->codecForName(mCharset);
-    mEditor->setText(codec->toUnicode(mMsg->bodyDecoded()));
+// Workaround for bug in QT-2.2.2
+if (mCharset == "utf-8")
+  mEditor->setText(QString::fromUtf8(mMsg->bodyDecoded()));
+else
+{
+    QTextCodec *codec = KMMsgBase::codecForName(mCharset);
+    if (codec) {
+      QString bodyDecoded = mMsg->bodyDecoded();
+      mEditor->setText(codec->toUnicode(bodyDecoded));
+    } else
+      mEditor->setText(QString::fromLocal8Bit(mMsg->bodyDecoded()));
+}
   }
 
-  setEditCharset();
-
-  QStringList encodings = encodingAction->items();
-  i = 0;
-  for ( QStringList::Iterator it = encodings.begin(); it != encodings.end(); ++it, i++ )
-  // it's safer to compare QFont::CharSet rather that strings directly
-    if (KGlobal::charsets()->nameToID(*it) == KGlobal::charsets()->nameToID(mCharset))
-    {
-      encodingAction->setCurrentItem( i );
-      break;
-    }
-
+  setCharset(mCharset);
 
   if( mAutoSign && mayAutoSign )
   {
@@ -1021,6 +1051,7 @@ void KMComposeWin::setMsg(KMMessage* newMsg, bool mayAutoSign)
   }
   mEditor->setModified(FALSE);
 
+
   //put font charset as default charset: jstolarz@kde.org
 //  QString defCharset = mMsg->charset();
 //  if ((mAtmList.count() <= 0) && defCharset.isEmpty() &&
@@ -1081,27 +1112,18 @@ bool KMComposeWin::applyChanges(void)
   if(mAtmList.count() <= 0) {
     // If there are no attachments in the list waiting it is a simple
     // text message.
+    mMsg->deleteBodyParts();
     mMsg->setAutomaticFields(TRUE);
-    mMsg->setTypeStr("text");
-    mMsg->setSubtypeStr("plain");
+    mMsg->setHeaderField("Content-Type","text/plain");
 
     mMsg->setCteStr(isQP ? "quoted-printable": "8bit");
 
-    QString str = pgpProcessedMsg();
-    QCString body;
-    if (str.isNull()) return FALSE;
-
     if (mCharset == "default")
       mCharset = defaultCharset();
     mMsg->setCharset(mCharset);
-    str.truncate(str.length()); // to ensure str.size()==str.length()+1
-    QTextCodec *codec = KGlobal::charsets()->codecForName(mCharset);
-
-    if (codec == NULL) {
-      kdDebug() << "Something is wrong and I can not get a codec." << endl;
-      body = str.latin1();
-    } else
-      body = codec->fromUnicode(str);
+    QCString body = pgpProcessedMsg();
+    if (body.isNull()) return FALSE;
+    if (body.isEmpty()) body = "\n";     // don't crash
 
     if (isQP)
       mMsg->setBodyEncoded(body);
@@ -1125,24 +1147,14 @@ bool KMComposeWin::applyChanges(void)
 
     bodyPart.setCteStr(isQP ? "quoted-printable": "8bit");
 
-    QString str = pgpProcessedMsg();
-    QCString body;
-    if (str.isNull()) return FALSE;
-
     if (mCharset == "default")
       mCharset = defaultCharset();
     bodyPart.setCharset(mCharset);
-    str.truncate(str.length()); // to ensure str.size()==str.length()+1
-    QTextCodec *codec = KGlobal::charsets()->codecForName(mCharset);
-
-    if (codec == NULL) {
-      kdDebug() << "Something is wrong and I can not get a codec." << endl;
-      body = str.latin1();
-    } else
-      body = codec->fromUnicode(str);
+    QCString body = pgpProcessedMsg();
+    if (body.isNull()) return FALSE;
+    if (body.isEmpty()) body = "\n";     // don't crash
 
     bodyPart.setBodyEncoded(body);
-
     mMsg->addBodyPart(&bodyPart);
 
     // Since there is at least one more attachment create another bodypart
@@ -1190,7 +1202,7 @@ bool KMComposeWin::queryExit ()
 }
 
 //-----------------------------------------------------------------------------
-const QString KMComposeWin::pgpProcessedMsg(void)
+const QCString KMComposeWin::pgpProcessedMsg(void)
 {
   Kpgp *pgp = Kpgp::getKpgp();
   bool doSign = signAction->isChecked();
@@ -1198,10 +1210,45 @@ const QString KMComposeWin::pgpProcessedMsg(void)
   QString _to, receiver;
   int index, lastindex;
   QStrList persons;
+  QString text;
+  QCString cText;
 
-  if (!doSign && !doEncrypt) return mEditor->brokenText();
+  if (disableBreaking)
+      text = mEditor->text();
+  else
+      text = mEditor->brokenText();
 
-  pgp->setMessage(mEditor->brokenText());
+  text.truncate(text.length()); // to ensure text.size()==text.length()+1
+  QTextCodec *codec = KMMsgBase::codecForName(mCharset);
+
+  if (mCharset == "us-ascii")
+    cText = KMMsgBase::toUsAscii(text);
+  else if (codec == NULL) {
+    kdDebug() << "Something is wrong and I can not get a codec." << endl;
+    cText = text.local8Bit();
+  } else
+      cText = codec->fromUnicode(text);
+
+  if (!text.isEmpty() && codec && mCharset != "utf-8" && codec->toUnicode(QString(cText)) != text) // Workaround for bug in QT-2.2.4
+  {
+    QString oldText = mEditor->text();
+    mEditor->setText(codec->toUnicode(QString(cText))); // Workaround
+    kernel->kbp()->idle();
+    bool anyway = (KMessageBox::warningYesNo(0L,
+    i18n("Not all characters fit into the chosen"
+    " encoding.\nSend the message anyway?"),
+    i18n("Some characters will be lost"),
+    i18n("Yes"), i18n("No, let me change the encoding") ) == KMessageBox::Yes);
+    if (!anyway)
+    {
+      mEditor->setText(oldText);
+      return QCString();
+    }
+  }
+
+  if (!doSign && !doEncrypt) return cText;
+
+  pgp->setMessage(cText);
 
   if (!doEncrypt)
   {
@@ -1234,12 +1281,12 @@ const QString KMComposeWin::pgpProcessedMsg(void)
   //qWarning(i18n("Error during PGP:") + QString("\n") +
   //	  pgp->lastErrorMsg());
 
-  return QString::null;
+  return QCString();
 }
 
 
 //-----------------------------------------------------------------------------
-void KMComposeWin::addAttach(const QString aUrl)
+void KMComposeWin::addAttach(const KURL aUrl)
 {
   KIO::Job *job = KIO::get(aUrl);
   atmLoadData ld;
@@ -1289,7 +1336,7 @@ void KMComposeWin::msgPartToItem(const KMMessagePart* msgPart,
   if (len > 9999) lenStr.sprintf("%uK", (len>>10));
   else lenStr.sprintf("%u", len);
 
-  lvi->setText(0, msgPart->name());
+  lvi->setText(0, msgPart->fileName());
   lvi->setText(1, lenStr);
   lvi->setText(2, msgPart->contentTransferEncodingStr());
   lvi->setText(3, msgPart->typeStr() + "/" + msgPart->subtypeStr());
@@ -1350,6 +1397,30 @@ void KMComposeWin::addrBookSelInto(KMLineEdit* aLineEdit)
 }
 
 
+//-----------------------------------------------------------------------------
+void KMComposeWin::setCharset(const QString& aCharset, bool forceDefault)
+{
+  if ((forceDefault && mForceReplyCharset) || aCharset.isEmpty())
+    mCharset = mDefCharset;
+  else mCharset = aCharset;
+  mMsg->setCharset(mCharset);
+
+  QStringList encodings = encodingAction->items();
+  int i = 0;
+  for ( QStringList::Iterator it = encodings.begin(); it != encodings.end();
+     ++it, i++ )
+  {
+    if (KMMsgBase::codecForName(KGlobal::charsets()->encodingForName(*it))
+      == KMMsgBase::codecForName(mCharset))
+    {
+      encodingAction->setCurrentItem( i );
+      slotSetCharset();
+      break;
+    }
+  }
+}
+
+
 //-----------------------------------------------------------------------------
 void KMComposeWin::slotAddrBook()
 {
@@ -1393,23 +1464,17 @@ void KMComposeWin::slotAddrBookBcc()
 
 
 //-----------------------------------------------------------------------------
-  //-----------------------------------------------------------------------------
-  void KMComposeWin::slotAttachFile()
-  {
-    // Create File Dialog and return selected file(s)
-    // We will not care about any permissions, existence or whatsoever in
-    // this function.
+void KMComposeWin::slotAttachFile()
+{
+  // Create File Dialog and return selected file(s)
+  // We will not care about any permissions, existence or whatsoever in
+  // this function.
 
-    KURL::List files = KFileDialog::getOpenURLs(QString::null, "*", this, i18n("Attach File"));
-    QStringList list = files.toStringList();
-    for ( QStringList::Iterator it = list.begin(); it != list.end(); ++it ) {
-      QString name = *it;
-      if(!name.isEmpty()) {
-        addAttach(name);
-      }
-    }
-
-  }
+  KURL::List files = KFileDialog::getOpenURLs(QString::null, "*", this,
+    i18n("Attach File"));
+  for (KURL::List::Iterator it = files.begin(); it != files.end(); ++it)
+    addAttach(*it);
+}
 
 
 //-----------------------------------------------------------------------------
@@ -1439,7 +1504,7 @@ void KMComposeWin::slotAttachFileResult(KIO::Job *job)
   {
     int col, line;
     mEditor->getCursorPosition(&line, &col);
-    mEditor->insertAt((*it).data, line, col);
+    mEditor->insertAt(QString::fromLocal8Bit((*it).data), line, col);
     mapAtmLoadData.remove(it);
     return;
   }
@@ -1452,14 +1517,15 @@ void KMComposeWin::slotAttachFileResult(KIO::Job *job)
   kernel->kbp()->busy();
   i = urlStr.findRev('/');
   name = (i>=0 ? urlStr.mid(i+1, 256) : urlStr);
-  QString encName = KMMsgBase::encodeRFC2231String(name);
+  QString encName = KMMsgBase::encodeRFC2231String(name, mCharset);
   bool RFC2231encoded = name != encName;
 
   // create message part
   msgPart = new KMMessagePart;
+  msgPart->setCharset(mCharset);
   msgPart->setName(name);
   msgPart->setCteStr(mDefEncoding);
-  msgPart->setBodyEncoded((*it).data);
+  msgPart->setBodyEncodedBinary((*it).data);
   msgPart->magicSetType();
   msgPart->setContentDisposition(QString("attachment; filename")
     + ((RFC2231encoded) ? "*" : "") +  "=\"" + encName + "\"");
@@ -1508,15 +1574,10 @@ void KMComposeWin::slotInsertFile()
 //-----------------------------------------------------------------------------
 void KMComposeWin::slotSetCharset()
 {
-  mCharset = encodingAction->currentText();
-  if (encodingAction->currentItem() != 0)  //i.e. <none>
-  {
-    QFont::CharSet c = KGlobal::charsets()->nameToID(mCharset);
-    mCharset = KGlobal::charsets()->name(c);
-  }
-  if (mAtmList.count() <= 0)
-    mMsg->setCharset(mCharset);
-  writeConfig();
+  mCharset = KGlobal::charsets()->encodingForName( encodingAction->
+    currentText() );
+  mMsg->setCharset(mCharset);
+  setEditCharset();
 }
 
 
@@ -1528,10 +1589,12 @@ void KMComposeWin::slotInsertMyPublicKey()
 
   // load the file
   kernel->kbp()->busy();
-  str=Kpgp::getKpgp()->getAsciiPublicKey(mMsg->from());
-  if (str.isNull())
+  str=Kpgp::getKpgp()->getAsciiPublicKey(Kpgp::getKpgp()->user());
+  if (str.isEmpty())
   {
     kernel->kbp()->idle();
+    KMessageBox::sorry( 0L, i18n("Couldn't get your public key for\n%1.")
+      .arg(Kpgp::getKpgp()->user()) );
     return;
   }
 
@@ -1645,9 +1708,10 @@ void KMComposeWin::slotAttachView()
   KTempFile* atmTempFile = new KTempFile();
   mAtmTempList.append( atmTempFile );
   atmTempFile->setAutoDelete( true );
-  kByteArrayToFile(msgPart->bodyDecoded(), atmTempFile->name(), false, false,
+  kByteArrayToFile(msgPart->bodyDecodedBinary(), atmTempFile->name(), false, false,
     false);
-  KMReaderWin::atmView(NULL, msgPart, false, atmTempFile->name(), pname, 0);
+  KMReaderWin::atmView(NULL, msgPart, false, atmTempFile->name(), pname,
+    KMMsgBase::codecForName(mCharset));
 }
 
 
@@ -1677,7 +1741,7 @@ void KMComposeWin::slotAttachSave()
 
   fileName = url.path();
 
-  kByteArrayToFile(msgPart->bodyDecoded(), fileName, TRUE);
+  kByteArrayToFile(msgPart->bodyDecodedBinary(), fileName, TRUE);
 }
 
 
@@ -1842,6 +1906,21 @@ void KMComposeWin::slotEncryptToggled(bool on)
 }
 
 
+//-----------------------------------------------------------------------------
+void KMComposeWin::slotWordWrapToggled(bool on)
+{
+  if (on)
+  {
+    mEditor->setWordWrap( QMultiLineEdit::FixedColumnWidth );
+    mEditor->setWrapColumnOrWidth(mLineBreak);
+  }
+  else
+  {
+    mEditor->setWordWrap( QMultiLineEdit::NoWrap );
+  }
+}
+
+
 //-----------------------------------------------------------------------------
 void KMComposeWin::slotPrint()
 {
@@ -1855,13 +1934,11 @@ void KMComposeWin::slotPrint()
 //-----------------------------------------------------------------------------
 void KMComposeWin::slotDropAction(QDropEvent *e)
 {
-  QStrList fileStrList;
-  QStringList::Iterator it;
-  if(QUriDrag::canDecode(e) && QUriDrag::decode( e, fileStrList )) {
-    QStringList fileList = QStringList::fromStrList(fileStrList);
-    for (it = fileList.begin(); it != fileList.end(); ++it) {
-      addAttach(QString::fromLocal8Bit(*it));
-    }
+  KURL::List urlList;
+  if(QUriDrag::canDecode(e) && KURLDrag::decode( e, urlList ))
+  {
+    for (KURL::List::Iterator it = urlList.begin(); it != urlList.end(); ++it)
+      addAttach(*it);
   }
   else
     KMessageBox::sorry( 0L, i18n( "Only local files are supported." ) );
@@ -1869,10 +1946,14 @@ void KMComposeWin::slotDropAction(QDropEvent *e)
 
 
 //----------------------------------------------------------------------------
-void KMComposeWin::doSend(int aSendNow)
+void KMComposeWin::doSend(int aSendNow, bool saveInDrafts)
 {
-    QString hf = mMsg->headerField("X-KMail-Transport");
+  QString hf = mMsg->headerField("X-KMail-Transport");
+  QString msgId = mMsg->msgId();
+  static bool busy = 0;
   bool sentOk;
+  if (busy) return;
+  busy = true;
 
   kernel->kbp()->busy();
   //applyChanges();  // is called twice otherwise. Lars
@@ -1887,14 +1968,25 @@ void KMComposeWin::doSend(int aSendNow)
       (!hf.isEmpty() && (hf != kernel->msgSender()->transportString())))
     mMsg->setHeaderField("X-KMail-Transport", mTransport.currentText());
 
-  sentOk = (applyChanges() && kernel->msgSender()->send(mMsg, aSendNow));
+  disableBreaking = saveInDrafts;
+  if (saveInDrafts)
+      sentOk = (applyChanges() && !(kernel->draftsFolder()->addMsg(mMsg)));
+  else
+      sentOk = (applyChanges() && kernel->msgSender()->send(mMsg, aSendNow));
+  disableBreaking = false;
+
   kernel->kbp()->idle();
 
+  if (saveInDrafts || !aSendNow)
+      emit messageQueuedOrDrafted();
+
   if (sentOk)
   {
     mAutoDeleteMsg = FALSE;
+    mFolder = NULL;
     close();
   }
+  busy = false;
 }
 
 
@@ -1906,6 +1998,13 @@ void KMComposeWin::slotSendLater()
 }
 
 
+//----------------------------------------------------------------------------
+void KMComposeWin::slotSaveDraft()
+{
+  doSend(FALSE, TRUE);
+}
+
+
 //----------------------------------------------------------------------------
 void KMComposeWin::slotSendNow()
 {
@@ -1980,8 +2079,8 @@ void KMComposeWin::slotAppendSignature()
   if( !sigText.isEmpty() )
   {
     /* actually "\n-- \n" (note the space) is a convention for attaching
-    signatures and we should respect it: */
-    mEditor->insertLine("-- ", -1);
+    signatures and we should respect it, unless the user has already done so. */
+    if (!sigText.startsWith("-- \n")) mEditor->insertLine("-- ", -1);
     mEditor->insertLine(sigText, -1);
     mEditor->update();
     mEditor->setModified(mod);
@@ -2054,25 +2153,50 @@ void KMComposeWin::setEditCharset()
   QFont fnt=mSavedEditorFont;
   if (mCharset == "default" || mCharset.isEmpty())
     mCharset = defaultCharset();
-  //set font only if it is really available
-  if (KGlobal::charsets()->isAvailable(mCharset))
-  {
-    KGlobal::charsets()->setQFont(fnt, KGlobal::charsets()->nameToID(mCharset));
-    mEditor->setFont(fnt);
-  }
+  QString cset = mCharset;
+  if (mUnicodeFont) cset = "iso10646-1";
+  fnt.setCharSet(KGlobal::charsets()->charsetForEncoding(cset));
+  mEditor->setFont(fnt);
+  mEdtFrom.setFont(fnt);
+  mEdtReplyTo.setFont(fnt);
+  mEdtTo.setFont(fnt);
+  mEdtCc.setFont(fnt);
+  mEdtBcc.setFont(fnt);
+  mEdtSubject.setFont(fnt);
 }
 
 //-----------------------------------------------------------------------------
 const QString KMComposeWin::defaultCharset(void)
 {
+  // first try
+  QString retval = KGlobal::locale()->charset();
+  // however KGlobal::locale->charset() has a fallback value of iso-8859-1,
+  // we try to be smarter
   QString aStr = QTextCodec::codecForLocale()->name();
-  // codecForLocale returns ISO 8859-1, we need iso-8859-1
-  QString bStr = "";
-  QChar spaceChar(' ');
-  for (int i = 0; i < (int)aStr.length(); i++)
-     if (aStr[i] != spaceChar)
-       bStr += aStr[i].lower();
-  return KGlobal::charsets()->name(KGlobal::charsets()->nameToID(bStr));
+  if ((retval == "iso-8859-1") && (aStr != "ISO 8859-1"))
+  {
+    // read locale if it really gives iso-8859-1
+    KConfig *globalConfig = KGlobal::instance()->config();
+    if (globalConfig)
+    {
+      KConfigGroupSaver saver(globalConfig, QString::fromLatin1("Locale"));
+      retval = globalConfig->readEntry(QString::fromLatin1("Charset"));
+      if (retval.isNull())  //this means iso-8859-1 was a fallback, make your own guess
+      {
+        //we basicly use LANG envvar here
+        QString bStr = "";
+        QChar spaceChar(' ');
+        for (int i = 0; i < (int)aStr.length(); i++)
+           if (aStr[i] != spaceChar)
+             bStr += aStr[i].lower();
+         retval = KGlobal::charsets()->name(KGlobal::charsets()->nameToID(bStr));
+      }
+    }
+    //we should be pretty safe: still if sth goes wrong we return iso-8859-1
+  }
+  else if (retval == "jisx0208.1983-0") retval = "iso-2022-jp";
+  else if (retval == "ksc5601.1987-0") retval = "euc-kr";
+  return retval;
 }
 
 //-----------------------------------------------------------------------------
@@ -2109,6 +2233,8 @@ void KMComposeWin::slotIdentityActivated(int)
     mEdtFrom.setText(ident.fullEmailAddr());
   if(!ident.replyToAddr().isNull())
     mEdtReplyTo.setText(ident.replyToAddr());
+  else
+    mEdtReplyTo.setText("");
   if (ident.organization().isEmpty())
     mMsg->removeHeaderField("Organization");
   else
@@ -2121,8 +2247,9 @@ void KMComposeWin::slotIdentityActivated(int)
       (mOldSigText.isEmpty())) {
     if (pos >= 0)
       edtText.truncate(pos);
-    if (!ident.signature().isEmpty()) {
-      edtText.append( "\n-- \n" );
+    if (!ident.signature().isEmpty() && mAutoSign) {
+      edtText.append( "\n" );
+      if (!ident.signature().startsWith("-- \n")) edtText.append( "-- \n" );
       edtText.append( ident.signature() );
     }
     mEditor->setText( edtText );
@@ -2345,6 +2472,25 @@ void KMLineEdit::slotCompletion()
   cursorAtEnd();
 }
 
+//-----------------------------------------------------------------------------
+void KMLineEdit::dropEvent(QDropEvent *e)
+{
+  QStrList uriList;
+  if(QUriDrag::canDecode(e) && QUriDrag::decode( e, uriList ))
+  {
+    QString ct = text();
+    for (QStrListIterator it(uriList); it; ++it)
+    {
+      if (!ct.isEmpty()) ct.append(", ");
+      KURL u(*it);
+      if (u.protocol() == "mailto") ct.append(QString::fromUtf8(u.path()));
+      else ct.append(QString::fromUtf8(*it));
+    }
+    setText(ct);
+  }
+  else QLineEdit::dropEvent(e);
+}
+
 //-----------------------------------------------------------------------------
 void KMComposeWin::slotSpellcheckConfig()
 {
@@ -2353,7 +2499,7 @@ void KMComposeWin::slotSpellcheckConfig()
   QTabDialog qtd (this, "tabdialog", true);
   KSpellConfig mKSpellConfig (&qtd);
 
-  qtd.addTab (&mKSpellConfig, "Spellchecker");
+  qtd.addTab (&mKSpellConfig, i18n("Spellchecker"));
   qtd.setCancelButton ();
 
   kwin.setIcons (qtd.winId(), kapp->icon(), kapp->miniIcon());
@@ -2386,6 +2532,7 @@ void KMComposeWin::slotEditToolbars()
   if (dlg.exec() == true)
   {
     createGUI("kmcomposerui.rc");
+    toolbarAction->setChecked(!toolBar()->isHidden());
   }
 }
 
@@ -2414,6 +2561,8 @@ KMEdit::KMEdit(QWidget *parent, KMComposeWin* composer,
 #endif
 
   mKSpell = NULL;
+  mTempFile = NULL;
+  mExtEditorProcess = NULL;
 }
 
 
@@ -2460,38 +2609,36 @@ bool KMEdit::eventFilter(QObject*o, QEvent* e)
         return TRUE;
       }
 
+      if (mTempFile) return TRUE;
       QRegExp repFn("\\%f");
       QString sysLine = mExtEditor;
-      KTempFile tmpFile;
-      QString tmpName = tmpFile.name();
+      mTempFile = new KTempFile();
 
-      tmpFile.setAutoDelete(true);
+      mTempFile->setAutoDelete(true);
 
-      fprintf(tmpFile.fstream(), "%s", (const char *)text());
+      fprintf(mTempFile->fstream(), "%s", (const char *)text().local8Bit());
 
-      tmpFile.close();
+      mTempFile->close();
       // replace %f in the system line
-      sysLine.replace(repFn, tmpName);
-      system((const char *)sysLine);
+      sysLine.replace(repFn, mTempFile->name());
+      mExtEditorProcess = new KProcess();
+      sysLine += " ";
+      while (!sysLine.isEmpty())
+      {
+        *mExtEditorProcess << sysLine.left(sysLine.find(" ")).local8Bit();
+        sysLine.remove(0, sysLine.find(" ") + 1);
+      }
+      connect(mExtEditorProcess, SIGNAL(processExited(KProcess*)),
+              SLOT(slotExternalEditorDone(KProcess*)));
+      if (!mExtEditorProcess->start())
+      {
+        KMessageBox::error(NULL, i18n("Unable to start external editor."));
+        delete mExtEditorProcess;
+        delete mTempFile;
+        mExtEditorProcess = NULL;
+        mTempFile = NULL;
+      }
 
-      setAutoUpdate(false);
-      clear();
-
-      // read data back in from file
-      insertLine(kFileToString(tmpName, TRUE, FALSE), -1);
-//       QFile mailFile(tmpName);
-
-//       while (!mailFile.atEnd()) {
-//          QString oneLine;
-//          mailFile.readLine(oneLine, 1024);
-//          insertLine(oneLine, -1);
-//       }
-
-//       setModified(true);
-//       mailFile.close();
-
-      setAutoUpdate(true);
-      repaint();
       return TRUE;
     } else {
 #endif
@@ -2518,6 +2665,27 @@ bool KMEdit::eventFilter(QObject*o, QEvent* e)
   return FALSE;
 }
 
+
+//-----------------------------------------------------------------------------
+void KMEdit::slotExternalEditorDone(KProcess* proc)
+{
+  assert(proc == mExtEditorProcess);
+  setAutoUpdate(false);
+  clear();
+
+  // read data back in from file
+  insertLine(QString::fromLocal8Bit(kFileToString(mTempFile->name(),
+    TRUE, FALSE)), -1);
+
+  setAutoUpdate(true);
+  repaint();
+  delete proc;
+  delete mTempFile;
+  mTempFile = NULL;
+  mExtEditorProcess = NULL;
+}
+
+
 //-----------------------------------------------------------------------------
 void KMEdit::spellcheck()
 {
