@@ -15,9 +15,7 @@
 #include <qfont.h>
 #include <keditcl.h>
 #include <qlineedit.h>
-#include <ktempfile.h>
 #include <kio/job.h>
-#include <kurl.h>
 
 #include "kmmsgpart.h"
 #include "kmmsgbase.h"
@@ -32,25 +30,28 @@ class _StringPair {
 
 
 
-class QLineEdit;
+class QCloseEvent;
 class QComboBox;
-class QGridLayout;
 class QFrame;
-class QPopupMenu;
-class KEdit;
+class QGridLayout;
+class QLineEdit;
 class QListView;
 class QListViewItem;
-class KMMessage;
-class KDNDDropZone;
-class KToolBar;
-class KStatusBar;
+class QPopupMenu;
 class QPushButton;
-class QCloseEvent;
+class KDNDDropZone;
+class KEdit;
+class KMComposeWin;
+class KMMessage;
+class KProcess;
+class KSelectAction;
 class KSpell;
 class KSpellConfig;
-class KMComposeWin;
+class KStatusBar;
+class KTempFile;
+class KToolBar;
 class KToggleAction;
-class KSelectAction;
+class KURL;
 
 typedef QList<KMMessagePart> KMMsgPartList;
 
@@ -85,6 +86,7 @@ public slots:
   void slotSpellcheck2(KSpell*);
   void slotSpellResult(const QString &newtext);
   void slotSpellDone();
+  void slotExternalEditorDone(KProcess*);
 
 protected:
   /** Event filter that does Tab-key handling. */
@@ -93,10 +95,10 @@ protected:
   KMComposeWin* mComposer;
 private:
   KSpell *mKSpell;
-#ifndef KRN
-  bool extEditor;
-  QString mExtEditor;
-#endif
+  KTempFile *mTempFile;
+  KProcess  *mExtEditorProcess;
+  bool      extEditor;
+  QString   mExtEditor;
 };
 
 
@@ -128,6 +130,7 @@ public slots:
 
 protected:
   virtual bool eventFilter(QObject*, QEvent*);
+  virtual void dropEvent(QDropEvent *e);
   KMComposeWin* mComposer;
 protected:
 };
@@ -145,6 +148,9 @@ public:
   KMComposeWin(KMMessage* msg=NULL, QString id = "unknown" );
   ~KMComposeWin();
 
+  /** Add descriptions to the encodings in the list */
+  static void makeDescriptiveNames(QStringList &encodings);
+
   /** To catch palette changes */
   virtual bool event(QEvent *e);
 
@@ -175,12 +181,20 @@ public:
     the composer is closed and the message was not sent. Default: FALSE */
    inline void setAutoDelete(bool f) { mAutoDeleteMsg = f; }
 
+  /** If this folder is set, the original message is inserted back after
+    cancelling */
+   void setFolder(KMFolder* aFolder) { mFolder = aFolder; }
+
+  /** Recode to the specified charset */
+   void setCharset(const QString& aCharset, bool forceDefault = FALSE);
+
 public slots:
  //Actions:
   void slotPrint();
   void slotAttachFile();
   void slotSendNow();
   void slotSendLater();
+  void slotSaveDraft();
   void slotDropAction(QDropEvent *e);
   void slotNewComposer();
   void slotNewMailReader();
@@ -216,6 +230,9 @@ public slots:
   /** Switch the icon to lock or unlock respectivly. */
   void slotEncryptToggled(bool);
 
+  /** Switch wordWrap on/off */
+  void slotWordWrapToggled(bool);
+
   /** Append signature file to the end of the text in the editor. */
   void slotAppendSignature();
 
@@ -273,6 +290,10 @@ public slots:
   void slotAttachFileData(KIO::Job *, const QByteArray &);
   void slotAttachFileResult(KIO::Job *);
 
+signals:
+  /** A message has been queued or saved in the drafts folder */
+  void messageQueuedOrDrafted();
+
 protected:
   /** Install grid management and header fields. If fields exist that
     should not be there they are removed. Those that are needed are
@@ -311,7 +332,7 @@ protected:
   virtual bool queryExit ();
 
   /** Add an attachment to the list. */
-   void addAttach(const QString url);
+   void addAttach(const KURL url);
    void addAttach(const KMMessagePart* msgPart);
 
   /** Remove an attachment from the list. */
@@ -327,7 +348,7 @@ protected:
 
 private:
   /** Get message including signing and encrypting it */
-  const QString pgpProcessedMsg(void);
+  const QCString pgpProcessedMsg(void);
 
   /** Test if string has any 8-bit characters */
   bool is8Bit(const QString str);
@@ -336,7 +357,7 @@ private:
   void setEditCharset();
 
   /** Send the message */
-  void doSend(int sendNow=-1);
+  void doSend(int sendNow=-1, bool saveInDrafts = false);
 
   /** get default charset from locale settings */
   const QString defaultCharset(void);
@@ -364,6 +385,7 @@ protected:
   QList<QListViewItem> mAtmItemList;
   KMMsgPartList mAtmList;
   bool mAutoSign, mAutoPgpSign, mAutoDeleteMsg;
+  KMFolder *mFolder;
   long mShowHeaders;
   QString mDefEncoding;
 #ifndef KRN
@@ -371,6 +393,7 @@ protected:
   bool useExtEditor;
   QList<_StringPair> mCustHeaders;
   bool mConfirmSend;
+  bool disableBreaking;
 #endif
   int mNumHeaders;
   int mLineBreak;
@@ -390,6 +413,7 @@ protected:
   KToggleAction *replyToAction, *toAction, *ccAction, *bccAction, *subjectAction;
   KToggleAction *identityAction, *transportAction;
   KToggleAction *toolbarAction, *statusbarAction;
+  KToggleAction *wordWrapAction;
 
   KSelectAction *encodingAction;
 
@@ -406,6 +430,8 @@ private:
     bool insert;
   };
   QMap<KIO::Job *, atmLoadData> mapAtmLoadData;
+  bool mUnicodeFont;
+  bool mForceReplyCharset;
 };
 #endif
 
