@@ -3,6 +3,7 @@
 // -1 -> status unchanged, 0 -> success, 1 -> failure, 2-> critical failure
 
 #include "kmmessage.h"
+#include "kmmsgpart.h"
 #include "kmfilteraction.h"
 #include "kmfiltermgr.h"
 #include "kmfoldermgr.h"
@@ -10,7 +11,9 @@
 #include "kmglobal.h"
 #include "kmsender.h"
 #include "kmidentity.h"
+#include "kfileio.h"
 #include <kapp.h>
+#include <kstddirs.h>
 #include <kconfig.h>
 #include <qcombobox.h>
 #include <qlineedit.h>
@@ -272,14 +275,30 @@ void KMFilterActionExec::dummySigHandler(int)
 {
 }
 
-int KMFilterActionExec::process(KMMessage* /*aMsg*/, bool& /*stop*/)
+int KMFilterActionExec::process(KMMessage *aMsg, bool& /*stop*/)
 {
   void (*oldSigHandler)(int);
   int rc;
   if (mCmd.isEmpty()) return 1;
+  QString fullCmd = mCmd + " ";
+  QList<KTempFile> atmList;
+  KMMessagePart msgPart;
+  int i, nr;
+  while (fullCmd.contains("%"))
+  {
+    i = fullCmd.find("%") + 1;
+    nr = fullCmd.mid(i, fullCmd.find(" ", i) - i).toInt();
+    aMsg->bodyPart(nr, &msgPart);
+    KTempFile *atmTempFile = new KTempFile();
+    atmList.append( atmTempFile );
+    atmTempFile->setAutoDelete( true );
+    kByteArrayToFile(msgPart.bodyDecoded(), atmTempFile->name(), false, false,
+      false);
+    fullCmd = fullCmd.arg( atmTempFile->name() );
+  }
   oldSigHandler = signal(SIGALRM, &KMFilterActionExec::dummySigHandler);
   alarm(30);
-  rc = system(mCmd);
+  rc = system(fullCmd.left(fullCmd.length() - 1 ));
   alarm(0);
   signal(SIGALRM, oldSigHandler);
   if (rc & 255)
@@ -346,8 +365,8 @@ int KMFilterActionExtFilter::process(KMMessage* aMsg, bool& stop)
   char buf[8192];
   FILE *fh;
   bool ok = TRUE;
-  KTempFile inFile("/tmp/kmail-filter", "in");
-  KTempFile outFile("/tmp/kmail-filter", "out");
+  KTempFile inFile(locateLocal("tmp", "kmail-filter"), "in");
+  KTempFile outFile(locateLocal("tmp", "kmail-filter"), "out");
 
   if (mCmd.isEmpty()) return 1;
 
@@ -528,6 +547,70 @@ const QString KMFilterActionTransport::argsAsString(void) const
 }
 
 
+//=============================================================================
+// Set the Reply-to header in a message
+//=============================================================================
+class KMFilterActionReplyTo: public KMFilterAction
+{
+public:
+  KMFilterActionReplyTo();
+  virtual const QString label(void) const;
+  virtual int process(KMMessage* msg, bool& stopIt);
+  virtual QWidget* createParamWidget(KMGFilterDlg* parent);
+  virtual void applyParamWidgetValue(QWidget* paramWidget);
+  virtual void argsFromString(const QString argsStr);
+  virtual const QString argsAsString(void) const;
+  static KMFilterAction* newAction(void);
+protected:
+  QString mReplyTo;
+};
+
+KMFilterAction* KMFilterActionReplyTo::newAction(void)
+{
+  return (new KMFilterActionReplyTo);
+}
+
+const QString KMFilterActionReplyTo::label(void) const
+{
+  return i18n("set Reply-To");
+}
+
+KMFilterActionReplyTo::KMFilterActionReplyTo(): KMFilterAction("set Reply-To")
+{
+  mReplyTo = "";
+}
+
+int KMFilterActionReplyTo::process(KMMessage* msg, bool& )
+{
+  msg->setHeaderField( "Reply-To", mReplyTo );
+  return -1;
+}
+
+QWidget* KMFilterActionReplyTo::createParamWidget(KMGFilterDlg* aParent)
+{
+  QLineEdit* edt;
+  edt = aParent->createEdit(mReplyTo);
+  return edt;
+}
+
+void KMFilterActionReplyTo::applyParamWidgetValue(QWidget* aParamWidget)
+{
+  QLineEdit* w = (QLineEdit*)aParamWidget;
+  mReplyTo = w->text();
+}
+
+void KMFilterActionReplyTo::argsFromString(const QString argsStr)
+{
+  mReplyTo = argsStr;
+}
+
+const QString KMFilterActionReplyTo::argsAsString(void) const
+{
+  return mReplyTo;
+}
+
+
+
 //=============================================================================
 //
 //   Filter  Action  Dictionary
@@ -535,12 +618,14 @@ const QString KMFilterActionTransport::argsAsString(void) const
 //=============================================================================
 void KMFilterActionDict::init(void)
 {
+  insert("transfer", i18n("transfer"),
+	 KMFilterActionMove::newAction);
   insert("set identity", i18n("set identity"),
 	 KMFilterActionIdentity::newAction);
   insert("set transport", i18n("set transport"),
 	 KMFilterActionTransport::newAction);
-  insert("transfer", i18n("transfer"),
-	 KMFilterActionMove::newAction);
+  insert("set Reply-To", i18n("set Reply-To"),
+	 KMFilterActionReplyTo::newAction);
   insert("forward", i18n("forward to"),
          KMFilterActionForward::newAction);
   insert("execute", i18n("execute"),
