@@ -3,17 +3,16 @@
 #include "kmfoldernode.h"
 #include "kmfolderdir.h"
 
-static QString sEmpty("");
-
 //-----------------------------------------------------------------------------
-KMFolderNode::KMFolderNode(KMFolderDir* aParent, const char* aName):
-  KMFolderNodeInherited(aParent)
+KMFolderNode::KMFolderNode(KMFolderDir* aParent, const QString& aName)
+//: KMFolderNodeInherited(aParent)
 {
   initMetaObject();
 
   mType = "node";
   mName = aName;
-  mName.detach();
+  mParent = aParent;
+  
   setName(mName);
 }
 
@@ -46,17 +45,28 @@ bool KMFolderNode::isDir(void) const
 
 
 //-----------------------------------------------------------------------------
-const QString& KMFolderNode::path(void) const
+const QString KMFolderNode::path() const
 {
   if (parent()) return parent()->path();
-  return sEmpty;
+  return 0;
 }
 
-
 //-----------------------------------------------------------------------------
 const QString KMFolderNode::label(void) const
 {
   return name();
 }
 
+//-----------------------------------------------------------------------------
+KMFolderDir* KMFolderNode::parent(void) const
+{
+  return mParent;
+}
+
+//-----------------------------------------------------------------------------
+void KMFolderNode::setParent( KMFolderDir* aParent )
+{
+  mParent = aParent;
+}
+
 #include "kmfoldernode.moc"
