@@ -54,7 +54,7 @@ struct KMPaintInfo {
 class KMHeaders : public QListView
 {
   Q_OBJECT
-    friend KMHeaderItem; // For easy access to the pixmaps
+    friend class KMHeaderItem; // For easy access to the pixmaps
 
 public:
   KMHeaders(KMMainWin *owner, QWidget *parent=0, const char *name=0);
@@ -87,6 +87,7 @@ public:
   virtual void replyToMsg();
   virtual void redirectMsg();
   virtual void replyAllToMsg();
+  virtual void replyListToMsg();
   virtual void resendMsg();
 
   /** If destination==NULL the messages are deleted, otherwise
@@ -178,6 +179,8 @@ public slots:
   void nextUnreadMessage();
   // Make the previous message header visible scrolling if necessary
   void prevUnreadMessage();
+  // Don't show a drag cursor
+  void slotNoDrag();
  
 protected:
   static QPixmap *pixNew, *pixUns, *pixDel, *pixOld, *pixRep, *pixSent, 
