@@ -39,11 +39,12 @@
 #include <kedittoolbar.h>
 #include <kkeydialog.h>
 #include <kcharsets.h>
+#include <kmimetype.h>
+#include <knotifyclient.h>
 
 #include "configuredialog.h"
 #include "kmbroadcaststatus.h"
 #include "kmfoldermgr.h"
-#include "kmsettings.h"
 #include "kmfolderdia.h"
 #include "kmaccount.h"
 #include "kmacctmgr.h"
@@ -102,7 +103,8 @@ KMMainWin::KMMainWin(QWidget *, char *name) :
   readConfig();
   activatePanners();
 
-  idx = mFolderTree->indexOfFolder(kernel->inboxFolder());
+  if (kernel->firstStart()) idx = mFolderTree->firstChild(); else
+    idx = mFolderTree->indexOfFolder(kernel->inboxFolder());
   if (idx!=0) {
     mFolderTree->setCurrentItem(idx);
     mFolderTree->setSelected(idx,TRUE);
@@ -124,7 +126,7 @@ KMMainWin::KMMainWin(QWidget *, char *name) :
 KMMainWin::~KMMainWin()
 {
   if (searchWin)
-    delete searchWin;
+    searchWin->close();
   writeConfig();
   writeFolderConfig();
 
@@ -239,6 +241,7 @@ void KMMainWin::readConfig(void)
   mBoxOnNew = config->readBoolEntry("msgbox-on-mail", false);
   mExecOnNew = config->readBoolEntry("exec-on-mail", false);
   mNewMailCmd = config->readEntry("exec-on-mail-cmd", "");
+  mConfirmEmpty = config->readBoolEntry("confirm-before-empty", true);
 
   // Re-activate panners
   if (mStartupDone)
@@ -341,8 +344,13 @@ void KMMainWin::createWidgets(void)
   accel->connectItem(accel->insertItem(Key_Right),
 		     mHeaders, SLOT(nextMessage()));
 
-  QString charset("iso8859-1");
-  mCodec = KGlobal::charsets()->codecForName(charset);
+  if (!mEncodingStr.isEmpty())
+    if (mEncodingStr != i18n("Auto"))
+      mCodec = KMMsgBase::codecForName(mEncodingStr);
+    else
+      mCodec = 0;
+  else
+    mCodec = KGlobal::charsets()->codecForName("iso8859-1");
 
   // create HTML reader widget
   mMsgView = new KMReaderWin(pnrMsgView);
@@ -356,6 +364,8 @@ void KMMainWin::createWidgets(void)
 	  this, SLOT(slotAtmMsg(KMMessage *)));
   connect(mHeaders, SIGNAL(maybeDeleting()),
 	  mMsgView, SLOT(clearCache()));
+  connect(mMsgView, SIGNAL(noDrag()),
+          mHeaders, SLOT(slotNoDrag()));
   accel->connectItem(accel->insertItem(Key_Up),
 		     mMsgView, SLOT(slotScrollUp()));
   accel->connectItem(accel->insertItem(Key_Down),
@@ -379,6 +389,16 @@ void KMMainWin::createWidgets(void)
 	  this, SLOT(slotMoveMsgToFolder(KMFolder*)));
   connect(mFolderTree, SIGNAL(folderDropCopy(KMFolder*)),
           this, SLOT(slotCopyMsgToFolder(KMFolder*)));
+  accel->connectItem(accel->insertItem(CTRL+Key_Plus),
+		     mFolderTree, SLOT(nextUnreadFolder()));
+  accel->connectItem(accel->insertItem(CTRL+Key_Minus),
+		     mFolderTree, SLOT(prevUnreadFolder()));
+  accel->connectItem(accel->insertItem(CTRL+Key_Right),
+		     mFolderTree, SLOT(incCurrentFolder()));
+  accel->connectItem(accel->insertItem(CTRL+Key_Left),
+		     mFolderTree, SLOT(decCurrentFolder()));
+  accel->connectItem(accel->insertItem(CTRL+Key_Space),
+		     mFolderTree, SLOT(selectCurrentFolder()));
 }
 
 
@@ -418,11 +438,11 @@ void KMMainWin::activatePanners(void)
 //-----------------------------------------------------------------------------
 void KMMainWin::slotSetEncoding()
 {
-     mEncodingStr = mEncoding->currentText();
+    mEncodingStr = KGlobal::charsets()->encodingForName(mEncoding->currentText());
      if (mEncoding->currentItem() == 0) // Auto
        mCodec = 0;
      else
-       mCodec = KGlobal::charsets()->codecForName( mEncodingStr );
+       mCodec = KMMsgBase::codecForName( mEncodingStr );
      mMsgView->setCodec(mCodec);
      return;
 }
@@ -469,7 +489,10 @@ void KMMainWin::slotSearch()
   if(!searchWin) {
     QString curFolder = "";
     if( mFolder )
-      curFolder = mFolder->name();
+    {
+      if ( mFolder->isSystemFolder() ) curFolder = i18n(mFolder->name());
+      else curFolder = mFolder->name();
+    }
     searchWin = new KMFldSearch(this, "Search", curFolder, false);
     connect(searchWin, SIGNAL(destroyed()),
 	    this, SLOT(slotSearchClosed()));
@@ -607,7 +630,7 @@ void KMMainWin::slotMailChecked(bool newMail) {
     return;
 
   if (mBeepOnNew) {
-    KApplication::beep();
+    KNotifyClient::beep();
   }
 
   // FIXME: change system() to a KProcess
@@ -656,6 +679,7 @@ void KMMainWin::slotModifyFolder()
     if (qlvi) {
       qlvi->setOpen(TRUE);
       mFolderTree->setCurrentItem( qlvi );
+      mHeaders->msgChanged();
     }
   }
 }
@@ -669,6 +693,15 @@ void KMMainWin::slotEmptyFolder()
 
   if (!mFolder) return;
 
+  if (mConfirmEmpty)
+  {
+    str = i18n("Are you sure you want to empty the folder \"%1\"?").arg(mFolder->label());
+
+    if (KMessageBox::warningContinueCancel(this, str,
+                                          i18n("Empty folder"), i18n("&Empty") )
+       !=KMessageBox::Continue) return;
+  }
+
   mMsgView->clearCache();
 
   kernel->kbp()->busy();
@@ -789,6 +822,26 @@ void KMMainWin::slotReplyAllToMsg()
 }
 
 
+//-----------------------------------------------------------------------------
+void KMMainWin::slotReplyListToMsg()
+{
+  mHeaders->replyListToMsg();
+}
+
+
+//-----------------------------------------------------------------------------
+void KMMainWin::slotPostToList()
+{
+  if (!mFolder || !mFolder->isMailingList()) return;
+
+  KMMessage *msg = new KMMessage;
+  msg->initHeader();
+  msg->setTo(mFolder->mailingListPostAddress());
+  KMComposeWin *win = new KMComposeWin(msg);
+  win->show();
+}
+
+
 //-----------------------------------------------------------------------------
 void KMMainWin::slotForwardMsg()
 {
@@ -810,27 +863,40 @@ void KMMainWin::slotBounceMsg()
 }
 
 
+//-----------------------------------------------------------------------------
+void KMMainWin::slotMessageQueuedOrDrafted()
+{
+  if((mFolder != kernel->outboxFolder()) && (mFolder != kernel->draftsFolder()))
+      return;
+  mMsgView->update(true);
+}
+
 //-----------------------------------------------------------------------------
 void KMMainWin::slotEditMsg()
 {
   KMMessage *msg;
   int aIdx;
 
-  if(mFolder != kernel->outboxFolder())
+  if((mFolder != kernel->outboxFolder()) && (mFolder != kernel->draftsFolder()))
   {
       KMessageBox::sorry(0,
-         i18n("Sorry, only messages in the outbox folder can be edited."));
+         i18n("Sorry, only messages in the outbox folder and drafts folder can be edited."));
       return;
   }
 
-
   if((aIdx = mHeaders->currentItemIndex()) <= -1)
     return;
   if(!(msg = mHeaders->getMsg(aIdx)))
     return;
+  mFolder->removeMsg(msg);
+  mHeaders->setSelected(mHeaders->currentItem(), TRUE);
+  mHeaders->highlightMessage(mHeaders->currentItem());
 
   KMComposeWin *win = new KMComposeWin;
+  QObject::connect( win, SIGNAL( messageQueuedOrDrafted()),
+		    this, SLOT( slotMessageQueuedOrDrafted()) );
   win->setMsg(msg,FALSE);
+  win->setFolder(mFolder);
   win->show();
 }
 
@@ -859,7 +925,17 @@ void KMMainWin::slotUndo()
 void KMMainWin::slotShowMsgSrc()
 {
   KMMessage* msg = mHeaders->getMsg(-1);
-  if (msg) msg->viewSource(i18n("Message as Plain Text"),mCodec);
+  if (msg)
+  {
+    QTextCodec *codec = mCodec;
+    if (!codec) //this is Auto setting
+    {
+       QString cset = msg->charset();
+       if (!cset.isEmpty())
+         codec = KMMsgBase::codecForName(cset);
+    }
+    msg->viewSource(i18n("Message as Plain Text"), codec);
+  }
 }
 
 
@@ -962,10 +1038,22 @@ void KMMainWin::slotSetHeaderStyle(int id)
 //-----------------------------------------------------------------------------
 void KMMainWin::folderSelected(KMFolder* aFolder)
 {
-  if (mFolder == aFolder)
+  if (mFolder == aFolder && aFolder)
     return;
 
   kernel->kbp()->busy();
+  if (!aFolder)
+  {
+    mMsgView->setMsg(0,TRUE);
+    if (mLongFolderList) mHeaders->hide();
+    mMsgView->displayAboutPage();
+  }
+  else if (!mFolder)
+  {
+    mMsgView->enableMsgDisplay();
+    mMsgView->setMsg(0,TRUE);
+    mHeaders->show();
+  }
   writeFolderConfig();
   mFolder = (KMFolder*)aFolder;
   readFolderConfig();
@@ -999,10 +1087,41 @@ void KMMainWin::slotSelectMessage(KMMessage* msg)
   }
 }
 
+
 //-----------------------------------------------------------------------------
-void KMMainWin::slotSetMsgStatus(int id)
+void KMMainWin::slotSetMsgStatusNew()
 {
-  mHeaders->setMsgStatus((KMMsgStatus)id);
+  mHeaders->setMsgStatus(KMMsgStatusNew);
+}
+
+//-----------------------------------------------------------------------------
+void KMMainWin::slotSetMsgStatusUnread()
+{
+  mHeaders->setMsgStatus(KMMsgStatusUnread);
+}
+
+//-----------------------------------------------------------------------------
+void KMMainWin::slotSetMsgStatusRead()
+{
+  mHeaders->setMsgStatus(KMMsgStatusRead);
+}
+
+//-----------------------------------------------------------------------------
+void KMMainWin::slotSetMsgStatusReplied()
+{
+  mHeaders->setMsgStatus(KMMsgStatusReplied);
+}
+
+//-----------------------------------------------------------------------------
+void KMMainWin::slotSetMsgStatusQueued()
+{
+  mHeaders->setMsgStatus(KMMsgStatusQueued);
+}
+
+//-----------------------------------------------------------------------------
+void KMMainWin::slotSetMsgStatusSent()
+{
+  mHeaders->setMsgStatus(KMMsgStatusSent);
 }
 
 
@@ -1014,7 +1133,10 @@ void KMMainWin::slotMsgActivated(KMMessage *msg)
   assert(msg != NULL);
 
   win = new KMReaderWin;
-  showMsg(win, msg);
+  win->setAutoDelete(true);
+  KMMessage *newMessage = new KMMessage();
+  newMessage->fromString(msg->asString());
+  showMsg(win, newMessage);
 }
 
 
@@ -1024,8 +1146,6 @@ void KMMainWin::slotAtmMsg(KMMessage *msg)
   KMReaderWin *win;
   assert(msg != NULL);
   win = new KMReaderWin;
-  connect(win, SIGNAL(showAtmMsg(KMMessage *)),
-	  this, SLOT(slotAtmMsg(KMMessage *)));
   win->setAutoDelete(true); //delete on end
   showMsg(win, msg);
 }
@@ -1034,6 +1154,7 @@ void KMMainWin::slotAtmMsg(KMMessage *msg)
 void KMMainWin::showMsg(KMReaderWin *win, KMMessage *msg)
 {
   KWin::setIcons(win->winId(), kapp->icon(), kapp->miniIcon());
+  win->setCodec(mCodec);
   win->setMsg(msg, true); // hack to work around strange QTimer bug
   win->resize(550,600);
 
@@ -1043,6 +1164,8 @@ void KMMainWin::showMsg(KMReaderWin *win, KMMessage *msg)
           this, SLOT(slotMsgPopup(const KURL&,const QPoint&)));
   connect(win, SIGNAL(urlClicked(const KURL&,int)),
           this, SLOT(slotUrlClicked(const KURL&,int)));
+  connect(win, SIGNAL(showAtmMsg(KMMessage *)),
+	  this, SLOT(slotAtmMsg(KMMessage *)));
 
   QAccel *accel = new QAccel(win);
   accel->connectItem(accel->insertItem(Key_Up),
@@ -1108,9 +1231,18 @@ void KMMainWin::slotUrlClicked(const KURL &aUrl, int)
     win->show();
   }
   else if ((aUrl.protocol() == "http") || (aUrl.protocol() == "https") ||
-	   (aUrl.protocol() ==  "ftp") || (aUrl.protocol() == "file"))
+	   (aUrl.protocol() ==  "ftp") || (aUrl.protocol() == "file") ||
+           (aUrl.protocol() == "help"))
   {
     statusMsg(i18n("Opening URL..."));
+    KMimeType::Ptr mime = KMimeType::findByURL( aUrl );
+    if (mime->name() == "application/x-desktop" ||
+        mime->name() == "application/x-executable" ||
+        mime->name() == "application/x-shellscript" )
+    {
+      if (KMessageBox::warningYesNo( 0, i18n( "Do you really want to execute"
+        " '%1' ? " ).arg( aUrl.prettyURL() ) ) != KMessageBox::Yes) return;
+    }
     // -- David : replacement for KFM::openURL
     if ( !KOpenWithHandler::exists() )
       (void) new KFileOpenWithHandler();
@@ -1137,13 +1269,14 @@ void KMMainWin::slotMailtoCompose()
 void KMMainWin::slotMailtoReply()
 {
   KMComposeWin *win;
-  KMMessage *msg;
+  KMMessage *msg, *rmsg;
 
   if (!(msg = mHeaders->getMsg(-1))) return;
-  msg = msg->createReply(FALSE);
-  msg->setTo(mUrlCurrent.path());
+  rmsg = msg->createReply(FALSE);
+  rmsg->setTo(mUrlCurrent.path());
 
-  win = new KMComposeWin(msg);
+  win = new KMComposeWin(rmsg);
+  win->setCharset(msg->codec()->name(), TRUE);
   win->show();
 }
 
@@ -1152,13 +1285,14 @@ void KMMainWin::slotMailtoReply()
 void KMMainWin::slotMailtoForward()
 {
   KMComposeWin *win;
-  KMMessage *msg;
+  KMMessage *msg, *fmsg;
 
   if (!(msg = mHeaders->getMsg(-1))) return;
-  msg = msg->createForward();
-  msg->setTo(mUrlCurrent.path());
+  fmsg = msg->createForward();
+  fmsg->setTo(mUrlCurrent.path());
 
-  win = new KMComposeWin(msg);
+  win = new KMComposeWin(fmsg);
+  win->setCharset(msg->codec()->name(), TRUE);
   win->show();
 }
 
@@ -1243,7 +1377,7 @@ void KMMainWin::slotMsgPopup(const KURL &aUrl, const QPoint& aPoint)
     menu->insertItem(i18n("&Move..."), this,
                      SLOT(slotMoveMsg()), Key_M);
     menu->insertItem(i18n("&Copy..."), this,
-                     SLOT(slotCopyMsg()), Key_C); 
+                     SLOT(slotCopyMsg()), Key_C);
     menu->insertSeparator();
     deleteAction->plug(menu);
     menu->popup(aPoint, 0);
@@ -1287,10 +1421,15 @@ void KMMainWin::setupMenuBar()
 		      actionCollection(), "check_mail" );
 
   KActionMenu *actActionMenu = new
-    KActionMenu( i18n("Check Mail in"), actionCollection(), "check_mail_in" );
+    KActionMenu( i18n("Check Mail in"), "mail_get", actionCollection(),
+				   	"check_mail_in" );
+  actActionMenu->setDelayed(true); //needed for checking "all accounts"
 
+  connect(actActionMenu,SIGNAL(activated()),this,SLOT(slotCheckMail()));
+  
   actMenu = actActionMenu->popupMenu();
   connect(actMenu,SIGNAL(activated(int)),this,SLOT(slotCheckOneAccount(int)));
+  connect(actMenu,SIGNAL(aboutToShow()),this,SLOT(getAccountMenu()));
 
   (void) new KAction( i18n("&Send Queued"), 0, this,
 		      SLOT(slotSendQueued()), actionCollection(), "send_queued");
@@ -1332,7 +1471,7 @@ void KMMainWin::setupMenuBar()
   (void) new KAction( i18n("&Empty"), 0, this,
 		      SLOT(slotEmptyFolder()), actionCollection(), "empty" );
 
-  removeFolderAction = new KAction( i18n("&Remove..."), 0, this,
+  removeFolderAction = new KAction( i18n("&Remove"), 0, this,
 		      SLOT(slotRemoveFolder()), actionCollection(), "remove" );
 
   preferHtmlAction = new KToggleAction( i18n("Prefer HTML to plain text"), 0, this,
@@ -1363,6 +1502,9 @@ void KMMainWin::setupMenuBar()
   replyAllAction = new KAction( i18n("Reply &All..."), "mail_replyall",
      Key_A, this, SLOT(slotReplyAllToMsg()), actionCollection(), "reply_all" );
 
+  replyListAction = new KAction( i18n("Reply &List..."),
+     Key_L, this, SLOT(slotReplyListToMsg()), actionCollection(), "reply_list" );
+
   forwardAction = new KAction( i18n("&Forward..."), "mail_forward", Key_F, this,
 		      SLOT(slotForwardMsg()), actionCollection(), "forward" );
 
@@ -1376,28 +1518,37 @@ void KMMainWin::setupMenuBar()
 		      SLOT(slotResendMsg()), actionCollection(), "send_again" );
 
   //----- Message-Encoding Submenu
-  mEncoding = new KSelectAction( i18n( "Set &Encoding.." ), 0, this, SLOT( slotSetEncoding() ), actionCollection(), "encoding" );
-  QStringList encodings = KGlobal::charsets()->availableEncodingNames();
+  mEncoding = new KSelectAction( i18n( "Set &Encoding" ), 0, this, SLOT( slotSetEncoding() ), actionCollection(), "encoding" );
+  QStringList encodings = KGlobal::charsets()->descriptiveEncodingNames();
   encodings.prepend( i18n( "Auto" ) );
   mEncoding->setItems( encodings );
   mEncoding->setCurrentItem(0);
-  if (encodings.findIndex( mEncodingStr ) != -1)
-      mEncoding->setCurrentItem(encodings.findIndex( mEncodingStr ));
+  QStringList::Iterator it;
+  int i = 0;
+  for( it = encodings.begin(); it != encodings.end(); ++it) {
+      if ( (*it).contains( mEncodingStr ) ) {
+	  mEncoding->setCurrentItem( i );
+	  break;
+      }
+      i++;
+  }
 
-  (void) new KAction( i18n("Edi&t..."), Key_T, this,
+  editAction = new KAction( i18n("Edi&t..."), Key_T, this,
 		      SLOT(slotEditMsg()), actionCollection(), "edit" );
 
-  KActionMenu *setStatusAction = new KActionMenu( i18n("Set status" ),
-					     actionCollection(), "set_status" );
-  QPopupMenu *msgStatusMenu = setStatusAction->popupMenu();
-  connect(msgStatusMenu, SIGNAL(activated(int)), this,
-	  SLOT(slotSetMsgStatus(int)));
-  msgStatusMenu->insertItem(i18n("New"), (int)KMMsgStatusNew);
-  msgStatusMenu->insertItem(i18n("Unread"), (int)KMMsgStatusUnread);
-  msgStatusMenu->insertItem(i18n("Read"), (int)KMMsgStatusOld);
-  msgStatusMenu->insertItem(i18n("Replied"), (int)KMMsgStatusReplied);
-  msgStatusMenu->insertItem(i18n("Queued"), (int)KMMsgStatusQueued);
-  msgStatusMenu->insertItem(i18n("Sent"), (int)KMMsgStatusSent);
+  //----- Set status submenu
+  newAction= new KAction( i18n("New"), 0, this,
+    SLOT(slotSetMsgStatusNew()), actionCollection(), "status_new");
+  unreadAction=new KAction( i18n("Unread"), 0, this,
+    SLOT(slotSetMsgStatusUnread()), actionCollection(), "status_unread");
+  readAction=new KAction( i18n("Read"), 0, this,
+    SLOT(slotSetMsgStatusRead()), actionCollection(), "status_read");
+  repliedAction= new KAction( i18n("Replied"), 0, this,
+    SLOT(slotSetMsgStatusReplied()), actionCollection(), "status_replied");
+  queueAction=new KAction( i18n("Queued"), 0, this,
+    SLOT(slotSetMsgStatusQueued()), actionCollection(), "status_queued");
+  sentAction=new KAction( i18n("Sent"), 0, this,
+    SLOT(slotSetMsgStatusSent()), actionCollection(), "status_sent");
 
   KActionMenu *moveActionMenu = new KActionMenu( i18n("&Move to" ),
 					     actionCollection(), "move_to" );
@@ -1453,9 +1604,6 @@ void KMMainWin::setupMenuBar()
 
   createGUI( "kmmainwin.rc", false );
 
-  QObject::connect( guiFactory()->container("file", this),
-		    SIGNAL( aboutToShow() ), this, SLOT( getAccountMenu() ));
-
   QObject::connect( guiFactory()->container("folder", this),
 		    SIGNAL( aboutToShow() ), this, SLOT( updateFolderMenu() ));
 
@@ -1491,6 +1639,7 @@ void KMMainWin::slotEditToolbars()
   if (dlg.exec() == true)
   {
     createGUI("kmmainwin.rc");
+    toolbarAction->setChecked(!toolBar()->isHidden());
   }
 }
 
@@ -1575,7 +1724,9 @@ QPopupMenu* KMMainWin::folderToPopupMenu(KMFolderDir* aFolderDir,
     if (!folderNode->isDir()) {
       folder = static_cast<KMFolder*>(folderNode);
 
-      int menuId = menu->insertItem(folder->label());
+      QString label(folder->label());
+      label.replace(QRegExp("&"),QString("&&"));
+      int menuId = menu->insertItem(label);
       aMenuToFolder->insert( menuId, folder );
 
       KMFolderDir *child = folder->child();
