@@ -48,10 +48,10 @@
 static DwString emptyString("");
 
 // Values that are set from the config file with KMMessage::readConfig()
-static QString sReplyStr, sReplyAllStr, sIndentPrefixStr;
-static bool sSmartQuote, sReplaceSubjPrefix;
+static QString sReplyLanguage, sReplyStr, sReplyAllStr, sIndentPrefixStr;
+static bool sSmartQuote, sReplaceSubjPrefix, sReplaceForwSubjPrefix;
 static int sWrapCol;
-static QStringList sReplySubjPrefixes;
+static QStringList sReplySubjPrefixes, sForwardSubjPrefixes;
 
 QString KMMessage::sForwardStr = "";
 int KMMessage::sHdrStyle = KMReaderWin::HdrFancy;
@@ -62,7 +62,8 @@ int KMMessage::sHdrStyle = KMReaderWin::HdrFancy;
 KMMessage::KMMessage(DwMessage* aMsg)
 {
     mNeedsAssembly = TRUE;
-    mMsg=aMsg;
+    mMsg = aMsg;
+    mCodec = NULL;
 }
 
 //-----------------------------------------------------------------------------
@@ -70,11 +71,11 @@ const QString KMMessage::followup(void) const
 {
   DwHeaders& header = mMsg->Headers();
   if (header.HasFollowupTo())
-    return decodeRFC1522String(header.FollowupTo().AsString().c_str());
+    return decodeRFC2047String(header.FollowupTo().AsString().c_str());
   else
   {
     if (header.HasNewsgroups())
-      return decodeRFC1522String(header.Newsgroups().AsString().c_str());
+      return decodeRFC2047String(header.Newsgroups().AsString().c_str());
     else return "";
   }
 }
@@ -173,6 +174,7 @@ KMMessage::KMMessage(KMFolder* parent): KMMessageInherited(parent)
 {
   mNeedsAssembly = FALSE;
   mMsg = new DwMessage;
+  mCodec = NULL;
 }
 
 
@@ -181,6 +183,7 @@ KMMessage::KMMessage(const KMMsgInfo& msgInfo): KMMessageInherited()
 {
   mNeedsAssembly = FALSE;
   mMsg = new DwMessage;
+  mCodec = NULL;
 
   assign(&msgInfo);
 }
@@ -252,7 +255,11 @@ void KMMessage::fromString(const QString& aStr, bool aSetStatus)
   resultPos = (char*)result.data();
   if (strPos) for (; (ch=*strPos)!='\0'; strPos++)
   {
-    if (ch>=' ' || ch=='\t' || ch=='\n' || ch<='\0')
+//  Mail header charset(iso-2022-jp) is using all most E-mail system in Japan.
+//  ISO-2022-JP code consists of ESC(0x1b) character and 7Bit character which
+//  used from '!' character to  '~' character.  toyo
+    if ((ch>=' ' || ch=='\t' || ch=='\n' || ch<='\0' || ch == 0x1b)
+       && !(ch=='>' && aStr.mid(strPos-aStr.data()-1,6)=="\n>From"))
       *resultPos++ = ch;
   }
   *resultPos = '\0'; // terminate zero for casting
@@ -264,6 +271,25 @@ void KMMessage::fromString(const QString& aStr, bool aSetStatus)
 
   mNeedsAssembly = FALSE;
   KMMessageInherited::setDate(date());
+
+  // Convert messages with a binary body into a message with attachment.
+  QString ct = QString(mMsg->Headers().ContentType().TypeStr().c_str()).lower();
+  if (ct.isEmpty() || ct == "text" || ct == "message" || ct == "multipart")
+    return;
+  KMMessagePart textPart;
+  textPart.setTypeStr("text");
+  textPart.setSubtypeStr("plain");
+  textPart.setBody("\n");
+  KMMessagePart bodyPart;
+  bodyPart.setTypeStr(ct);
+  bodyPart.setSubtypeStr(subtypeStr());
+  bodyPart.setContentDisposition(headerField("Content-Disposition"));
+  bodyPart.setCteStr(contentTransferEncodingStr());
+  bodyPart.setContentDisposition(headerField("Content-Disposition"));
+  bodyPart.setBodyEncodedBinary(bodyDecodedBinary());
+  addBodyPart(&textPart);
+  addBodyPart(&bodyPart);
+  mNeedsAssembly = FALSE;
 }
 
 
@@ -281,6 +307,7 @@ const QString KMMessage::formatString(const QString& aStr) const
     ch = aStr[i++];
     if (ch == '%') {
       ch = aStr[i++];
+      QString langSave = KGlobal::locale()->language();
       switch ((char)ch) {
       case 'D':
 	/* I'm not too sure about this change. Is it not possible
@@ -288,9 +315,11 @@ const QString KMMessage::formatString(const QString& aStr) const
 	   like this change to a short XX/XX/YY date format.
 	   At least not for the default. -sanders */
         {
-        QDateTime datetime;
-	datetime.setTime_t(date());
-        result += KGlobal::locale()->formatDateTime(datetime, false);
+          QDateTime datetime;
+          datetime.setTime_t(date());
+          KLocale locale("kmail");
+          locale.setLanguage(sReplyLanguage);
+          result += locale.formatDateTime(datetime, false);
         }
         break;
       case 'F':
@@ -567,6 +596,7 @@ const QCString KMMessage::asQuotedString(const QString& aHeaderStr,
                                         bool aStripSignature) const
 {
   QString result;
+  QCString cStr;
   QString headerStr;
   KMMessagePart msgPart;
   QRegExp reNL("\\n");
@@ -574,12 +604,14 @@ const QCString KMMessage::asQuotedString(const QString& aHeaderStr,
   bool isInline;
   int i;
 
-  QString cset = charset();
-  QTextCodec* codec;
-  if (!cset.isEmpty() && !cset.isNull())
-    codec = KGlobal::charsets()->codecForName(charset());
-  else
-    codec = QTextCodec::codecForLocale();
+  QTextCodec *codec = mCodec;
+  if (!codec)
+  {
+    QString cset = charset();
+    if (!cset.isEmpty())
+      codec = KMMsgBase::codecForName(cset);
+    if (!codec) codec = QTextCodec::codecForLocale();
+  }
 
   indentStr = formatString(aIndentStr);
   headerStr = formatString(aHeaderStr);
@@ -590,14 +622,19 @@ const QCString KMMessage::asQuotedString(const QString& aHeaderStr,
   if (numBodyParts() == 0) {
     Kpgp* pgp = Kpgp::getKpgp();
     assert(pgp != NULL);
-    result = codec->toUnicode(bodyDecoded());
+    cStr = bodyDecoded();
 
-    pgp->setMessage(result);
+    pgp->setMessage(cStr);
     if(pgp->isEncrypted()) {
       pgp->decrypt();
-      result = pgp->message().stripWhiteSpace();
+      result = codec->toUnicode(pgp->message());
     } else
-      result = result.stripWhiteSpace();
+      result = codec->toUnicode(cStr);
+
+    // Remove blank lines at the beginning
+    for( i = 0; i < (int)result.length() && result[i] <= ' '; i++ );
+    while (i > 0 && result[i-1] == ' ') i--;
+    result.remove(0,i);
 
     result.replace(reNL, '\n' + indentStr);
     result = indentStr + result + '\n';
@@ -612,20 +649,17 @@ const QCString KMMessage::asQuotedString(const QString& aHeaderStr,
       if (i==0)
         isInline = TRUE;
       else
-        isInline = (stricmp(msgPart.contentDisposition(), "inline") == 0);
+        isInline = (qstricmp(msgPart.contentDisposition(), "inline") == 0);
 
       if (isInline) {
-        if (stricmp(msgPart.typeStr(),"text") == 0 ||
-            stricmp(msgPart.typeStr(),"message") == 0) {
-          result += '\n';
-          result += indentStr;
+        if (qstricmp(msgPart.typeStr(),"text") == 0) {
           Kpgp* pgp = Kpgp::getKpgp();
           assert(pgp != NULL);
           QString part;
-          if ((pgp->setMessage(codec->toUnicode(msgPart.bodyDecoded()))) &&
+          if ((pgp->setMessage(msgPart.bodyDecoded())) &&
               (pgp->isEncrypted()) &&
               (pgp->decrypt())) {
-            part = pgp->message();
+            part = codec->toUnicode(pgp->message());
           } else {
             part = codec->toUnicode(msgPart.bodyDecoded());
             //	    debug ("part\n" + part ); inexplicably crashes -sanders
@@ -635,6 +669,16 @@ const QCString KMMessage::asQuotedString(const QString& aHeaderStr,
           if (sSmartQuote)
             smartQuote(part, '\n' + indentStr, sWrapCol, aStripSignature);
           result += part;
+        } else
+        if (qstricmp(msgPart.typeStr(),"message") == 0) {
+          KMMessage inlineMsg;
+          inlineMsg.fromString(msgPart.bodyDecoded());
+          QString inlineHeaderStr = inlineMsg.headerAsString();
+          inlineHeaderStr.replace(reNL, '\n' + indentStr);
+          result += "\n" + indentStr;
+          result += inlineHeaderStr;
+          result += QString::fromUtf8(inlineMsg.asQuotedString("", indentStr,
+            TRUE, FALSE));
         } else
           isInline = FALSE;
       }
@@ -655,14 +699,14 @@ const QCString KMMessage::asQuotedString(const QString& aHeaderStr,
     }
   }
 
-  QCString c = codec->fromUnicode(headerStr + "\n" + result);
+  QCString c = QString(headerStr + "\n" + result).utf8();
 
   return c;
 }
 
 
 //-----------------------------------------------------------------------------
-KMMessage* KMMessage::createReply(bool replyToAll)
+KMMessage* KMMessage::createReply(bool replyToAll, bool replyToList)
 {
   KMMessage* msg = new KMMessage;
   QString str, replyStr, mailingListStr, replyToStr, toStr, refStr;
@@ -674,7 +718,14 @@ KMMessage* KMMessage::createReply(bool replyToAll)
   mailingListStr = headerField("X-Mailing-List");
   replyToStr = replyTo();
 
-  if (replyToAll)
+  msg->setCharset("utf-8");
+
+  if (replyToList && parent()->isMailingList())
+  {
+      // Reply to mailing-list posting address
+      toStr = parent()->mailingListPostAddress();
+  }
+  else if (replyToAll)
   {
     int i;
     // sanders only include the replyTo address if it's != to the from address
@@ -698,8 +749,14 @@ KMMessage* KMMessage::createReply(bool replyToAll)
       f = f.right(f.length() + 1 -i );
     if((i = toStr.find(f)) != -1)
     {
-      int pos1, pos2;
+      int pos1, pos2, quot;
+      quot = toStr.findRev("\"", i);
       pos1 = toStr.findRev(", ", i);
+      if (pos1 < quot)
+      {
+        quot = toStr.findRev("\"", quot - 1);
+        pos1 = toStr.findRev(", ", quot);
+      }
       if( pos1 == -1 ) pos1 = 0;
       pos2 = toStr.find(", ", i);
       toStr = toStr.left(pos1) + toStr.right(toStr.length() - pos2);
@@ -710,8 +767,14 @@ KMMessage* KMMessage::createReply(bool replyToAll)
     QString ccStr = cc().simplifyWhiteSpace() + ", ";
     if((i = ccStr.find(f)) != -1)
     {
-      int pos1, pos2;
+      int pos1, pos2, quot;
+      quot = ccStr.findRev("\"", i);
       pos1 = ccStr.findRev(", ", i);
+      if (pos1 < quot)
+      {
+        quot = ccStr.findRev("\"", quot - 1);
+        pos1 = ccStr.findRev(", ", quot);
+      }
       if( pos1 == -1 ) pos1 = 0;
       pos2 = ccStr.find(", ", i);
       ccStr = ccStr.left(pos1) + ccStr.right(ccStr.length() - pos2 - 1); //Daniel
@@ -729,7 +792,6 @@ KMMessage* KMMessage::createReply(bool replyToAll)
           ccStr.truncate(ccStr.length()-1);
         msg->setCc(ccStr);
       }
-
   }
   else
   {
@@ -784,7 +846,6 @@ KMMessage* KMMessage::createReply(bool replyToAll)
   if (!recognized)
     msg->setSubject("Re: " + subject());
 
-  msg->setCharset(charset());
   setStatus(KMMsgStatusReplied);
 
   return msg;
@@ -824,25 +885,27 @@ KMMessage* KMMessage::createRedirect(void)
 {
   KMMessage* msg = new KMMessage;
   KMMessagePart msgPart;
-  QString str = "";
+  QCString str = "";
   int i;
 
   str = asQuotedString(str, "", FALSE, false);
 
-  msg->setBody(str.latin1());
+  msg->setHeaderField("Content-Type","text/plain; charset=\"utf-8\"");
+  msg->setBody(str);
   if (numBodyParts() > 0)
   {
-    msgPart.setBody(str.latin1());
+    msgPart.setBody(str);
     msgPart.setTypeStr("text");
     msgPart.setSubtypeStr("plain");
+    msgPart.setCharset("utf-8");
     msg->addBodyPart(&msgPart);
 
     for (i = 1; i < numBodyParts(); i++)
     {
       bodyPart(i, &msgPart);
-      if (stricmp(msgPart.contentDisposition(),"inline")!=0 ||
-	  (stricmp(msgPart.typeStr(),"text")!=0 &&
-	   stricmp(msgPart.typeStr(),"message")!=0))
+      if (qstricmp(msgPart.contentDisposition(),"inline")!=0 ||
+	  (qstricmp(msgPart.typeStr(),"text")!=0 &&
+	   qstricmp(msgPart.typeStr(),"message")!=0))
       {
 	msg->addBodyPart(&msgPart);
       }
@@ -853,7 +916,6 @@ KMMessage* KMMessage::createRedirect(void)
   msg->setHeaderField("X-KMail-Redirect-From", from());
   msg->setSubject(subject());
   msg->setFrom(from());
-  msg->setCharset(charset());
   setStatus(KMMsgStatusForwarded);
 
   return msg;
@@ -882,36 +944,59 @@ KMMessage* KMMessage::createForward(void)
     s += "Date: " + dateStr() + "\n";
     s += "From: " + from() + "\n";
     s += "To: " + to() + "\n";
+    if (!cc().isEmpty()) s += "Cc: " + cc() + "\n";
     s += "\n";
     str = asQuotedString(s, "", FALSE, false);
     str += "\n-------------------------------------------------------\n";
   }
 
-  if (!charset().isEmpty()) msg->setCharset(charset());
+  msg->setCharset("utf-8");
   msg->setBody(str);
 
   if (numBodyParts() > 0)
   {
-    msgPart.setBody(str);
     msgPart.setTypeStr("text");
     msgPart.setSubtypeStr("plain");
+    msgPart.setCharset("utf-8");
+    msgPart.setBody(str);
     msg->addBodyPart(&msgPart);
 
     for (i = 1; i < numBodyParts(); i++)
     {
       bodyPart(i, &msgPart);
-      if (stricmp(msgPart.contentDisposition(),"inline")!=0 ||
-	  (stricmp(msgPart.typeStr(),"text")!=0 &&
-	   stricmp(msgPart.typeStr(),"message")!=0))
+      if (qstricmp(msgPart.contentDisposition(),"inline")!=0 ||
+	  (qstricmp(msgPart.typeStr(),"text")!=0 &&
+	   qstricmp(msgPart.typeStr(),"message")!=0))
       {
         msg->addBodyPart(&msgPart);
       }
     }
   }
 
-  if (strnicmp(subject(), "Fwd:", 4)!=0)
+  QStringList::Iterator it;
+  bool recognized = false;
+  for (it = sForwardSubjPrefixes.begin(); !recognized && (it != sForwardSubjPrefixes.end()); ++it)
+  {
+    QString prefix = subject().left((*it).length());
+    if (prefix.lower() == (*it).lower()) //recognized
+    {
+      if (!sReplaceForwSubjPrefix || (prefix == "Fwd:"))
+        msg->setSubject(subject());
+      else
+      {
+        //replace recognized prefix with "Fwd: "
+        //handle crappy subjects Fwd:  blah blah (note double space)
+        int subjStart = (*it).length();
+        while (subject()[subjStart].isSpace()) //strip only from beginning
+          subjStart++;
+        msg->setSubject("Fwd: " + subject().mid(subjStart,
+                                   subject().length() - subjStart));
+      }
+      recognized = true;
+    }
+  }
+  if (!recognized)
     msg->setSubject("Fwd: " + subject());
-  else msg->setSubject(subject());
   setStatus(KMMsgStatusForwarded);
 
   return msg;
@@ -984,7 +1069,8 @@ void KMMessage::setAutomaticFields(bool aIsMulti)
 {
   DwHeaders& header = mMsg->Headers();
   header.MimeVersion().FromString("1.0");
-  header.MessageId().CreateDefault();
+  if (!QString(QTextCodec::locale()).contains("tr_TR")) // crashes otherwise
+    header.MessageId().CreateDefault();
 
   if (aIsMulti || numBodyParts() > 1)
   {
@@ -1087,7 +1173,7 @@ void KMMessage::setDate(const QString& aStr)
 //-----------------------------------------------------------------------------
 const QString KMMessage::to(void) const
 {
-  return headerField("To");
+  return headerField("To").simplifyWhiteSpace();
 }
 
 
@@ -1100,13 +1186,13 @@ void KMMessage::setTo(const QString& aStr)
 //-----------------------------------------------------------------------------
 const QString KMMessage::toStrip(void) const
 {
-  return stripEmailAddr(decodeRFC1522String(headerField("To")));
+  return stripEmailAddr(headerField("To"));
 }
 
 //-----------------------------------------------------------------------------
 const QString KMMessage::replyTo(void) const
 {
-  return headerField("Reply-To");
+  return headerField("Reply-To").simplifyWhiteSpace();
 }
 
 
@@ -1127,7 +1213,7 @@ void KMMessage::setReplyTo(KMMessage* aMsg)
 //-----------------------------------------------------------------------------
 const QString KMMessage::cc(void) const
 {
-  return headerField("Cc");
+  return headerField("Cc").simplifyWhiteSpace();
 }
 
 
@@ -1141,7 +1227,7 @@ void KMMessage::setCc(const QString& aStr)
 //-----------------------------------------------------------------------------
 const QString KMMessage::bcc(void) const
 {
-  return headerField("Bcc");
+  return headerField("Bcc").simplifyWhiteSpace();
 }
 
 
@@ -1167,7 +1253,7 @@ const QString KMMessage::who(void) const
 //-----------------------------------------------------------------------------
 const QString KMMessage::from(void) const
 {
-  return headerField("From");
+  return headerField("From").simplifyWhiteSpace();
 }
 
 
@@ -1185,13 +1271,13 @@ void KMMessage::setFrom(const QString& bStr)
 //-----------------------------------------------------------------------------
 const QString KMMessage::fromStrip(void) const
 {
-  return stripEmailAddr(decodeRFC1522String(headerField("From")));
+  return stripEmailAddr(headerField("From"));
 }
 
 //-----------------------------------------------------------------------------
 const QString KMMessage::fromEmail(void) const
 {
-  return getEmailAddr(decodeRFC1522String(headerField("From")));
+  return getEmailAddr(headerField("From"));
 }
 
 
@@ -1255,7 +1341,7 @@ const QString KMMessage::replyToId(void) const
 //-----------------------------------------------------------------------------
 const QString KMMessage::replyToIdMD5(void) const
 {
-  //  QString result = KMMessagePart::encodeBase64( decodeRFC1522String(replyToId()) );
+  //  QString result = KMMessagePart::encodeBase64( decodeRFC2047String(replyToId()) );
   QString result = KMMessagePart::encodeBase64( replyToId() );
   return result;
 }
@@ -1285,7 +1371,7 @@ const QString KMMessage::msgId(void) const
 //-----------------------------------------------------------------------------
 const QString KMMessage::msgIdMD5(void) const
 {
-  //  QString result = KMMessagePart::encodeBase64(  decodeRFC1522String(msgId()) );
+  //  QString result = KMMessagePart::encodeBase64(  decodeRFC2047String(msgId()) );
   QString result = KMMessagePart::encodeBase64( msgId() );
   return result;
 }
@@ -1314,7 +1400,7 @@ const QStrList KMMessage::headerAddrField(const QString& aName) const
   resultList.clear();
   for (addr=addrList->FirstAddress(); addr; addr=addr->Next())
   {
-    resultList.append(decodeRFC1522String(addr->AsString().c_str()));
+    resultList.append(addr->AsString().c_str());
   }
 
   if (resultList.count()==0)
@@ -1332,12 +1418,12 @@ const QString KMMessage::headerField(const QString& aName) const
 {
   DwHeaders& header = mMsg->Headers();
   DwField* field;
-  QCString result;
+  QString result;
 
   if (aName.isEmpty() || !(field = header.FindField((const char*)aName)))
     result = "";
   else
-    result = decodeRFC1522String(header.FieldBody((const char*)aName).
+    result = decodeRFC2047String(header.FieldBody((const char*)aName).
                     AsString().c_str());
   return result;
 }
@@ -1365,7 +1451,7 @@ void KMMessage::setHeaderField(const QString& aName, const QString& bValue)
   DwField* field;
   QString aValue = "";
   if (!bValue.isEmpty())
-    aValue = encodeRFC2047String(bValue);
+    aValue = encodeRFC2047String(bValue, charset());
 
   if (aName.isEmpty()) return;
 
@@ -1501,7 +1587,7 @@ QCString KMMessage::body(void) const
 
 
 //-----------------------------------------------------------------------------
-QCString KMMessage::bodyDecoded(void) const
+QByteArray KMMessage::bodyDecodedBinary(void) const
 {
   DwString dwsrc, dwstr;
   QString result;
@@ -1519,10 +1605,22 @@ QCString KMMessage::bodyDecoded(void) const
     dwstr = dwsrc;
     break;
   }
-  // Should probably be returning a QByteArray, if it may contain NUL
 
-  QCString ba(dwstr.c_str(), dwstr.size() + 1);
+  int len=dwstr.size();
+  QByteArray ba(len);
+  memcpy(ba.data(),dwstr.data(),len);
+  return ba;
+}
 
+
+//-----------------------------------------------------------------------------
+QCString KMMessage::bodyDecoded(void) const
+{
+  QByteArray raw(bodyDecodedBinary());
+  int len=raw.size();
+  QCString ba(len+1);
+  memcpy(ba.data(),raw.data(),len);
+  ba[len] = 0;
   return ba;
 }
 
@@ -1530,11 +1628,17 @@ QCString KMMessage::bodyDecoded(void) const
 //-----------------------------------------------------------------------------
 void KMMessage::setBodyEncoded(const QCString& aStr)
 {
-  QCString bStr = aStr;
-  if (aStr.isNull())
-    bStr = "";
-  int len = bStr.length();
-  DwString dwSrc(bStr.data(), len);
+  int len = aStr.length();
+  QByteArray ba(len);
+  if (len > 0)
+    memcpy(ba.data(),aStr.data(),len);
+  setBodyEncodedBinary(ba);
+}
+
+//-----------------------------------------------------------------------------
+void KMMessage::setBodyEncodedBinary(const QByteArray& aStr)
+{
+  DwString dwSrc(aStr.data(), aStr.size());
   DwString dwResult;
 
   switch (cte())
@@ -1578,7 +1682,7 @@ int KMMessage::numBodyParts(void) const
   QList< DwBodyPart > parts;
   QString mp = "multipart";
 
-  while (part) 
+  while (part)
   {
      //dive into multipart messages
      while ( part && part->Headers().HasContentType() &&
@@ -1596,7 +1700,7 @@ int KMMessage::numBodyParts(void) const
 	part = parts.getLast();
 	parts.removeLast();
      } ;
-     
+
      if (part)
 	 part = part->Next();
   }
@@ -1639,11 +1743,12 @@ void KMMessage::bodyPart(int aIdx, KMMessagePart* aPart) const
      } ;
      if (curpart)
 	 curpart = curpart->Next();
-  }  
+  }
 
   // If the DwBodyPart was found get the header fields and body
   if (part)
   {
+    aPart->setName("");
     headers = &part->Headers();
 
     // Content-type
@@ -1653,9 +1758,14 @@ void KMMessage::bodyPart(int aIdx, KMMessagePart* aPart) const
       aPart->setSubtypeStr(headers->ContentType().SubtypeStr().c_str());
       DwParameter *param=headers->ContentType().FirstParameter();
       while(param)
-          if (param->Attribute()=="charset") break;
-          else param=param->Next();
-      if (param) aPart->setCharset(param->Value().c_str());
+      {
+        if (QString(param->Attribute().c_str()).lower()=="charset")
+          aPart->setCharset(QString(param->Value().c_str()).lower());
+        else if (QString(param->Attribute().c_str())=="name*")
+          aPart->setName(KMMsgBase::decodeRFC2231String(
+            param->Value().c_str()));
+        param=param->Next();
+      }
     }
     else
     {
@@ -1663,12 +1773,17 @@ void KMMessage::bodyPart(int aIdx, KMMessagePart* aPart) const
       aPart->setSubtypeStr("plain");
     }
     // Modification by Markus
-    if (!headers->ContentType().Name().empty())
-	aPart->setName(headers->ContentType().Name().c_str());
-    else if (!headers->Subject().AsString().empty())
-	aPart->setName( headers->Subject().AsString().c_str() );
-    else
-      aPart->setName( i18n("Attachment: ") + QString( "%1" ).arg( aIdx ) );
+    if (aPart->name().isEmpty())
+    {
+      if (!headers->ContentType().Name().empty())
+        aPart->setName(KMMsgBase::decodeQuotedPrintableString(headers->
+          ContentType().Name().c_str()) );
+      else if (!headers->Subject().AsString().empty())
+        aPart->setName( KMMsgBase::decodeQuotedPrintableString(headers->
+          Subject().AsString().c_str()) );
+      else
+        aPart->setName( i18n("Attachment: ") + QString( "%1" ).arg( aIdx ) );
+    }
 
     // Content-transfer-encoding
     if (headers->HasContentTransferEncoding())
@@ -1753,7 +1868,7 @@ void KMMessage::setBodyPart(int aIdx, const KMMessagePart* aPart)
       DwParameter *param=headers.ContentType().FirstParameter();
       while(param)
       {
-	if (param->Attribute()=="charset") break;
+	if (QString(param->Attribute().c_str()).lower()=="charset") break;
 	else param=param->Next();
       }
       if (!param)
@@ -1789,17 +1904,18 @@ void KMMessage::deleteBodyParts(void)
 //-----------------------------------------------------------------------------
 void KMMessage::addBodyPart(const KMMessagePart* aPart)
 {
+  QString charset  = aPart->charset();
+
   DwBodyPart* part = DwBodyPart::NewBodyPart(emptyString, 0);
 
   QString type     = aPart->typeStr();
   QString subtype  = aPart->subtypeStr();
   QString cte      = aPart->cteStr();
   QString contDesc = KMMsgBase::encodeRFC2047String(aPart->
-    contentDescription());
+    contentDescription(), charset);
   QString contDisp = aPart->contentDisposition();
-  QString name     = KMMsgBase::encodeRFC2231String(aPart->name());
+  QString name     = KMMsgBase::encodeRFC2231String(aPart->name(), charset);
   bool RFC2231encoded = aPart->name() != name;
-  QString charset  = aPart->charset();
 
   DwHeaders& headers = part->Headers();
   if (type != "" && subtype != "")
@@ -1935,65 +2051,88 @@ const QString KMMessage::getEmailAddr(const QString& aStr)
 //-----------------------------------------------------------------------------
 const QString KMMessage::emailAddrAsAnchor(const QString& aEmail, bool stripped)
 {
-  QString result, addr, tmp, tmp2;
+  QCString result, addr, tmp2;
   const char *pos;
   char ch;
-  QString email = decodeRFC1522String(aEmail);
+  bool insideQuote = false;
+
+  // FIXME: use unicode instead of utf8
+  QCString email = aEmail.utf8();
 
   if (email.isEmpty()) return email;
 
-  result = "<a href=\"mailto:";
+  result = "<a href='mailto:";
   for (pos=email.data(); *pos; pos++)
   {
     ch = *pos;
+    if (ch == '"') insideQuote = !insideQuote;
     if (ch == '<') addr += "&lt;";
     else if (ch == '>') addr += "&gt;";
     else if (ch == '&') addr += "&amp;";
-    else if (ch != ',') addr += ch;
+    else if (ch == '\'') addr += "&#39;";
+    else if (ch != ',' || insideQuote) addr += ch;
 
-    if (ch != ',')
+    if (ch != ',' || insideQuote)
       tmp2 += ch;
 
-    if (ch == ',' || !pos[1])
+    if ((ch == ',' && !insideQuote) || !pos[1])
     {
-      tmp = addr.copy();
-      result += tmp.replace(QRegExp("\""),"");
+      result += addr;
       result = result.replace(QRegExp("\n"),"");
-      result += "\">";
+      result += "'>";
       if (stripped) result += KMMessage::stripEmailAddr(tmp2);
       else result += addr;
       tmp2 = "";
       result += "</a>";
       if (ch == ',')
       {
-	result += ", <a href=\"mailto:";
+	result += ", <a href='mailto:";
 	while (pos[1]==' ') pos++;
       }
       addr = "";
     }
   }
-  return result;
+  return QString::fromUtf8(result);
 }
 
 
 //-----------------------------------------------------------------------------
 void KMMessage::readConfig(void)
 {
+  KConfig *config=kapp->config();
+
+  config->setGroup("General");
+  int languageNr = config->readNumEntry("reply-current-language",0);
+//  int replyLanguages = config->readNumEntry("reply-languages",1);
 
   /* Default values added for KRN otherwise createReply() segfaults*/
   /* They are taken from kmail's dialog */
 
-  KConfig *config=kapp->config();
-
-  config->setGroup("KMMessage");
-  sReplyStr = config->readEntry("phrase-reply",i18n("On %D, you wrote:"));
-  sReplyAllStr = config->readEntry("phrase-reply-all",i18n("On %D, %F wrote:"));
-  sForwardStr = config->readEntry("phrase-forward",i18n("Forwarded Message"));
-  sIndentPrefixStr = config->readEntry("indent-prefix",">%_");
+//  for (int i=0; i<replyLanguages; i++)
+  {
+    config->setGroup(QString("KMMessage #%1").arg(languageNr));
+//    if (i == replyLanguages - 1 || config->readEntry("language") == sLanguage)
+    {
+      sReplyLanguage = config->readEntry("language",KGlobal::locale()->language());
+      sReplyStr = config->readEntry("phrase-reply",
+        i18n("On %D, you wrote:"));
+      sReplyAllStr = config->readEntry("phrase-reply-all",
+        i18n("On %D, %F wrote:"));
+      sForwardStr = config->readEntry("phrase-forward",
+        i18n("Forwarded Message"));
+      sIndentPrefixStr = config->readEntry("indent-prefix",">%_");
+//      break;
+    }
+  }
+  config->setGroup("Composer");
   sReplySubjPrefixes = config->readListEntry("reply-prefixes", ',');
   if (sReplySubjPrefixes.count() == 0)
     sReplySubjPrefixes.append("Re:");
-  sReplaceSubjPrefix = config->readBoolEntry("replace-prefix", true);
+  sReplaceSubjPrefix = config->readBoolEntry("replace-reply-prefix", true);
+  sForwardSubjPrefixes = config->readListEntry("forward-prefixes", ',');
+  if (sForwardSubjPrefixes.count() == 0)
+    sForwardSubjPrefixes.append("Fwd:");
+  sReplaceForwSubjPrefix = config->readBoolEntry("replace-forward-prefix", true);
 
   config->setGroup("Reader");
   sHdrStyle = config->readNumEntry("hdr-style", KMReaderWin::HdrFancy);
@@ -2015,7 +2154,7 @@ const QString KMMessage::charset(void) const
    mType.Parse();
    DwParameter *param=mType.FirstParameter();
    while(param){
-      if (param->Attribute()=="charset")
+      if (QString(param->Attribute().c_str()).lower()=="charset")
         return QString(param->Value().c_str());
       else param=param->Next();
    }
@@ -2032,7 +2171,7 @@ void KMMessage::setCharset(const QString& bStr)
    mType.Parse();
    DwParameter *param=mType.FirstParameter();
    while(param)
-      if (param->Attribute()=="charset") break;
+      if (QString(param->Attribute().c_str()).lower()=="charset") break;
       else param=param->Next();
    if (!param){
       param=new DwParameter;
