@@ -1,19 +1,18 @@
-/***************************************************************************
-                          knaccountmanager.cpp  -  description
-                             -------------------
+/*
+    knaccountmanager.cpp
 
-    copyright            : (C) 2000 by Christian Thurner
-    email                : cthurner@freepage.de
- ***************************************************************************/
+    KNode, the KDE newsreader
+    Copyright (c) 1999-2000 the KNode authors.
+    See file AUTHORS for details
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software Foundation,
+    Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, US
+*/
 
 #include <stdlib.h>
 
@@ -32,40 +31,29 @@
 #include "kngroup.h"
 #include "kngroupmanager.h"
 #include "knnntpaccount.h"
-#include "knserverinfo.h"
-#include "knsavedarticlemanager.h"
-#include "knaccnewssettings.h"
 #include "kncollectionviewitem.h"
 #include "knglobals.h"
+#include "knconfigmanager.h"
 #include "utilities.h"
 #include "knaccountmanager.h"
+#include "knfoldermanager.h"
+#include "knconfig.h"
 
 
-KNAccountManager::KNAccountManager(KNGroupManager *gm, KNListView *v, KActionCollection* actColl, QObject * parent, const char * name)
-  : QObject(parent, name), gManager(gm), view(v), actionCollection(actColl)
+KNAccountManager::KNAccountManager(KNGroupManager *gm, KNListView *v, QObject * parent, const char * name)
+  : QObject(parent, name), gManager(gm), c_urrentAccount(0), view(v)
 {
   accList=new QList<KNNntpAccount>;
   accList->setAutoDelete(true);
   s_mtp=new KNServerInfo();
   s_mtp->setType(KNServerInfo::STsmtp);
   s_mtp->setId(0);
-  readConfig();
-  loadAccounts();
-  
-  actProperties = new KAction(i18n("&Properties..."), 0, this, SLOT(slotProperties()),
-                              actionCollection, "account_properties");
-  actSubscribe = new KAction(i18n("&Subscribe to Newsgroups..."),"news_subscribe", 0, this, SLOT(slotSubscribe()),
-                             actionCollection, "account_subscribe");
-  actLoadHdrs = new KAction(i18n("&Get New Articles"), "mail_get", 0, this, SLOT(slotLoadHdrs()),
-                            actionCollection, "account_dnlHeaders");
-  actDelete = new KAction(i18n("&Delete"), 0, this, SLOT(slotDelete()),
-                          actionCollection, "account_delete");
-  actPostNewArticle = new KAction(i18n("&Post new article"), "filenew", Key_P , this, SLOT(slotPostNewArticle()),
-                                  actionCollection, "article_postNew");
-  
-  setCurrentAccount(0);
-}
+  KConfig *conf=KGlobal::config();
+  conf->setGroup("MAILSERVER");
+  s_mtp->readConf(conf);
 
+  loadAccounts();
+}
 
 
 KNAccountManager::~KNAccountManager()
@@ -75,24 +63,13 @@ KNAccountManager::~KNAccountManager()
 }
 
 
-
-void KNAccountManager::readConfig()
-{
-  KConfig *conf=KGlobal::config();
-  conf->setGroup("MAILSERVER");
-  s_mtp->readConf(conf);
-}
-
-
-
-void KNAccountManager::saveYourself()
+void KNAccountManager::prepareShutdown()
 {
   for(KNNntpAccount *a=accList->first(); a; a=accList->next())
-    a->syncInfo();
+    a->saveInfo();
 }
 
 
-
 void KNAccountManager::loadAccounts()
 {
   QString dir(KGlobal::dirs()->saveLocation("appdata"));
@@ -102,17 +79,17 @@ void KNAccountManager::loadAccounts()
   }
   QDir d(dir);
   KNNntpAccount *a;
-  
+  QPixmap pm=knGlobals.cfgManager->appearance()->icon(KNConfig::Appearance::nntp);
   QStringList entries(d.entryList("nntp.*", QDir::Dirs));
 
-  QStringList::Iterator it; 
+  QStringList::Iterator it;
   for(it = entries.begin(); it != entries.end(); it++) {
     a=new KNNntpAccount();
     if (a->readInfo(dir+(*it)+"/info")) {
       accList->append(a);
       KNCollectionViewItem* cvit=new KNCollectionViewItem(view);
       a->setListItem(cvit);
-      cvit->setPixmap(0, KNLVItemBase::icon(KNLVItemBase::PTnntp));
+      cvit->setPixmap(0, pm);
       gManager->loadGroups(a);
     } else {
       delete a;
@@ -122,7 +99,6 @@ void KNAccountManager::loadAccounts()
 }
 
 
-
 KNNntpAccount* KNAccountManager::account(int i)
 {
   KNNntpAccount *ret=0;
@@ -139,27 +115,12 @@ KNNntpAccount* KNAccountManager::account(int i)
 }
 
 
-
 void KNAccountManager::setCurrentAccount(KNNntpAccount *a)
 {
   c_urrentAccount=a;
-  if (a) {
-    actProperties->setEnabled(true);
-    actSubscribe->setEnabled(true);
-    actLoadHdrs->setEnabled(true);
-    actDelete->setEnabled(true);
-    actPostNewArticle->setEnabled(true);
-  } else {
-    actProperties->setEnabled(false);
-    actSubscribe->setEnabled(false);
-    actLoadHdrs->setEnabled(false);
-    actDelete->setEnabled(false);
-    actPostNewArticle->setEnabled(false);   
-  }
 }
 
 
-
 // a is new account allocated and configured by the caller
 bool KNAccountManager::newAccount(KNNntpAccount *a)
 {
@@ -182,9 +143,8 @@ bool KNAccountManager::newAccount(KNNntpAccount *a)
   dir = KGlobal::dirs()->saveLocation("appdata",QString("nntp.%1/").arg(a->id()));
   if (dir!=QString::null) {
     accList->append(a);
-    applySettings(a);
     KNCollectionViewItem *it = new KNCollectionViewItem(view);
-    it->setPixmap(0, KNLVItemBase::icon(KNLVItemBase::PTnntp));
+    it->setPixmap(0, knGlobals.cfgManager->appearance()->icon(KNConfig::Appearance::nntp));
     a->setListItem(it);
     emit(accountAdded(a));
     return true;
@@ -196,17 +156,6 @@ bool KNAccountManager::newAccount(KNNntpAccount *a)
 }
 
 
-
-// commit changes on a the caller made
-void KNAccountManager::applySettings(KNNntpAccount *a)
-{
-  a->saveInfo();
-  a->updateListItem();
-  emit(accountModified(a));
-}
-
-
-
 // a==0: remove current account
 void KNAccountManager::removeAccount(KNNntpAccount *a)
 {
@@ -214,7 +163,7 @@ void KNAccountManager::removeAccount(KNNntpAccount *a)
   if(!a) return;
 
   QList<KNGroup> *lst;
-  if(a->hasUnsent()) {
+  if(knGlobals.folManager->unsentForAccount(a->id()) > 0) {
     KMessageBox::sorry(knGlobals.topWidget, i18n("This account cannot be deleted, since there are some unsent messages for it."));
   } 
   else if(KMessageBox::questionYesNo(knGlobals.topWidget, i18n("Do you really want to delete this account?"))==KMessageBox::Yes) {
@@ -222,7 +171,7 @@ void KNAccountManager::removeAccount(KNNntpAccount *a)
     lst->setAutoDelete(false);
     gManager->getGroupsOfAccount(a, lst);
     for(KNGroup *g=lst->first(); g; g=lst->next()) {
-      if(g->locked()) {
+      if(g->isLocked()) {
         KMessageBox::sorry(knGlobals.topWidget, i18n("At least one group of this account is currently in use.\nThe account cannot be deleted at the moment."));
         return;
       }
@@ -251,57 +200,17 @@ void KNAccountManager::removeAccount(KNNntpAccount *a)
     accList->removeRef(a);      // finally delete a
   }     
 }
-  
 
 
-void KNAccountManager::slotProperties()
+void KNAccountManager::editProperties(KNNntpAccount *a)
 {
-  if (c_urrentAccount) {
-    KNAccNewsConfDialog *confDlg = new KNAccNewsConfDialog(c_urrentAccount,knGlobals.topWidget);
+  if(!a) a=c_urrentAccount;
+  if(!a) return;
 
-    if (confDlg->exec())
-      applySettings(c_urrentAccount);
-
-    delete confDlg;
-  }
-}
-    
-
-
-void KNAccountManager::slotSubscribe()
-{
-  if (c_urrentAccount)
-    gManager->showGroupDialog(c_urrentAccount);
-}
-
-  
-
-void KNAccountManager::slotLoadHdrs()
-{
-  if (c_urrentAccount)
-    gManager->checkAll(c_urrentAccount);
-}
-
-
-
-void KNAccountManager::slotDelete()
-{
-  removeAccount();
-}
-
-
-
-void KNAccountManager::slotPostNewArticle()
-{
-  if (c_urrentAccount) {
-    if(gManager->hasCurrentGroup())
-      knGlobals.sArtManager->post(gManager->currentGroup());
-    else
-      knGlobals.sArtManager->post(c_urrentAccount); 
-  }
+  a->editProperties(knGlobals.topWidget);
+  emit(accountModified(a));
 }
 
 //--------------------------------
 
 #include "knaccountmanager.moc"
-
