@@ -1,20 +1,18 @@
-/***************************************************************************
-                          knfiltermanager.cpp  -  description
-                             -------------------
+/*
+    knfiltermanager.cpp
 
-    copyright            : (C) 1999 by Christian Thurner
-    email                : cthurner@freepage.de
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    KNode, the KDE newsreader
+    Copyright (c) 1999-2000 the KNode authors.
+    See file AUTHORS for details
 
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software Foundation,
+    Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, US
+*/
 
 #include <stdlib.h>
 #include <qlayout.h>
@@ -39,12 +37,12 @@
 #include "knstringfilter.h"
 #include "knarticlefilter.h"
 #include "knfilterdialog.h"
-#include "knfiltersettings.h"
 #include "knfiltermanager.h"
+#include "knconfig.h"
 
 
 KNFilterSelectAction::KNFilterSelectAction( const QString& text, const QString& pix,
-                                            QObject* parent, char *name )
+                                            QObject* parent, const char *name )
  : KActionMenu(text,pix,parent,name), currentItem(-42)
 {
   popupMenu()->setCheckable(true);
@@ -73,22 +71,21 @@ void KNFilterSelectAction::slotMenuActivated(int id)
 }
 
 
-
-//=========================================================================================
+//==============================================================================
 
 
-
-KNFilterManager::KNFilterManager(KActionCollection* actColl, QObject * parent, const char * name)
- : QObject(parent,name), fset(0), currFilter(0), actionCollection(actColl), isAGroup(false)
+KNFilterManager::KNFilterManager(KNFilterSelectAction *a, KAction *keybA, QObject * parent, const char * name)
+ : QObject(parent,name), fset(0), currFilter(0), a_ctFilter(a)
 {
   fList.setAutoDelete(true);
 
-  actFilter = new KNFilterSelectAction(i18n("&Filter"), "filter", actionCollection, "view_Filter");
-  connect(actFilter, SIGNAL(activated(int)), this,  SLOT(slotMenuActivated(int)));
-  actFilter->setEnabled(false);
+  connect(a_ctFilter, SIGNAL(activated(int)), this,  SLOT(slotMenuActivated(int)));
+  connect(keybA, SIGNAL(activated()), this,  SLOT(slotShowFilterChooser()));
+  loadFilters();
 
-  loadFilters();  
-  readOptions();  
+  KConfig *conf=KGlobal::config();
+  conf->setGroup("READNEWS");
+  setFilter(conf->readNumEntry("lastFilterID", 1));
 }
 
 
@@ -101,33 +98,25 @@ KNFilterManager::~KNFilterManager()
 
 void KNFilterManager::readOptions()
 {
-  KConfig *conf=KGlobal::config();    
-  conf->setGroup("READNEWS");
-  setFilter(conf->readNumEntry("lastFilterID", 1));
 }
 
 
 
 void KNFilterManager::saveOptions()
+{
+}
+
+
+void KNFilterManager::prepareShutdown()
 {
   if (currFilter) {
-    KConfig *conf=KGlobal::config();    
+    KConfig *conf=KGlobal::config();
     conf->setGroup("READNEWS");
     conf->writeEntry("lastFilterID", currFilter->id());
   }
 }
 
 
-
-// dis-/enable the filter menu
-void KNFilterManager::setIsAGroup(bool b)
-{
-  isAGroup = b;
-  actFilter->setEnabled(isAGroup && (menuOrder.count()));
-}
-
-
-
 void KNFilterManager::loadFilters()
 {
   QString fname(KGlobal::dirs()->findResource("appdata","filters/filters.rc"));
@@ -171,7 +160,7 @@ void KNFilterManager::saveFilterLists()
 
 
 
-void KNFilterManager::startConfig(KNFilterSettings *fs)
+void KNFilterManager::startConfig(KNConfig::FilterListWidget *fs)
 {
   fset=fs;
   commitNeeded = false;
@@ -323,7 +312,7 @@ KNArticleFilter* KNFilterManager::setFilter(const int id)
   currFilter=byID(id);  
   
   if(currFilter) {
-    actFilter->setCurrentItem(currFilter->id());
+    a_ctFilter->setCurrentItem(currFilter->id());
     emit(filterChanged(currFilter));
   } else
     currFilter=bak;
@@ -347,22 +336,21 @@ KNArticleFilter* KNFilterManager::byID(int id)
 
 void KNFilterManager::updateMenu()
 {
-  actFilter->popupMenu()->clear();
+  a_ctFilter->popupMenu()->clear();
   KNArticleFilter *f=0;
 
   QValueList<int>::Iterator it = menuOrder.begin();
   while (it != menuOrder.end()) {
     if ((*it)!=-1) {
       if ((f=byID((*it))))
-        actFilter->popupMenu()->insertItem(f->translatedName(), f->id());
+        a_ctFilter->popupMenu()->insertItem(f->translatedName(), f->id());
     }
-    else actFilter->popupMenu()->insertSeparator();
+    else a_ctFilter->popupMenu()->insertSeparator();
     ++it;
   }
   
   if(currFilter)
-    actFilter->setCurrentItem(currFilter->id());
-  actFilter->setEnabled(isAGroup && (menuOrder.count()));
+    a_ctFilter->setCurrentItem(currFilter->id());
 }
 
 
@@ -376,6 +364,34 @@ void KNFilterManager::slotMenuActivated(int id)
 }
 
 
+void KNFilterManager::slotShowFilterChooser()
+{
+  KNArticleFilter *f=0;
+  QStringList items;
+  QValueList<int> ids;
+
+  QValueList<int>::Iterator it = menuOrder.begin();
+  while (it != menuOrder.end()) {
+    if ((*it)!=-1)
+      if ((f=byID((*it)))) {
+        items.append(f->translatedName());
+        ids.append(*it);
+      }
+    ++it;
+  }
+
+  int currentItem=0;
+  if (currFilter)
+    currentItem=ids.findIndex(currFilter->id());
+  if (currentItem==-1)
+    currentItem=0;
+
+  int newFilter = selectDialog(knGlobals.topWidget, i18n("Select Filter"), items, currentItem);
+  if (newFilter != -1)
+    setFilter(ids[newFilter]);
+}
+
+
 //--------------------------------
 
 #include "knfiltermanager.moc"
