@@ -1,19 +1,18 @@
-/***************************************************************************
-                          kngroup.cpp  -  description
-                             -------------------
+/*
+    kngroup.cpp
 
-    copyright            : (C) 2000 by Christian Thurner
-    email                : cthurner@freepage.de
- ***************************************************************************/
+    KNode, the KDE newsreader
+    Copyright (c) 1999-2000 the KNode authors.
+    See file AUTHORS for details
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software Foundation,
+    Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, US
+*/
 
 #include <qfile.h>
 #include <qtextstream.h>
@@ -24,22 +23,25 @@
 #include <kmessagebox.h>
 #include <kdebug.h>
 
+#include "knserverinfo.h"
+#include "knprotocolclient.h"
 #include "knglobals.h"
-#include "knuserentry.h"
-#include "knfetcharticle.h"
+#include "knmime.h"
 #include "knstringsplitter.h"
 #include "kncollectionviewitem.h"
 #include "kngrouppropdlg.h"
 #include "knnntpaccount.h"
 #include "utilities.h"
 #include "kngroup.h"
+#include "knconfigmanager.h"
 
 
 #define SORT_DEPTH 5
 
 KNGroup::KNGroup(KNCollection *p)
   : KNArticleCollection(p), n_ewCount(0), r_eadCount(0),
-    l_astNr(0), m_axFetch(0), u_ser(0), l_ocked(false), l_oading(0)
+    l_astNr(0), m_axFetch(0), l_ocked(false), u_seCharset(false),
+    s_tatus(unknown), i_dentity(0)
 {
 }
 
@@ -47,7 +49,7 @@ KNGroup::KNGroup(KNCollection *p)
 
 KNGroup::~KNGroup()
 {
-  delete u_ser;
+  delete i_dentity;
 }
 
 
@@ -82,27 +84,32 @@ bool KNGroup::readInfo(const QString &confPath)
 {
   KSimpleConfig info(confPath);
 
-  /*if(tmp.isEmpty()) {
-    tmp=info.deleteEntry("name", false);
-    info.writeEntry("groupname", tmp);
-    kdDebug(5003) << "Group info-file converted" << endl;
-    info.sync();
-  }*/
-  
-  g_roupname = info.readEntry("groupname").local8Bit();
-  d_escription = info.readEntry("description").local8Bit();
+  g_roupname = info.readEntry("groupname");
+  d_escription = info.readEntry("description");
   n_ame = info.readEntry("name");
   c_ount = info.readNumEntry("count",0);
   r_eadCount = info.readNumEntry("read",0);
   l_astNr = info.readNumEntry("lastMsg",0);
+  u_seCharset = info.readBoolEntry("useCharset", false);
+  d_efaultChSet = info.readEntry("defaultChSet").latin1();
+  QString s = info.readEntry("status","unknown");
+  if (s=="readOnly")
+    s_tatus = readOnly;
+  else if (s=="postingAllowed")
+    s_tatus = postingAllowed;
+  else if (s=="moderated")
+    s_tatus = moderated;
+  else
+    s_tatus = unknown;
 
-  u_ser=new KNUserEntry();
-  u_ser->load(&info);
-  if(!u_ser->isEmpty()) {
-    kdDebug(5003) << "using alternative user for " << g_roupname.data() << endl;
-  } else {
-    delete u_ser;
-    u_ser=0;
+  i_dentity=new KNConfig::Identity(false);
+  i_dentity->loadConfig(&info);
+  if(!i_dentity->isEmpty()) {
+    kdDebug(5003) << "KNGroup::readInfo(const QString &confPath) : using alternative user for " << g_roupname << endl;
+  }
+  else {
+    delete i_dentity;
+    i_dentity=0;
   }
   
   return (!g_roupname.isEmpty());
@@ -115,22 +122,37 @@ void KNGroup::saveInfo()
   QString dir(path());
   
   if (dir != QString::null){
-    KSimpleConfig info(dir+QString(g_roupname)+".grpinfo");
+    KSimpleConfig info(dir+g_roupname+".grpinfo");
   
-    info.writeEntry("groupname", QString(g_roupname));
-    info.writeEntry("description", QString(d_escription));
+    info.writeEntry("groupname", g_roupname);
+    info.writeEntry("description", d_escription);
     info.writeEntry("lastMsg", l_astNr);
     info.writeEntry("count", c_ount);
     info.writeEntry("read", r_eadCount);
     info.writeEntry("name", n_ame);
-  
-    if(u_ser) u_ser->save(&info);
+    info.writeEntry("useCharset", u_seCharset);
+    info.writeEntry("defaultChSet", QString::fromLatin1(d_efaultChSet));
+    switch (s_tatus) {
+      case unknown: info.writeEntry("status","unknown");
+                    break;
+      case readOnly: info.writeEntry("status","readOnly");
+                     break;
+      case postingAllowed: info.writeEntry("status","postingAllowed");
+                           break;
+      case moderated: info.writeEntry("status","moderated");
+                           break;
+    }
+
+    if(i_dentity)
+      i_dentity->saveConfig(&info);
     else if(info.hasKey("Email")) {
       info.deleteEntry("Name", false);
       info.deleteEntry("Email", false);
       info.deleteEntry("Reply-To", false);
       info.deleteEntry("Org", false);
+      info.deleteEntry("UseSigFile", false);
       info.deleteEntry("sigFile", false);
+      info.deleteEntry("sigText", false);
     }
   }
 }
@@ -147,10 +169,10 @@ KNNntpAccount* KNGroup::account()
 
 
 
-KNFetchArticle* KNGroup::byId(int id)
+KNRemoteArticle* KNGroup::byId(int id)
 {
   int idx=findId(id);
-  if(idx!=-1) return ((KNFetchArticle*)list[idx]);
+  if(idx!=-1) return ( static_cast<KNRemoteArticle*> (list[idx]) );
   else return 0;
 }
 
@@ -165,15 +187,16 @@ bool KNGroup::loadHdrs()
     KNStringSplitter split;
     int cnt=0, id, lines;
     time_t timeT;//, fTimeT;
-    KNFetchArticle *art;
+    KNRemoteArticle *art;
 
     QString dir(path());
     if (dir == QString::null)
       return false;
       
-    f.setName(dir+QString(g_roupname)+".static");
-      
+    f.setName(dir+g_roupname+".static");
+
     if(f.open(IO_ReadOnly)) {
+
       if(!resize(c_ount)) {
         f.close();
         return false;
@@ -193,49 +216,30 @@ bool KNGroup::loadHdrs()
         }
         
         split.init(buff, "\t");
-        art=new KNFetchArticle(this);
+
+        art=new KNRemoteArticle(this);
+
         split.first();
-        art->setMessageId(split.string());
+        art->messageID()->from7BitString(split.string());
     
         split.next();
-        art->setSubject(split.string());
+        art->subject()->from7BitString(split.string());
         
         split.next();
-        art->setFromEmail(split.string());
-    
+        art->from()->setEmail(split.string());
         split.next();
-        if(split.string()!="0") art->setFromName(split.string());
-        else {
-          art->setFromName(art->fromEmail());
-        }
-          
-        /*split.init(f.readLine(), ";");
-      
-        bool isRef=split.first(); 
-    
-        if(isRef){
-                
-          int RefNr=0;
-        
-          while(isRef && RefNr<5) {
-            art->setReference(RefNr, split.string());
-            isRef=split.next();
-            RefNr++;
-          }
-        }*/
-        
+        if(split.string()!="0")
+          art->from()->setNameFrom7Bit(split.string());
+
         buff=f.readLine();
-        if(!buff.isEmpty()) art->references().setLine(buff.copy());
+        if(buff!="0") art->references()->from7BitString(buff.copy());
                       
         buff=f.readLine();
-        sscanf(buff,"%d %d %d", &id, &lines, (uint*) &timeT);//, (uint*) &fTimeT);
-        //kdDebug(5003) << "id = " << id << endl;
-      
+        sscanf(buff,"%d %d %u", &id, &lines, (uint*) &timeT);
         art->setId(id);
-        art->setLines(lines);
-        art->setTimeT(timeT);
-        //art->setFetchTime(fTimeT);
-                
+        art->lines()->setNumberOfLines(lines);
+        art->date()->setUnixTime(timeT);
+
         if(append(art)) cnt++;
         else {
           f.close();
@@ -253,7 +257,7 @@ bool KNGroup::loadHdrs()
     } 
     
   
-    f.setName(dir+QString(g_roupname)+".dynamic");
+    f.setName(dir+g_roupname+".dynamic");
   
     if (f.open(IO_ReadOnly)) {
   
@@ -313,66 +317,73 @@ bool KNGroup::loadHdrs()
 
 
 // Attention: this method is called from the network thread!
-void KNGroup::insortNewHeaders(QStrList *hdrs)
+void KNGroup::insortNewHeaders(QStrList *hdrs, KNProtocolClient *client)
 {
-  KNFetchArticle *art=0;
+  KNRemoteArticle *art=0;
   QCString tmp;
-  //DwDateTime dt;
-  //time_t fTimeT=dt.AsUnixTime();
   KNStringSplitter split;
   split.setIncludeSep(false);
-  int cnt=0;
-  
+  int cnt=0,todo=hdrs->count();
+  QTime timer;
+
+  timer.start();
+
   //resize the list 
   if(!resize(siz+hdrs->count())) return;
-  
+
   for(char *line=hdrs->first(); line; line=hdrs->next()) {
     split.init(line, "\t");
       
     //new Header-Object
-    art=new KNFetchArticle(this);
+    art=new KNRemoteArticle(this);
     art->setNew(true);
-    //art->setFetchTime(fTimeT);
-        
+
     //Article Number
     split.first();
     // ignored hdr->artNr=split.string().toInt();
-    
+
     //Subject
     split.next();
-    art->setSubject(split.string());
-    if(art->subject().isEmpty()) art->setSubject(i18n("no subject").local8Bit());
+    art->subject()->from7BitString(split.string());
+    if(art->subject()->isEmpty())
+      art->subject()->fromUnicodeString(i18n("no subject"), art->defaultCharset());
     
     //From and Email
     split.next();
-    art->parseFrom(split.string());
+    art->from()->from7BitString(split.string());
         
     //Date
     split.next();
-    art->parseDate(split.string());
+    art->date()->from7BitString(split.string());
                     
     //Message-ID
     split.next();
-    art->setMessageId(split.string().simplifyWhiteSpace());
+    art->messageID()->from7BitString(split.string().simplifyWhiteSpace());
       
     //References
     split.next();
     if(!split.string().isEmpty())
-      art->references().setLine(split.string().copy());
+      art->references()->from7BitString(split.string()); //use QCString::copy() ?
     
     //Lines
     split.next();
     split.next();
-    art->setLines(split.string().toInt());      
+    art->lines()->setNumberOfLines(split.string().toInt());
         
     if(append(art)) cnt++;
     else {
       delete art;
       return;
     }
+
+    if (timer.elapsed() > 200) {           // don't flicker
+      timer.restart();
+      if (client) client->updatePercentage((cnt*30)/todo);
+    }
   }
-  
-  sortHdrs(cnt);
+
+  sortHdrs(cnt,client);
+
   int count = saveStaticData(cnt);
 #ifndef NDEBUG
   qDebug("knode: %d headers wrote to file",count);
@@ -390,13 +401,13 @@ void KNGroup::insortNewHeaders(QStrList *hdrs)
 int KNGroup::saveStaticData(int cnt,bool ovr)
 {
   int idx, savedCnt=0, mode;
-  KNFetchArticle *art;
+  KNRemoteArticle *art;
   
   QString dir(path());
   if (dir == QString::null)
     return 0;
   
-  QFile f(dir+QString(g_roupname)+".static");
+  QFile f(dir+g_roupname+".static");
   
   if(ovr) mode=IO_WriteOnly;
   else mode=IO_WriteOnly | IO_Append;
@@ -404,39 +415,37 @@ int KNGroup::saveStaticData(int cnt,bool ovr)
   if(f.open(mode)) {
   
     QTextStream ts(&f);
-    ts.setEncoding(QTextStream::Latin1);
     
     for(idx=len-cnt; idx<len; idx++) {
             
       art=at(idx);    
       
-      if(!art->hasData()) continue;
+      if(art->subject()->isEmpty()) continue;
     
-      ts << art->messageId() << '\t';
-      ts << art->subject() << '\t';
-      ts << art->fromEmail() << '\t';
+      ts << art->messageID()->as7BitString(false) << '\t';
+      ts << art->subject()->as7BitString(false) << '\t';
+      ts << art->from()->email() << '\t';
 
-      if(art->fromEmail().nrefs()==1)
-        ts << art->fromName() << '\n';
+      if(art->from()->hasName())
+        ts << art->from()->nameAs7Bit() << '\n';
       else
         ts << "0\n";
           
-      if(art->hasReferences())
-        ts << art->references().line() << "\n";
+      if(!art->references()->isEmpty())
+        ts << art->references()->as7BitString(false) << "\n";
       else
         ts << "0\n";
     
       ts << art->id() << ' ';
-      ts << art->lines() << ' ';
-      ts << art->timeT() << '\n';
-      //ts << art->fetchTime() << '\n';
+      ts << art->lines()->numberOfLines() << ' ';
+      ts << art->date()->unixTime() << '\n';
+
     
       savedCnt++;
       
     }
   
     f.close();
-    
   }
   
   return savedCnt;
@@ -448,14 +457,14 @@ void KNGroup::saveDynamicData(int cnt,bool ovr)
 {
   dynData data;
   int mode;
-  KNFetchArticle *art;  
+  KNRemoteArticle *art;
   
   if(len>0) {
     QString dir(path());
     if (dir == QString::null)
       return;
     
-    QFile f(dir+QString(g_roupname)+".dynamic");      
+    QFile f(dir+g_roupname+".dynamic");
     
     if(ovr) mode=IO_WriteOnly;
     else mode=IO_WriteOnly | IO_Append;
@@ -464,7 +473,7 @@ void KNGroup::saveDynamicData(int cnt,bool ovr)
         
       for(int idx=len-cnt; idx<len; idx++) {    
         art=at(idx);  
-        if(!art->hasData()) continue;
+        if(art->subject()->isEmpty()) continue;
         data.setData(art);
         f.writeBlock((char*)(&data), sizeof(dynData));
       }
@@ -480,7 +489,7 @@ void KNGroup::syncDynamicData()
 {
   dynData data;
   int cnt=0, readCnt=0, sOfData;
-  KNFetchArticle *art;
+  KNRemoteArticle *art;
   
   if(len>0) {
 
@@ -488,7 +497,7 @@ void KNGroup::syncDynamicData()
     if (dir == QString::null)
       return;
     
-    QFile f(dir+QString::fromLatin1(g_roupname)+".dynamic");
+    QFile f(dir+g_roupname+".dynamic");
         
     if(f.open(IO_ReadWrite)) {
       
@@ -497,13 +506,13 @@ void KNGroup::syncDynamicData()
       for(int i=0; i<len; i++) {
         art=at(i);
         
-        if(art->hasChanged() && art->hasData()) {
+        if(art->hasChanged() && !art->subject()->isEmpty()) {
           
           data.setData(art);
           f.at(i*sOfData);
           f.writeBlock((char*) &data, sOfData);
           cnt++;
-          art->setHasChanged(false);
+          art->setChanged(false);
         }
       
         if(art->isRead()) readCnt++;
@@ -521,16 +530,22 @@ void KNGroup::syncDynamicData()
 
 
 
-void KNGroup::sortHdrs(int cnt)
+void KNGroup::sortHdrs(int cnt, KNProtocolClient *client)
 {
   int end=len,
       start=len-cnt,
       foundCnt_1=0, foundCnt_2=0, bySubCnt=0, refCnt=0,
       resortCnt=0, idx, oldRef, idRef;
-  KNFetchArticle *art;
-  
-  kdDebug(5003) << "KNGroup::sortHdrs() : start = " << start << "   end = " << end << endl;
-  
+  KNRemoteArticle *art;
+  QTime timer;
+
+  timer.start();
+
+  // this method is called from the nntp-thread!!!
+#ifndef NDEBUG
+  qDebug("knode: KNGroup::sortHdrs() : start = %d  end = %d",start,end);
+#endif
+
   //resort old hdrs
   if(start>0)
     for(idx=0; idx<start; idx++) {
@@ -538,9 +553,12 @@ void KNGroup::sortHdrs(int cnt)
       if(art->threadingLevel()>1) {
         oldRef=art->idRef();
         if(findRef(art, start, end)!=-1) {
-          kdDebug(5003) << art->id() << " : old " << oldRef << "    new " << art->idRef() << "\n" << endl;
+          // this method is called from the nntp-thread!!!
+          #ifndef NDEBUG
+          qDebug("knode: %d: old %d  new %d",art->id(), oldRef, art->idRef());
+          #endif
           resortCnt++;
-          art->setHasChanged(true);
+          art->setChanged(true);
         }
       }
     }
@@ -550,7 +568,7 @@ void KNGroup::sortHdrs(int cnt)
   
     art=at(idx);
     
-    if(art->hasReferences() && art->idRef()==-1){   //hdr has references
+    if(art->idRef()==-1 && !art->references()->isEmpty() ){   //hdr has references
       refCnt++;
       
       if(findRef(art, start, end)!=-1)  foundCnt_1++;   //scan new hdrs
@@ -559,20 +577,25 @@ void KNGroup::sortHdrs(int cnt)
           foundCnt_2++;
     }
     else {
-      if(strncasecmp(art->subject(),"Re:",3)!=0) {
+      if(art->subject()->isReply()) {
         art->setIdRef(0); //hdr has no references
         art->setThreadingLevel(0);
       }
       else if(art->idRef()==-1) refCnt++;
     }
+
+    if (timer.elapsed() > 200) {           // don't flicker
+      timer.restart();
+      if (client) client->updatePercentage(30+((foundCnt_1+foundCnt_2)*70)/cnt);
+    }
   }
   
     
   if((foundCnt_1+foundCnt_2)<refCnt) {    // if some references could not be found
   
     //try to sort by subject
-    KNFetchArticle *oldest; 
-    QList<KNFetchArticle> list;
+    KNRemoteArticle *oldest;
+    QList<KNRemoteArticle> list;
     list.setAutoDelete(false);
       
     for(idx=start; idx<end; idx++) {
@@ -599,15 +622,15 @@ void KNGroup::sortHdrs(int cnt)
       
           //find oldest
           oldest=list.first();
-          for(KNFetchArticle *var=list.next(); var; var=list.next())
-            if(var->timeT() < oldest->timeT()) oldest=var;
+          for(KNRemoteArticle *var=list.next(); var; var=list.next())
+            if(var->date()->unixTime() < oldest->date()->unixTime()) oldest=var;
           
           //oldest gets idRef 0 
           if(oldest->idRef()==-1) bySubCnt++;
           oldest->setIdRef(0);
           oldest->setThreadingLevel(6);   
           
-          for(KNFetchArticle *var=list.first(); var; var=list.next()) {
+          for(KNRemoteArticle *var=list.first(); var; var=list.next()) {
             if(var==oldest) continue;
             else if(var->idRef()==-1 || (var->idRef()!=-1 && var->threadingLevel()==6)) {
               var->setIdRef(oldest->id());
@@ -617,11 +640,14 @@ void KNGroup::sortHdrs(int cnt)
           }
         }
       }
+
+      if (timer.elapsed() > 200) {           // don't flicker
+        timer.restart();
+        if (client) client->updatePercentage(30+((bySubCnt+foundCnt_1+foundCnt_2)*70)/cnt);
+      }
     } 
   }
-  
-  
-  
+
   //all not found items get refID 0
   for (int idx=start; idx<end; idx++){
     art=at(idx);
@@ -647,7 +673,10 @@ void KNGroup::sortHdrs(int cnt)
     }
     
     if(isLoop) {
-      kdDebug(5003) << "Sorting : loop in " << hList[idx]->id << endl;
+      // this method is called from the nntp-thread!!!
+      #ifndef NDEBUG
+      qDebug("knode: Sorting : loop in %d",hList[idx]->id);
+      #endif
       hList[idx]->idRef=0;
       hList[idx]->thrLevel=0;
     }
@@ -670,29 +699,31 @@ void KNGroup::sortHdrs(int cnt)
     }
   }
   
-  
-  kdDebug(5003) << "Sorting : " << resortCnt << " headers resorted" << endl;
-  kdDebug(5003) << "Sorting : " << foundCnt_1 << " references of " << refCnt << " found in step 1" << endl;
-  kdDebug(5003) << "Sorting : " << foundCnt_2 << " references of " << refCnt << " found in step 2" << endl;
-  kdDebug(5003) << "Sorting : " << bySubCnt << " references of " << refCnt << " sorted by subject" << endl;
+  // this method is called from the nntp-thread!!!
+#ifndef NDEBUG
+  qDebug("knode: Sorting : %d headers resorted", resortCnt);
+  qDebug("knode: Sorting : %d references of %d found in step 1", foundCnt_1, refCnt);
+  qDebug("knode: Sorting : %d references of %d found in step 2", foundCnt_2, refCnt);
+  qDebug("knode: Sorting : %d references of %d sorted by subject", bySubCnt, refCnt);
+#endif
     
 }
 
 
 
-int KNGroup::findRef(KNFetchArticle *a, int from, int to, bool reverse)
+int KNGroup::findRef(KNRemoteArticle *a, int from, int to, bool reverse)
 {
   bool found=false;
   int foundID=-1, idx=0;
   short refNr=0;
   QCString ref;
-  ref=a->references().first();  
+  ref=a->references()->first();
   
   if(!reverse){
     
     while(!found && !ref.isNull() && refNr < SORT_DEPTH) {
       for(idx=from; idx<to; idx++) {
-        if(at(idx)->messageId()==ref) {
+        if(at(idx)->messageID()->as7BitString(false)==ref) {
           found=true;
           foundID=at(idx)->id();
           a->setThreadingLevel(refNr+1);
@@ -700,13 +731,13 @@ int KNGroup::findRef(KNFetchArticle *a, int from, int to, bool reverse)
         }
       }
       ++refNr;
-      ref=a->references().next();
+      ref=a->references()->next();
     }
   }
   else {
     while(!found && !ref.isNull() && refNr < SORT_DEPTH) {
       for(idx=to; idx>=from; idx--) {
-        if(at(idx)->messageId()==ref){
+        if(at(idx)->messageID()->as7BitString(false)==ref){
           found=true;
           foundID=at(idx)->id();
           a->setThreadingLevel(refNr+1);
@@ -714,7 +745,7 @@ int KNGroup::findRef(KNFetchArticle *a, int from, int to, bool reverse)
         }
       }
       ++refNr;
-      ref=a->references().next();
+      ref=a->references()->next();
     }
   }
       
@@ -723,23 +754,25 @@ int KNGroup::findRef(KNFetchArticle *a, int from, int to, bool reverse)
 }
 
 
-
-void KNGroup::resort()
+void KNGroup::reorganize()
 {
+  kdDebug(5003) << "KNGroup::reorganize()" << endl;
+
   for(int idx=0; idx<len; idx++) {
+    at(idx)->setId(idx+1); //new ids
     at(idx)->setIdRef(-1);
     at(idx)->setThreadingLevel(0);
   }
-  kdDebug(5003) << "KNGroup::resort()" << endl;
+
   sortHdrs(len);
+  saveStaticData(len, true);
   saveDynamicData(len, true);
 }
 
 
-
 void KNGroup::updateThreadInfo()
 {
-  KNFetchArticle *ref;
+  KNRemoteArticle *ref;
   bool brokenThread=false;
   
   for(int idx=0; idx<len; idx++) {
@@ -766,8 +799,8 @@ void KNGroup::updateThreadInfo()
   }
 
   if(brokenThread) {
-    kdWarning(5003) << "KNGroup::updateThreadInfo() : Found broken threading infos !! Restoring ..." << endl;
-    resort();
+    kdWarning(5003) << "KNGroup::updateThreadInfo() : Found broken threading infos! Restoring ..." << endl;
+    reorganize();
     updateThreadInfo();
   }
 }
@@ -775,12 +808,12 @@ void KNGroup::updateThreadInfo()
 
 
 
-KNFetchArticle* KNGroup::byMessageId(const QCString &mId)
+KNRemoteArticle* KNGroup::byMessageId(const QCString &mId)
 {
-  KNFetchArticle *ret=0;
+  KNRemoteArticle *ret=0;
   
   for(int i=0; i<len; i++) {
-    if(at(i)->messageId()==mId) {
+    if(at(i)->messageID()->as7BitString(false)==mId) {
       ret=at(i);
       break;
     }
@@ -792,17 +825,18 @@ KNFetchArticle* KNGroup::byMessageId(const QCString &mId)
 
 void KNGroup::showProperties()
 {
-  if(!u_ser) u_ser=new KNUserEntry();
+  if(!i_dentity) i_dentity=new KNConfig::Identity(false);
   KNGroupPropDlg *d=new KNGroupPropDlg(this, knGlobals.topWidget);
   
   if(d->exec())
     if(d->nickHasChanged())
       l_istItem->setText(0, name());
 
-  if(u_ser->isEmpty()) {
-    delete u_ser;
-    u_ser=0;
+  if(i_dentity->isEmpty()) {
+    delete i_dentity;
+    i_dentity=0;
   }
+
   delete d;
 }
 
@@ -828,7 +862,7 @@ int KNGroup::statThrWithUnread()
 
 
 
-void KNGroup::dynData::setData(KNFetchArticle *a)
+void KNGroup::dynData::setData(KNRemoteArticle *a)
 {
   id=a->id();
   idRef=a->idRef();
