@@ -1,19 +1,18 @@
-/***************************************************************************
-                          kngroupmanager.cpp  -  description
-                             -------------------
+/*
+    kngroupmanager.cpp
 
-    copyright            : (C) 2000 by Christian Thurner
-    email                : cthurner@freepage.de
- ***************************************************************************/
+    KNode, the KDE newsreader
+    Copyright (c) 1999-2000 the KNode authors.
+    See file AUTHORS for details
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software Foundation,
+    Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, US
+*/
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -27,22 +26,24 @@
 #include <kurl.h>
 #include <kiconloader.h>
 #include <kdebug.h>
+#include <kcharsets.h>
 
-#include "knpurgeprogressdialog.h"
 #include "knode.h"
-#include "knfetcharticlemanager.h"
+#include "knarticlemanager.h"
 #include "knjobdata.h"
 #include "kngroupdialog.h"
 #include "kngroup.h"
 #include "kncollectionviewitem.h"
 #include "knnntpaccount.h"
+#include "knprotocolclient.h"
 #include "kncleanup.h"
-#include "knuserentry.h"
 #include "knnetaccess.h"
 #include "knglobals.h"
+#include "knconfigmanager.h"
 #include "resource.h"
 #include "utilities.h"
 #include "knarticlewindow.h"
+#include "knarticlewidget.h"
 #include "kngroupmanager.h"
 
 
@@ -57,8 +58,9 @@ KNGroupInfo::KNGroupInfo()
 }
 
 
-KNGroupInfo::KNGroupInfo(const char *n_ame, const char *d_escription, bool n_ewGroup, bool s_ubscribed)
-  : name(n_ame), description(d_escription), newGroup(n_ewGroup), subscribed(s_ubscribed)
+KNGroupInfo::KNGroupInfo(const QString &n_ame, const QString &d_escription, bool n_ewGroup, bool s_ubscribed, KNGroup::Status s_tatus)
+  : name(n_ame), description(d_escription), newGroup(n_ewGroup), subscribed(s_ubscribed),
+    status(s_tatus)
 {
 }
 
@@ -84,6 +86,7 @@ bool KNGroupInfo::operator< (const KNGroupInfo &gi2)
 
 
 KNGroupListData::KNGroupListData()
+  : codecForDescriptions(0)
 {
   groups = new QSortedList<KNGroupInfo>;
   groups->setAutoDelete(true);
@@ -98,36 +101,62 @@ KNGroupListData::~KNGroupListData()
 
 
 
-bool KNGroupListData::readIn()
+bool KNGroupListData::readIn(KNProtocolClient *client)
 {
   KNFile f(path+"groups");
-  QCString line,name;
-  int sepPos;
+  QCString line;
+  int sepPos1,sepPos2;
+  QString name,description;
+  bool sub;
+  KNGroup::Status status=KNGroup::unknown;
+  QTime timer;
+  uint size=f.size()+2;
+
+  timer.start();
+  if (client) client->updatePercentage(0);
 
   if(f.open(IO_ReadOnly)) {
     while(!f.atEnd()) {
       line = f.readLine();
-      sepPos = line.find(' ');
-
-      if (sepPos==-1) {        // no description
-
-        if (subscribed.contains(line)) {
-          subscribed.remove(line);    // group names are unique, we wont find it again anyway...
-          groups->append(new KNGroupInfo(line,"",false,true));
-        } else {
-          groups->append(new KNGroupInfo(line,"",false,false));
-        }
+      sepPos1 = line.find(' ');
 
+      if (sepPos1==-1) {        // no description
+        name = QString::fromUtf8(line);
+        description = QString::null;
+        status = KNGroup::unknown;
       } else {
-        name = line.left(sepPos);
+        name = QString::fromUtf8(line.left(sepPos1));
 
-        if (subscribed.contains(name)) {
-          subscribed.remove(name);    // group names are unique, we wont find it again anyway...
-          groups->append(new KNGroupInfo(name,line.right(line.length()-sepPos-1),false,true));
+        sepPos2 = line.find(' ',sepPos1+1);
+        if (sepPos2==-1) {        // no status
+          description = QString::fromUtf8(line.right(line.length()-sepPos1-1));
+          status = KNGroup::unknown;
         } else {
-          groups->append(new KNGroupInfo(name,line.right(line.length()-sepPos-1),false,false));
+          description = QString::fromUtf8(line.right(line.length()-sepPos2-1));
+          switch (line[sepPos1+1]) {
+            case 'u':   status = KNGroup::unknown;
+                        break;
+            case 'n':   status = KNGroup::readOnly;
+                        break;
+            case 'y':   status = KNGroup::postingAllowed;
+                        break;
+            case 'm':   status = KNGroup::moderated;
+                        break;
+          }
         }
+      }
 
+      if (subscribed.contains(name)) {
+        subscribed.remove(name);    // group names are unique, we wont find it again anyway...
+        sub = true;
+      } else
+        sub = false;
+
+      groups->append(new KNGroupInfo(name,description,false,sub,status));
+
+      if (timer.elapsed() > 200) {           // don't flicker
+        timer.restart();
+        if (client) client->updatePercentage((f.at()*100)/size);
       }
     }
 
@@ -148,9 +177,20 @@ bool KNGroupListData::writeOut()
 
   if(f.open(IO_WriteOnly)) {
     for (KNGroupInfo *i=groups->first(); i; i=groups->next()) {
-      temp = i->name + " " + i->description + "\n";
+      temp = i->name.utf8();
+      switch (i->status) {
+        case KNGroup::unknown: temp += " u ";
+                               break;
+        case KNGroup::readOnly: temp += " n ";
+                                break;
+        case KNGroup::postingAllowed: temp += " y ";
+                                      break;
+        case KNGroup::moderated: temp += " m ";
+                                 break;
+      }
+      temp += i->description.utf8() + "\n";
       f.writeBlock(temp.data(),temp.length());
-    }         
+    }
     f.close();
     return true;
   } else {
@@ -173,7 +213,7 @@ void KNGroupListData::merge(QSortedList<KNGroupInfo>* newGroups)
       groups->remove();   // avoid duplicates
     } else
       subscribed = false;
-    groups->append(new KNGroupInfo(i->name,i->description,true,subscribed));
+    groups->append(new KNGroupInfo(i->name,i->description,true,subscribed,i->status));
   }   
 
   groups->sort();
@@ -191,75 +231,27 @@ QSortedList<KNGroupInfo>* KNGroupListData::extractList()
 //===============================================================================
 
 
-KNGroupManager::KNGroupManager(KNFetchArticleManager *a, KActionCollection* actColl, QObject * parent, const char * name)
-  : QObject(parent,name), aManager(a), actionCollection(actColl)
+
+KNGroupManager::KNGroupManager(KNArticleManager *a, QObject * parent, const char * name)
+  : QObject(parent,name)
 {
-  gList=new QList<KNGroup>;
-  gList->setAutoDelete(true);
-    
-  readConfig(); 
-  
-  actProperties = new KAction(i18n("&Properties..."), 0, this, SLOT(slotProperties()),
-                              actionCollection, "group_properties");
-  actLoadHdrs = new KAction(i18n("&Get New Articles"), "mail_get" , 0, this, SLOT(slotLoadHdrs()),
-                            actionCollection, "group_dnlHeaders");
-  actExpire = new KAction(i18n("E&xpire Now"), "wizard", 0, this, SLOT(slotExpire()),
-                          actionCollection, "group_expire");
-  actResort = new KAction(i18n("Res&ort"), 0, this, SLOT(slotResort()),
-                          actionCollection, "group_resort");
-  actUnsubscribe = new KAction(i18n("&Unsubscribe"), 0, this, SLOT(slotUnsubscribe()),
-                               actionCollection, "group_unsubscribe");
-  
-  setCurrentGroup(0);
+  g_List=new QList<KNGroup>;
+  g_List->setAutoDelete(true);
+  c_urrentGroup=0;
+  a_rticleMgr=a;
 }
 
 
 
 KNGroupManager::~KNGroupManager()
 {
-  delete gList;
+  delete g_List;
 }
 
 
-
-void KNGroupManager::readConfig()
-{
-  KConfig *conf=KGlobal::config();
-  conf->setGroup("READNEWS");
-  a_utoCheck=conf->readBoolEntry("autoCheck",true);
-  defaultMaxFetch=conf->readNumEntry("maxFetch", 1000);
-}
-
-
-
-bool KNGroupManager::timeToExpire()
-{
-  KConfig *c=KGlobal::config();
-  c->setGroup("EXPIRE");
-  
-  if (!c->readBoolEntry("doExpire", true))
-    return false;
-
-  QDate today=QDate::currentDate();
-  QDate lastExpDate=c->readDateTimeEntry("lastExpire").date();
-  int interval=c->readNumEntry("expInterval", 5);
-  
-  if (lastExpDate==today) {
-    c->writeEntry("lastExpire", QDateTime::currentDateTime());  // important! otherwise lastExpDate will be at its default value (current date) forever
-    return false;
-  }
-
-  if(lastExpDate.daysTo(today) >= interval)
-    return true;
-  else
-    return false;
-}
-
-
-
 void KNGroupManager::syncGroups()
 {
-  for(KNGroup *var=gList->first(); var; var=gList->next()) {
+  for(KNGroup *var=g_List->first(); var; var=g_List->next()) {
     var->syncDynamicData();
     var->saveInfo();
   }
@@ -270,7 +262,8 @@ void KNGroupManager::syncGroups()
 void KNGroupManager::loadGroups(KNNntpAccount *a)
 {   
   KNGroup *group;
-  
+  KNConfig::Appearance *app=knGlobals.cfgManager->appearance();
+
   QString dir(a->path());
   if (dir == QString::null)
     return;
@@ -280,9 +273,9 @@ void KNGroupManager::loadGroups(KNNntpAccount *a)
   for(QStringList::Iterator it=entries.begin(); it != entries.end(); it++) {
     group=new KNGroup(a);
     if (group->readInfo(dir+(*it))) {
-      gList->append(group);
+      g_List->append(group);
       KNCollectionViewItem *cvit=new KNCollectionViewItem(a->listItem());
-      cvit->setPixmap(0, KNLVItemBase::icon(KNLVItemBase::PTgroup));
+      cvit->setPixmap(0, app->icon(KNConfig::Appearance::group));
       group->setListItem(cvit);
       group->updateListItem();
     } else {
@@ -294,11 +287,11 @@ void KNGroupManager::loadGroups(KNNntpAccount *a)
 
 
 
-void KNGroupManager::getSubscribed(KNNntpAccount *a, QStrList* l)
+void KNGroupManager::getSubscribed(KNNntpAccount *a, QStringList &l)
 {
-  l->clear();
-  for(KNGroup *var=gList->first(); var; var=gList->next()) {
-    if(var->account()==a) l->append(var->groupname());
+  l.clear();
+  for(KNGroup *var=g_List->first(); var; var=g_List->next()) {
+    if(var->account()==a) l.append(var->groupname());
   }
 }
 
@@ -307,52 +300,31 @@ void KNGroupManager::getSubscribed(KNNntpAccount *a, QStrList* l)
 void KNGroupManager::getGroupsOfAccount(KNNntpAccount *a, QList<KNGroup> *l)
 {
   l->clear();
-  for(KNGroup *var=gList->first(); var; var=gList->next()) {
+  for(KNGroup *var=g_List->first(); var; var=g_List->next()) {
     if(var->account()==a) l->append(var);
   }
 }
 
 
 
-KNGroup* KNGroupManager::group(const QCString &gName, const KNServerInfo *s)
+KNGroup* KNGroupManager::group(const QString &gName, const KNServerInfo *s)
 {
-  for(KNGroup *var=gList->first(); var; var=gList->next())
+  for(KNGroup *var=g_List->first(); var; var=g_List->next())
     if(var->account()==s && var->groupname()==gName) return var;
-  
+
   return 0;
 }
 
 
 
-void KNGroupManager::expireAll(KNPurgeProgressDialog *dlg)
+void KNGroupManager::expireAll(KNCleanUp *cup)
 {
-  KNCleanUp cup;
-  
-  if (dlg) {
-    knGlobals.top->blockUI(true);
-    dlg->init(i18n("Deleting expired articles ..."), gList->count());
-  }
-
-  for(KNGroup *var=gList->first(); var; var=gList->next()) {
-    if((var->locked()) || (var->loading()>0))
+  for(KNGroup *var=g_List->first(); var; var=g_List->next()) {
+    if((var->isLocked()) || (var->lockedArticles()>0))
       continue;
-    if(dlg) {
-      dlg->setInfo(var->groupname());
-      kapp->processEvents();
-    }
-    KNArticleWindow::closeAllWindowsForCollection(var);
-    cup.group(var);
-    kdDebug() << var->groupname() << " => " << cup.deleted() << " expired , " << cup.left() << " left" << endl;
-    if(dlg) dlg->progress();
+
+    cup->appendCollection(var);
   }
-  if (dlg) {
-    knGlobals.top->blockUI(false);
-    kapp->processEvents();
-  }
-  
-  KConfig *c=KGlobal::config();
-  c->setGroup("EXPIRE");
-  c->writeEntry("lastExpire", QDateTime::currentDateTime());
 }
 
 
@@ -360,34 +332,34 @@ void KNGroupManager::expireAll(KNPurgeProgressDialog *dlg)
 void KNGroupManager::showGroupDialog(KNNntpAccount *a, QWidget *parent)
 {
   KNGroupDialog* gDialog=new KNGroupDialog((parent!=0)? parent:knGlobals.topWidget, a);
-  
+
   connect(gDialog, SIGNAL(loadList(KNNntpAccount*)), this, SLOT(slotLoadGroupList(KNNntpAccount*)));
   connect(gDialog, SIGNAL(fetchList(KNNntpAccount*)), this, SLOT(slotFetchGroupList(KNNntpAccount*)));
   connect(gDialog, SIGNAL(checkNew(KNNntpAccount*,QDate)), this, SLOT(slotCheckForNewGroups(KNNntpAccount*,QDate)));
   connect(this, SIGNAL(newListReady(KNGroupListData*)), gDialog, SLOT(slotReceiveList(KNGroupListData*)));
-    
+
   if(gDialog->exec()) {
     KNGroup *g=0;
-    
-    QStrList lst;
+
+    QStringList lst;
     gDialog->toUnsubscribe(&lst);
     if (lst.count()>0) {
       if (KMessageBox::Yes == KMessageBox::questionYesNoList((parent!=0)? parent:knGlobals.topWidget,i18n("Do you really want to unsubscribe\nfrom these groups?"),
-                                                             QStringList::fromStrList(lst))) {
-        for(char *var=lst.first(); var; var=lst.next()) {
-          if((g=group(var, a)))
+                                                              lst)) {
+        for ( QStringList::Iterator it = lst.begin(); it != lst.end(); ++it ) {
+          if((g=group(*it, a)))
             unsubscribeGroup(g);
         }
       }
     }
-  
+
     QSortedList<KNGroupInfo> lst2;
     gDialog->toSubscribe(&lst2);
     for(KNGroupInfo *var=lst2.first(); var; var=lst2.next()) {
       subscribeGroup(var, a);
     }
-  } 
-    
+  }
+
   delete gDialog;
 }
 
@@ -397,12 +369,13 @@ void KNGroupManager::subscribeGroup(const KNGroupInfo *gi, KNNntpAccount *a)
 {
   KNGroup *grp;
   KNCollectionViewItem *it;
-    
+
   grp=new KNGroup(a);
   grp->setGroupname(gi->name);
-  grp->setDescription(gi->description); 
+  grp->setDescription(gi->description);
+  grp->setStatus(gi->status);
   grp->saveInfo();
-  gList->append(grp);
+  g_List->append(grp);
   it=new KNCollectionViewItem(a->listItem());
   it->setPixmap(0,UserIcon("group"));
   grp->setListItem(it);
@@ -417,15 +390,17 @@ void KNGroupManager::unsubscribeGroup(KNGroup *g)
   if(!g) g=c_urrentGroup;
   if(!g) return;
 
-  if((g->locked()) || (g->loading()>0)) {
+
+  if((g->isLocked()) || (g->lockedArticles()>0)) {
     KMessageBox::sorry(knGlobals.topWidget, QString(i18n("The group \"%1\" is being updated currently.\nIt is not possible to unsubscribe it at the moment.")).arg(g->groupname()));
     return;
   }
 
   KNArticleWindow::closeAllWindowsForCollection(g);
+  KNArticleWidget::collectionRemoved(g);
 
   acc=g->account();
-  
+
   QDir dir(acc->path(),g->groupname()+"*");
   if (dir.exists()) {
     const QFileInfoList *list = dir.entryInfoList();  // get list of matching files and delete all
@@ -437,10 +412,13 @@ void KNGroupManager::unsubscribeGroup(KNGroup *g)
       }
     }
     kdDebug(5003) << "Files deleted!" << endl;
-    
-    if(c_urrentGroup==g) setCurrentGroup(0);
-    
-    gList->removeRef(g);
+
+    if(c_urrentGroup==g) {
+      setCurrentGroup(0);
+      a_rticleMgr->updateStatusString();
+    }
+
+    g_List->removeRef(g);
   }
 }
 
@@ -459,79 +437,67 @@ void KNGroupManager::checkGroupForNewHeaders(KNGroup *g)
 {
   if(!g) g=c_urrentGroup;
   if(!g) return;
-  if(g->locked()) {
+  if(g->isLocked()) {
     kdDebug(5003) << "KNGroupManager::setCurrentGroup() : group locked - returning" << endl;
     return;
-  } 
-  g->setMaxFetch(defaultMaxFetch);
-  KNJobData *job=new KNJobData(KNJobData::JTfetchNewHeaders, g->account(), g);
-  knGlobals.netAccess->addJob(job);
+  }
+  g->setMaxFetch(knGlobals.cfgManager->readNewsGeneral()->maxToFetch());
+  emitJob( new KNJobData(KNJobData::JTfetchNewHeaders, this, g->account(), g) );
 }
 
 
 
 void KNGroupManager::expireGroupNow(KNGroup *g)
 {
-  if(!g) g=c_urrentGroup;
   if(!g) return;
 
-  if((g->locked()) || (g->loading()>0)) {
-    // add error message after 2.0!!!!!!!!!
+  if((g->isLocked()) || (g->lockedArticles()>0)) {
+    KMessageBox::sorry(knGlobals.topWidget,
+      i18n("This group cannot be expired because it is currently being updated.\n Please try again later."));
     return;
   }
 
   KNArticleWindow::closeAllWindowsForCollection(g);
 
-  KNCleanUp cup;
-  cup.group(g, true);
-  kdDebug(5003) << "KNExpire: " << g->groupname() << " => " << cup.deleted() << " expired , " << cup.left() << " left" << endl;
-  
-  if(cup.deleted()>0) {
-    g->updateListItem();
-    if(g==c_urrentGroup) {
-      if(g->loadHdrs()) aManager->showHdrs();
-      else aManager->setGroup(0);
-    }
-  }     
+  KNCleanUp cup(knGlobals.cfgManager->cleanup());
+  cup.expireGroup(g, true);
+
+  g->updateListItem();
+  if(g==c_urrentGroup) {
+    if(g->loadHdrs())
+      a_rticleMgr->showHdrs();
+    else
+      a_rticleMgr->setGroup(0);
+  }
 }
 
 
-void KNGroupManager::resortGroup(KNGroup *g)
+void KNGroupManager::reorganizeGroup(KNGroup *g)
 {
   if(!g) g=c_urrentGroup;
   if(!g) return;
-  g->resort();
-  if(g==c_urrentGroup) aManager->showHdrs();
+  g->reorganize();
+  if(g==c_urrentGroup)
+    a_rticleMgr->showHdrs();
 }
 
 
-  
 void KNGroupManager::setCurrentGroup(KNGroup *g)
 {
   c_urrentGroup=g;
-  aManager->setGroup(g);
+  a_rticleMgr->setGroup(g);
   bool loaded;
   kdDebug(5003) << "KNGroupManager::setCurrentGroup() : group changed" << endl;
-  
+
   if (g) {
     loaded=g->loadHdrs();
     if (loaded) {
-      aManager->showHdrs();
-      if(a_utoCheck) checkGroupForNewHeaders(g);
-    } else
+      a_rticleMgr->showHdrs();
+      if(knGlobals.cfgManager->readNewsGeneral()->autoCheckGroups())
+        checkGroupForNewHeaders(g);
+    }
+    else
       KMessageBox::error(knGlobals.topWidget, i18n("Cannot load saved headers"));
-    
-    actProperties->setEnabled(true);
-    actLoadHdrs->setEnabled(true);
-    actExpire->setEnabled(true);
-    actResort->setEnabled(true);
-    actUnsubscribe->setEnabled(true);   
-  } else {
-    actProperties->setEnabled(false);
-    actLoadHdrs->setEnabled(false);
-    actExpire->setEnabled(false);
-    actResort->setEnabled(false);
-    actUnsubscribe->setEnabled(false);    
   }
 }
 
@@ -539,36 +505,34 @@ void KNGroupManager::setCurrentGroup(KNGroup *g)
 
 void KNGroupManager::checkAll(KNNntpAccount *a)
 {
-  KNJobData *j;
   if(!a) return;
-  
-  for(KNGroup *g=gList->first(); g; g=gList->next()) {
+
+  for(KNGroup *g=g_List->first(); g; g=g_List->next()) {
     if(g->account()==a) {
-      g->setMaxFetch(defaultMaxFetch);
-      if(g->loadHdrs()) {
-        j=new KNJobData(KNJobData::JTfetchNewHeaders, a, g);
-        knGlobals.netAccess->addJob(j);
-      }
+      g->setMaxFetch(knGlobals.cfgManager->readNewsGeneral()->maxToFetch());
+      if(g->loadHdrs())
+        emitJob( new KNJobData(KNJobData::JTfetchNewHeaders, this, a, g) );
     }
-  } 
+  }
 }
 
 
 
-void KNGroupManager::jobDone(KNJobData *j)
+void KNGroupManager::processJob(KNJobData *j)
 {
   if((j->type()==KNJobData::JTLoadGroups)||(j->type()==KNJobData::JTFetchGroups)||(j->type()==KNJobData::JTCheckNewGroups)) {
-    KNGroupListData *d=static_cast<KNGroupListData*>(j->data());  
+    KNGroupListData *d=static_cast<KNGroupListData*>(j->data());
 
     if (!j->canceled()) {
       if (j->success()) {
         if ((j->type()==KNJobData::JTFetchGroups)||(j->type()==KNJobData::JTCheckNewGroups)) {
           // update the descriptions of the subscribed groups
-          for(KNGroup *var=gList->first(); var; var=gList->next()) {
+          for(KNGroup *var=g_List->first(); var; var=g_List->next()) {
             if(var->account()==j->account()) {
               for (KNGroupInfo* inf = d->groups->first(); inf; inf=d->groups->next())
                 if (inf->name == var->groupname()) {
-                  var->setDescription(inf->description.copy());
+                  var->setDescription(inf->description);
+                  var->setStatus(inf->status);
                   break;
                 }             
             }
@@ -582,7 +546,9 @@ void KNGroupManager::jobDone(KNJobData *j)
     } else
       emit(newListReady(0));
 
-    delete d;   
+    delete j;
+    delete d;
+
   
   } else {               //KNJobData::JTfetchNewHeaders
     KNGroup *group=static_cast<KNGroup*>(j->data());
@@ -596,10 +562,11 @@ void KNGroupManager::jobDone(KNJobData *j)
       } else
         KMessageBox::error(knGlobals.topWidget, j->errorString());
     }         
-    if(group==c_urrentGroup) aManager->showHdrs(false);         
+    if(group==c_urrentGroup)
+      a_rticleMgr->showHdrs(false);
+    
+    delete j;
   }
-  
-  delete j;
 }
 
 
@@ -621,11 +588,10 @@ void KNGroupManager::slotLoadGroupList(KNNntpAccount *a)
     }
   }
       
-  getSubscribed(a,&(d->subscribed));
+  getSubscribed(a,d->subscribed);
   d->getDescriptions = a->fetchDescriptions();
 
-  KNJobData *job=new KNJobData(KNJobData::JTLoadGroups, a, d);
-  knGlobals.netAccess->addJob(job);
+  emitJob( new KNJobData(KNJobData::JTLoadGroups, this, a, d) );
 }
 
 
@@ -634,11 +600,11 @@ void KNGroupManager::slotFetchGroupList(KNNntpAccount *a)
 {
   KNGroupListData *d = new KNGroupListData();
   d->path = a->path();  
-  getSubscribed(a,&(d->subscribed));
+  getSubscribed(a,d->subscribed);
   d->getDescriptions = a->fetchDescriptions();
+  d->codecForDescriptions=KGlobal::charsets()->codecForName(knGlobals.cfgManager->postNewsTechnical()->charset());
 
-  KNJobData *job=new KNJobData(KNJobData::JTFetchGroups, a, d);
-  knGlobals.netAccess->addJob(job);
+  emitJob( new KNJobData(KNJobData::JTFetchGroups, this, a, d) );
 }
 
 
@@ -647,21 +613,12 @@ void KNGroupManager::slotCheckForNewGroups(KNNntpAccount *a, QDate date)
 {
   KNGroupListData *d = new KNGroupListData();
   d->path = a->path();  
-  getSubscribed(a,&(d->subscribed));
+  getSubscribed(a,d->subscribed);
   d->getDescriptions = a->fetchDescriptions();
   d->fetchSince = date;
+  d->codecForDescriptions=KGlobal::charsets()->codecForName(knGlobals.cfgManager->postNewsTechnical()->charset());
   
-  KNJobData *job=new KNJobData(KNJobData::JTCheckNewGroups, a, d);
-  knGlobals.netAccess->addJob(job);
-}
-
-
-void KNGroupManager::slotUnsubscribe()
-{
-  if (!c_urrentGroup)
-    return;
-  if(KMessageBox::Yes == KMessageBox::questionYesNo(knGlobals.topWidget, i18n("Do you really want to unsubscribe from %1?").arg(c_urrentGroup->groupname())))
-    unsubscribeGroup();
+  emitJob( new KNJobData(KNJobData::JTCheckNewGroups, this, a, d) );
 }
 
 
