@@ -1,19 +1,18 @@
-/***************************************************************************
-                          knnetaccess.cpp  -  description
-                             -------------------
+/*
+    knnetaccess.cpp
 
-    copyright            : (C) 2000 by Christian Thurner
-    email                : cthurner@freepage.de
- ***************************************************************************/
+    KNode, the KDE newsreader
+    Copyright (c) 1999-2000 the KNode authors.
+    See file AUTHORS for details
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software Foundation,
+    Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, US
+*/
 
 #include <pthread.h>
 #include <unistd.h>
@@ -35,8 +34,8 @@
 #include "knnetaccess.h"
 
 
-KNNetAccess::KNNetAccess(KActionCollection* actColl, QObject *parent, const char *name )
-: QObject(parent,name), currentNntpJob(0L), currentSmtpJob(0L), actionCollection(actColl)
+KNNetAccess::KNNetAccess(QObject *parent, const char *name )
+: QObject(parent,name), currentNntpJob(0L), currentSmtpJob(0L)
 {
   if((pipe(nntpInPipe)==-1)||
      (pipe(nntpOutPipe)==-1)||
@@ -76,10 +75,6 @@ KNNetAccess::KNNetAccess(KActionCollection* actColl, QObject *parent, const char
   
   nntpJobQueue.setAutoDelete(false);    
   smtpJobQueue.setAutoDelete(false);    
-  
-  actNetStop = new KAction(i18n("Stop &Network"),"stop",0, this, SLOT(slotCancelAllJobs()),
-                           actionCollection, "net_stop");
-  actNetStop->setEnabled(false);
 }
 
 
@@ -121,12 +116,21 @@ KNNetAccess::~KNNetAccess()
 void KNNetAccess::addJob(KNJobData *job)
 {
   // kdDebug(5003) << "KNNetAccess::addJob() : job queued" << endl;
+  if(job->account()==0) {
+    job->setErrorString(i18n("Internal Error: No account set for this job!"));
+    job->notifyConsumer();
+    return;
+  }
+
   if (job->type()==KNJobData::JTmail) {
-    smtpJobQueue.enqueue(job);
+    smtpJobQueue.append(job);
     if (!currentSmtpJob)   // no active job, start the new one
       startJobSmtp();
   } else {
-    nntpJobQueue.enqueue(job);
+    if (job->type()==KNJobData::JTfetchNewHeaders || job->type()==KNJobData::JTpostArticle)
+      nntpJobQueue.append(job);
+    else
+      nntpJobQueue.prepend(job);
     if (!currentNntpJob)   // no active job, start the new one
       startJobNntp();
   }
@@ -141,19 +145,19 @@ void KNNetAccess::stopJobsNntp(int type)
     currentNntpJob->cancel();
     triggerAsyncThread(nntpOutPipe[1]);
   }
-    
+
   KNJobData *tmp;                          // kill waiting jobs
-  KNJobData *start = nntpJobQueue.head(); 
+  KNJobData *start = nntpJobQueue.first();
   do {
     if (!nntpJobQueue.isEmpty()) {
-      tmp=nntpJobQueue.dequeue();
+      tmp=nntpJobQueue.take(0);
       if ((type==0)||(tmp->type()==type)) {
         tmp->cancel();
-        knGlobals.top->jobDone(tmp);
+        tmp->notifyConsumer();
       } else
-        nntpJobQueue.enqueue(tmp);
+        nntpJobQueue.append(tmp);
     }
-  } while(!nntpJobQueue.isEmpty() && (start != nntpJobQueue.head())); 
+  } while(!nntpJobQueue.isEmpty() && (start != nntpJobQueue.first()));
 }
 
 
@@ -167,17 +171,17 @@ void KNNetAccess::stopJobsSmtp(int type)
   }
     
   KNJobData *tmp;                          // kill waiting jobs
-  KNJobData *start = smtpJobQueue.head(); 
+  KNJobData *start = smtpJobQueue.first();
   do {
     if (!smtpJobQueue.isEmpty()) {
-      tmp=smtpJobQueue.dequeue();
+      tmp=smtpJobQueue.take(0);
       if ((type==0)||(tmp->type()==type)) {
         tmp->cancel();
-        knGlobals.top->jobDone(tmp);
+        tmp->notifyConsumer();
       } else
-        smtpJobQueue.enqueue(tmp);
+        smtpJobQueue.append(tmp);
     }
-  } while(!smtpJobQueue.isEmpty() && (start != smtpJobQueue.head()));
+  } while(!smtpJobQueue.isEmpty() && (start != smtpJobQueue.first()));
 }
 
 
@@ -199,10 +203,10 @@ void KNNetAccess::startJobNntp()
     kdWarning(5003) << "KNNetAccess::startJobNntp(): job queue is empty?? aborting" << endl;
     return;
   }
-  currentNntpJob = nntpJobQueue.dequeue();
+  currentNntpJob = nntpJobQueue.take(0);
   nntpClient->insertJob(currentNntpJob);
   triggerAsyncThread(nntpOutPipe[1]);
-  actNetStop->setEnabled(true);
+  emit netActive(true);
   kdDebug(5003) << "KNNetAccess::startJobNntp(): job started" << endl;
 }
 
@@ -218,10 +222,10 @@ void KNNetAccess::startJobSmtp()
   unshownByteCount = QString::null;
   unshownProgress = 0;
   
-  currentSmtpJob = smtpJobQueue.dequeue();
+  currentSmtpJob = smtpJobQueue.take(0);
   smtpClient->insertJob(currentSmtpJob);
   triggerAsyncThread(smtpOutPipe[1]);
-  actNetStop->setEnabled(true);
+  emit netActive(true);
   kdDebug(5003) << "KNNetAccess::startJobSmtp(): job started" << endl;
 }
 
@@ -241,15 +245,17 @@ void KNNetAccess::threadDoneNntp()
   nntpClient->removeJob();
   currentNntpJob = 0L;
   if (!currentSmtpJob) {
-    actNetStop->setEnabled(false);
+    emit netActive(false);
+    currMsg = QString::null;
     knGlobals.progressBar->disableProgressBar();
     knGlobals.top->setStatusMsg();
   } else {
     knGlobals.progressBar->setProgressBar(unshownProgress,unshownByteCount);
-    knGlobals.top->setStatusMsg(unshownMsg);
+    currMsg = unshownMsg;
+    knGlobals.top->setStatusMsg(currMsg);
   }
   
-  knGlobals.top->jobDone(tmp);  
+  tmp->notifyConsumer();
 
   if (!nntpJobQueue.isEmpty())
     startJobNntp();
@@ -271,12 +277,13 @@ void KNNetAccess::threadDoneSmtp()
   smtpClient->removeJob();
   currentSmtpJob = 0L;
   if (!currentNntpJob) {
-    actNetStop->setEnabled(false);
+    emit netActive(false);
+    currMsg = QString::null;
     knGlobals.progressBar->disableProgressBar();
     knGlobals.top->setStatusMsg();
   }
   
-  knGlobals.top->jobDone(tmp);  
+  tmp->notifyConsumer();
 
   if (!smtpJobQueue.isEmpty())
     startJobSmtp();
@@ -284,6 +291,14 @@ void KNNetAccess::threadDoneSmtp()
 
 
 
+void KNNetAccess::cancelAllJobs()
+{
+  stopJobsNntp(0);
+  stopJobsSmtp(0);
+}
+
+
+
 void KNNetAccess::slotThreadSignal(int i)
 {
   int signal,byteCount;
@@ -301,45 +316,58 @@ void KNNetAccess::slotThreadSignal(int i)
         threadDoneNntp();
       break;
       case KNProtocolClient::TSconnect:
-        knGlobals.top->setStatusMsg(i18n(" Connecting to server..."));
+        currMsg = i18n(" Connecting to server...");
+        knGlobals.top->setStatusMsg(currMsg);
       break;
       case KNProtocolClient::TSloadGrouplist:
-        knGlobals.top->setStatusMsg(i18n(" Loading group list from disk..."));
+        currMsg = i18n(" Loading group list from disk...");
+        knGlobals.top->setStatusMsg(currMsg);
       break;
       case KNProtocolClient::TSwriteGrouplist:
-        knGlobals.top->setStatusMsg(i18n(" Writing group list to disk..."));
+        currMsg = i18n(" Writing group list to disk...");
+        knGlobals.top->setStatusMsg(currMsg);
       break;
       case KNProtocolClient::TSdownloadGrouplist:
-        knGlobals.top->setStatusMsg(i18n(" Downloading group list..."));
+        currMsg = i18n(" Downloading group list...");
+        knGlobals.top->setStatusMsg(currMsg);
       break;
       case KNProtocolClient::TSdownloadNewGroups:
-        knGlobals.top->setStatusMsg(i18n(" Looking for new groups..."));
+        currMsg = i18n(" Looking for new groups...");
+        knGlobals.top->setStatusMsg(currMsg);
       break;      
       case KNProtocolClient::TSdownloadDesc:
-        knGlobals.top->setStatusMsg(i18n(" Downloading group descriptions..."));
+        currMsg = i18n(" Downloading group descriptions...");
+        knGlobals.top->setStatusMsg(currMsg);
       break;      
       case KNProtocolClient::TSdownloadNew:
-        knGlobals.top->setStatusMsg(i18n(" Downloading new headers..."));
+        currMsg = i18n(" Downloading new headers...");
+        knGlobals.top->setStatusMsg(currMsg);
       break;
       case KNProtocolClient::TSsortNew:
-        knGlobals.top->setStatusMsg(i18n(" Sorting..."));
+        currMsg = i18n(" Sorting...");
+        knGlobals.top->setStatusMsg(currMsg);
       break;
       case KNProtocolClient::TSdownloadArticle:
-        knGlobals.top->setStatusMsg(i18n(" Downloading article..."));
+        currMsg = i18n(" Downloading article...");
+        knGlobals.top->setStatusMsg(currMsg);
       break;
       case KNProtocolClient::TSsendArticle:
-        knGlobals.top->setStatusMsg(i18n(" Sending article..."));
+        currMsg = i18n(" Sending article...");
+        knGlobals.top->setStatusMsg(currMsg);
       break;
       case KNProtocolClient::TSjobStarted:
         knGlobals.progressBar->setProgressBar(10, i18n("0 Bytes"));
       break;
       case KNProtocolClient::TSprogressUpdate:
-        byteCount = nntpClient->getByteCount();
-        if (byteCount < 1000)
-          tmp = i18n("%1 Bytes").arg(KGlobal::locale()->formatNumber(byteCount, 0));
-        else
-          tmp = i18n("%1 KB").arg(KGlobal::locale()->formatNumber(byteCount/1000.0, 1));
-        knGlobals.progressBar->setProgressBar(nntpClient->getProgressValue(),tmp);
+        if (nntpClient->isInByteCountMode()) {
+          byteCount = nntpClient->getByteCount();
+          if (byteCount < 1000)
+            tmp = i18n("%1 Bytes").arg(KGlobal::locale()->formatNumber(byteCount, 0));
+          else
+            tmp = i18n("%1 KB").arg(KGlobal::locale()->formatNumber(byteCount/1000.0, 1));
+          knGlobals.progressBar->setProgressBar(nntpClient->getProgressValue(),tmp);
+        } else
+          knGlobals.progressBar->setProgressBar(nntpClient->getProgressValue(),"%p%");
       break;
     };
   } else {                    // signal from smtp thread
@@ -349,13 +377,17 @@ void KNNetAccess::slotThreadSignal(int i)
       break;
       case KNProtocolClient::TSconnect:
         unshownMsg = i18n(" Connecting to server...");
-        if (!currentNntpJob)
-          knGlobals.top->setStatusMsg(unshownMsg);
+        if (!currentNntpJob) {
+          currMsg = unshownMsg;
+          knGlobals.top->setStatusMsg(currMsg);
+        }
       break;
       case KNProtocolClient::TSsendMail:
         unshownMsg = i18n(" Sending mail...");
-        if (!currentNntpJob)
-          knGlobals.top->setStatusMsg(unshownMsg);
+        if (!currentNntpJob) {
+          currMsg = unshownMsg;
+          knGlobals.top->setStatusMsg(currMsg);
+        }
       break;
       case KNProtocolClient::TSjobStarted:
         unshownByteCount = i18n("0 Bytes");
@@ -378,14 +410,6 @@ void KNNetAccess::slotThreadSignal(int i)
 }
 
 
-
-void KNNetAccess::slotCancelAllJobs()
-{
-  stopJobsNntp(0);
-  stopJobsSmtp(0);
-}
-
-
 //--------------------------------
 
 #include "knnetaccess.moc"
