@@ -1,19 +1,18 @@
-/***************************************************************************
-                          knprotocolclient.cpp  -  description
-                             -------------------
-    copyright            : (C) 2000 by Christian Gebauer
-    email                : gebauer@bigfoot.com
-    version              : $Id: knprotocolclient.cpp,v 1.23.2.1 2000/11/03 23:19:57 gebauer Exp $
- ***************************************************************************/
+/*
+    knprotocolclient.cpp
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    KNode, the KDE newsreader
+    Copyright (c) 1999-2000 the KNode authors.
+    See file AUTHORS for details
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software Foundation,
+    Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, US
+*/
 
 #include <config.h>
 
@@ -47,6 +46,7 @@ KNProtocolClient::KNProtocolClient(int NfdPipeIn, int NfdPipeOut, QObject *paren
   input = new char[inputSize];
 }
 
+
 KNProtocolClient::~KNProtocolClient()
 {
   if (isConnected())
@@ -83,6 +83,14 @@ void KNProtocolClient::removeJob()
 }
 
 
+void KNProtocolClient::updatePercentage(int percent)
+{
+  byteCountMode=false;
+  progressValue = percent*10;
+  sendSignal(TSprogressUpdate);
+}
+
+
 // main loop, maintains connection and waits for next job
 void KNProtocolClient::waitForWork()
 {
@@ -122,12 +130,14 @@ void KNProtocolClient::waitForWork()
 
     clearPipe();      // remove start signal
 
+    timer.start();
+
     sendSignal(TSjobStarted);
     if (job) {
     //  qDebug("knode: KNProtocolClient::waitForWork(): got job");
 
-      if (job->net()&&!account.isEqual(job->account())) {     // server changed
-        account.copy(job->account());
+      if (job->net()&&!(account == *job->account())) {     // server changed
+        account = *job->account();
         if (isConnected())
           closeConnection();
       }
@@ -140,6 +150,7 @@ void KNProtocolClient::waitForWork()
       predictedLines = -1;
       doneLines = 0;
       byteCount = 0;
+      byteCountMode = true;
 
       if (!job->net())    // job needs no net access
         processJob();
@@ -150,7 +161,7 @@ void KNProtocolClient::waitForWork()
         if (isConnected())         // connection is ready
           processJob();
       }
-      errorPrefix = "";
+      errorPrefix = QString::null;
 
       clearPipe();
     }
@@ -185,10 +196,9 @@ bool KNProtocolClient::openConnection()
     return false;
   }
 
-// use non-blocking sockets only if we are sure that
-// they work reliable. (i.e. on linux / glibc >=2.0)
-#ifdef __linux__
-#if (__GNU_LIBRARY__ != 1)        // non-blocking operation doesn't work on libc5
+  // use non-blocking sockets only if we are sure that
+  // they work reliable. (i.e. on linux/glibc>=2.0 and Solaris)
+#if ((defined(__linux__) && (__GNU_LIBRARY__ != 1)) || defined(__sun__))
   if (-1 == fcntl(tcpSocket,F_SETFL,O_NONBLOCK)) {  // make socket non-blocking
     QString str = i18n("Communication error:\n");
     str += strerror(errno);
@@ -196,14 +206,12 @@ bool KNProtocolClient::openConnection()
     closeSocket();
     return false;
   }
-#endif
 #endif
 
   in_addr address;
 
- // can only use inet_addr because of portability problem on Solaris
- // TODO: port to QDns/QSocket
- // Solaris uses deprecated inet_addr instead of inet_aton (David F.)
+  // can only use inet_addr because of portability problem on Solaris
+  // Solaris uses deprecated inet_addr instead of inet_aton (David F.)
   address.s_addr = inet_addr(account.server().local8Bit().data());
   // unsigned int is ok because its uint/32bit in fact
   if ( (unsigned int) address.s_addr != (unsigned int)-1 ) {
@@ -215,7 +223,6 @@ bool KNProtocolClient::openConnection()
     struct hostent* hostData = gethostbyname(account.server().local8Bit().data());
 
     if (NULL==hostData) {
-      herror("connect(): ");
       job->setErrorString(i18n("Unable to resolve hostname"));
       closeSocket();
       return false;
@@ -285,9 +292,9 @@ bool KNProtocolClient::sendCommandWCheck(const QCString &cmd, int rep)
 
 
 // sends a message (multiple lines)
-bool KNProtocolClient::sendMsg(const DwString &msg)
+bool KNProtocolClient::sendMsg(const QCString &msg)
 {
-  const char *line = msg.c_str();
+  const char *line = msg.data();
   char *end;
   QCString buffer;
   size_t length;
@@ -340,10 +347,18 @@ bool KNProtocolClient::getNextLine()
   thisLine = input;
   inputEnd = input+div-1;
   do {
-    if ((inputEnd-input) > 9500) {
-      job->setErrorString(i18n("Message size exceeded the size of the internal buffer."));
-      closeSocket();
-      return false;
+    div = inputEnd-thisLine+1;
+    if ((div) > inputSize-100) {
+      inputSize += 10000;
+      char *newInput = new char[inputSize];
+      memmove(newInput,input,div);
+      delete [] input;
+      input = newInput;
+      thisLine = input;
+      inputEnd = input+div-1;
+#ifndef NDEBUG
+      qDebug("knode: KNProtocolClient::getNextLine(): input buffer enlarged");
+#endif
     }
     if (!waitForRead())
       return false;
@@ -358,6 +373,14 @@ bool KNProtocolClient::getNextLine()
       closeSocket();
       return false;
     }
+
+    // remove null characters that some stupid servers return...
+    for (int i=0; i<received; i++)
+      if (inputEnd[i] == 0) {
+         memmove(inputEnd+i,inputEnd+i+1,received-i-1);
+         received--;
+      }
+
     inputEnd += received;
     inputEnd[0] = 0;  // terminate *char
 
@@ -365,9 +388,12 @@ bool KNProtocolClient::getNextLine()
 
   } while (!(nextLine = strstr(thisLine,"\r\n")));
 
-  if (predictedLines > 0)
-    progressValue = 100 + (doneLines*900/predictedLines);
-  sendSignal(TSprogressUpdate);
+  if (timer.elapsed()>50) {   // reduce framerate to 20 f/s
+    timer.start();
+    if (predictedLines > 0)
+      progressValue = 100 + (doneLines*900/predictedLines);
+    sendSignal(TSprogressUpdate);
+  }
 
   nextLine[0] = 0;  // terminate string
   nextLine[1] = 0;
@@ -570,7 +596,7 @@ bool KNProtocolClient::conRawIP(in_addr* ip)
   fd_set fdsR,fdsW;
   timeval tv;
 
-  job->setErrorString("");
+  job->setErrorString(QString::null);
   sockaddr_in address;
   address.sin_family = AF_INET;
   address.sin_port = htons(account.port());
@@ -603,8 +629,28 @@ bool KNProtocolClient::conRawIP(in_addr* ip)
       if ((ret > 0)&&(FD_ISSET(fdPipeIn,&fdsR)))   // stop signal
         return false;
 
+      // the getsockopt() stuff doesn't work on solaris...
+#ifdef __sun__
+      if (-1 == ::connect(tcpSocket,(struct sockaddr*)&address,sizeof(struct sockaddr_in))) {
+        switch (errno) {
+          case EISCONN:
+          case 0:
+            return true;   // success!!
+          case ECONNREFUSED:
+            job->setErrorString(i18n("The server refused the connection."));
+            return false;
+          case ETIMEDOUT:
+            job->setErrorString(i18n("A delay occured which exceeded the\ncurrent timeout limit."));
+            return false;
+          default:
+            job->setErrorString(i18n("Unable to connect:\n%1").arg(strerror(errno)));
+            return false;
+        }
+      } else
+        return true;
+#else
       int err = 0;
-      unsigned int len = 1;
+      ksize_t len = 1;
       if (getsockopt(tcpSocket,SOL_SOCKET,SO_ERROR,(char*)&err,&len)!=0) {
         QString str = i18n("Communication error:\n");
         str += strerror(errno);
@@ -621,10 +667,11 @@ bool KNProtocolClient::conRawIP(in_addr* ip)
             job->setErrorString(i18n("A delay occured which exceeded the\ncurrent timeout limit."));
             return false;
           default:
-                      job->setErrorString(i18n("Unable to connect:\n%1").arg(strerror(err)));
+            job->setErrorString(i18n("Unable to connect:\n%1").arg(strerror(err)));
             return false;
         }
       }
+#endif
     } else {
       QCString str;
       switch (errno) {
@@ -679,9 +726,12 @@ bool KNProtocolClient::sendStr(const QCString &str)
     }
     byteCount += ret;
   }
-  if (predictedLines > 0)
-    progressValue = 100 + (doneLines/predictedLines)*900;
-  sendSignal(TSprogressUpdate);
+  if (timer.elapsed()>50) {   // reduce framerate to 20 f/s
+    timer.start();
+    if (predictedLines > 0)
+      progressValue = 100 + (doneLines/predictedLines)*900;
+    sendSignal(TSprogressUpdate);
+  }
   return true;
 }
 
