@@ -1,28 +1,25 @@
-/***************************************************************************
-                          knstatusfilter.cpp  -  description
-                             -------------------
+/*
+    knstatusfilter.cpp
 
-    copyright            : (C) 1999 by Christian Thurner
-    email                : cthurner@freepage.de
- ***************************************************************************/
+    KNode, the KDE newsreader
+    Copyright (c) 1999-2000 the KNode authors.
+    See file AUTHORS for details
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software Foundation,
+    Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, US
+*/
 
 #include <qlayout.h>
-#include <qbitarray.h>
 #include <qcheckbox.h>
-
 #include <klocale.h>
 #include <ksimpleconfig.h>
 
-#include "knfetcharticle.h"
+#include "knmime.h"
 #include "knstatusfilter.h"
 
 
@@ -74,7 +71,7 @@ void KNStatusFilter::save(KSimpleConfig *conf)
 
 
 
-bool KNStatusFilter::doFilter(KNFetchArticle *a)
+bool KNStatusFilter::doFilter(KNRemoteArticle *a)
 {
   bool ret=true;  
 
