@@ -1,9 +1,10 @@
 /*
  *            kPPP: A pppd front end for the KDE project
  *
- * 
- *            Copyright (C) 1997 Bernd Johannes Wuebben 
+ *
+ *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
+ *            Copyright (C) 1998-2000 Harri Porten <porten@kde.org>
  *
  * based on EzPPP:
  * Copyright (C) 1997  Jay Painter
@@ -26,10 +27,11 @@
 #include <config.h>
 
 #include <qdir.h>
-#include <qregexp.h> 
+#include <qregexp.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 
+#include <unistd.h>
 #include <stdlib.h>
 #include <string.h>
 #include <fcntl.h>
@@ -40,6 +42,10 @@
 #include <netinet/in.h>
 #include <sys/ioctl.h>
 
+#ifdef _XPG4_2
+#define __xnet_connect	connect
+#endif
+
 #include <errno.h>
 
 #ifdef HAVE_SYS_PARAM_H
@@ -75,7 +81,7 @@ ConnectWidget::ConnectWidget(QWidget *parent, const char *name, PPPStats *st)
     // initialize some important variables
     myreadbuffer(""),
     main_timer_ID(0),
-    vmain(0),  
+    vmain(0),
     scriptindex(0),
     loopnest(0),
     loopend(false),
@@ -101,7 +107,7 @@ ConnectWidget::ConnectWidget(QWidget *parent, const char *name, PPPStats *st)
   messg = new QLabel(this, "messg");
   messg->setFrameStyle(QFrame::Panel|QFrame::Sunken);
   messg->setAlignment(AlignCenter);
-  messg->setText(i18n("Sorry, can't create modem lock file."));  
+  messg->setText(i18n("Sorry, can't create modem lock file."));
   messg->setMinimumHeight(messg->sizeHint().height() + 5);
   int messw = (messg->sizeHint().width() * 12) / 10;
   messw = QMAX(messw,280);
@@ -114,7 +120,7 @@ ConnectWidget::ConnectWidget(QWidget *parent, const char *name, PPPStats *st)
   QHBoxLayout *l1 = new QHBoxLayout(10);
   tl->addLayout(l1);
   l1->addStretch(1);
-  
+
   debug = new QPushButton(i18n("Log"), this);
   connect(debug, SIGNAL(clicked()), SLOT(debugbutton()));
 
@@ -139,16 +145,16 @@ ConnectWidget::ConnectWidget(QWidget *parent, const char *name, PPPStats *st)
 
   timeout_timer = new QTimer(this);
   connect(timeout_timer, SIGNAL(timeout()), SLOT(script_timed_out()));
-  
+
   inittimer = new QTimer(this);
   connect(inittimer, SIGNAL(timeout()), SLOT(init()));
 
   if_timeout_timer = new QTimer(this);
   connect(if_timeout_timer, SIGNAL(timeout()), SLOT(if_waiting_timed_out()));
-  
+
   connect(this,SIGNAL(if_waiting_signal()),this,SLOT(if_waiting_slot()));
 
-  prompt = new PWEntry( this, "pw" );         
+  prompt = new PWEntry( this, "pw" );
   if_timer = new QTimer(this);
   connect(if_timer,SIGNAL(timeout()), SLOT(if_waiting_slot()));
 }
@@ -218,7 +224,7 @@ void ConnectWidget::init() {
     return;
   }
 
-  if (lock == -1) {    
+  if (lock == -1) {
     messg->setText(i18n("Sorry, can't create modem lock file."));
     vmain = 20; // wait until cancel is pressed
     return;
@@ -235,10 +241,10 @@ void ConnectWidget::init() {
 
       Modem::modem->stop();
       Modem::modem->notify(this, SLOT(readChar(unsigned char)));
-      
+
       // if we are stuck anywhere we will time out
-      timeout_timer->start(gpppdata.modemTimeout()*1000); 
-      
+      timeout_timer->start(gpppdata.modemTimeout()*1000);
+
       // this timer will run the script etc.
       main_timer_ID = startTimer(10);
 
@@ -250,7 +256,7 @@ void ConnectWidget::init() {
   messg->setText(Modem::modem->modemMessage());
   vmain = 20; // wait until cancel is pressed
   Modem::modem->unlockdevice();
-}                  
+}
 
 
 void ConnectWidget::timerEvent(QTimerEvent *) {
@@ -275,7 +281,7 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
     }
     setExpect(gpppdata.modemInitResp());
     writeline(gpppdata.modemInitStr());
-    usleep(gpppdata.modemInitDelay() * 10000); // 0.01 - 3.0 sec       
+    usleep(gpppdata.modemInitDelay() * 10000); // 0.01 - 3.0 sec
     vmain = 3;
     return;
   }
@@ -320,9 +326,9 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
       if(++dialnumber >= plist.count())
         dialnumber = 0;
       writeline(pn);
-      
+
       setExpect(gpppdata.modemConnectResp());
-      vmain = 100;  
+      vmain = 100;
       return;
     }
   }
@@ -337,7 +343,7 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
       return;
     }
 
-    if(readbuffer.contains(gpppdata.modemBusyResp())) {      
+    if(readbuffer.contains(gpppdata.modemBusyResp())) {
       timeout_timer->stop();
       timeout_timer->start(gpppdata.modemTimeout()*1000);
 
@@ -349,14 +355,14 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
 	QString bm = i18n("Line Busy. Waiting: %1 seconds").arg(gpppdata.busyWait());
 	messg->setText(bm);
 	emit debugMessage(bm);
-      
+
 	pausing = true;
-      
+
 	pausetimer->start(gpppdata.busyWait()*1000, true);
 	timeout_timer->stop();
       }
 
-      Modem::modem->setDataMode(false); 
+      Modem::modem->setDataMode(false);
       vmain = 0;
       return;
     }
@@ -478,12 +484,12 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
 	QString bm = i18n("Pause %1 seconds").arg(scriptArgument);
 	messg->setText(bm);
 	emit debugMessage(bm);
-	
+
 	pausing = true;
-	
+
 	pausetimer->start(scriptArgument.toInt()*1000, true);
 	timeout_timer->stop();
-	
+
 	scriptindex++;
 	return;
       }
@@ -495,10 +501,10 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
 	QString bm = i18n("Timeout %1 seconds").arg(scriptArgument);
 	messg->setText(bm);
 	emit debugMessage(bm);
-	
+
 	scriptTimeout=scriptArgument.toInt()*1000;
         timeout_timer->start(scriptTimeout);
-	
+
 	scriptindex++;
 	return;
       }
@@ -509,13 +515,13 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
 
 	writeline(gpppdata.modemHangupStr());
 	setExpect(gpppdata.modemHangupResp());
-	
+
 	scriptindex++;
 	return;
       }
 
       if (scriptCommand == "Answer") {
-	
+
 	timeout_timer->stop();
 
 	messg->setText(i18n("Answer"));
@@ -532,7 +538,7 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
 	emit debugMessage(bm);
 
 	QString idstring = gpppdata.storedUsername();
-	
+
 	if(!idstring.isEmpty() && firstrunID) {
 	  // the user entered an Id on the main kppp dialog
 	  writeline(idstring);
@@ -568,7 +574,7 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
 	emit debugMessage(bm);
 
 	QString pwstring = gpppdata.Password();
-	
+
 	if(!pwstring.isEmpty() && firstrunPW) {
 	  // the user entered a password on the main kppp dialog
 	  writeline(pwstring);
@@ -598,14 +604,14 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
 	     }
 	}
       }
- 
+
       if (scriptCommand == "Prompt") {
 	QString bm = i18n("Prompting %1");
 
-        // if the scriptindex (aka the prompt text) includes a ## marker 
-        // this marker should get substituted with the contents of our stored 
+        // if the scriptindex (aka the prompt text) includes a ## marker
+        // this marker should get substituted with the contents of our stored
         // variable (from the subsequent scan).
-	
+
 	QString ts = scriptArgument;
 	int vstart = ts.find( "##" );
 	if( vstart != -1 ) {
@@ -719,7 +725,7 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
   }
 
   if(vmain == 30) {
-    if (termwindow->isVisible()) 
+    if (termwindow->isVisible())
       return;
     if (termwindow->pressedContinue())
       vmain = 10;
@@ -727,7 +733,7 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
       cancelbutton();
   }
 
-  if(vmain == 10) { 
+  if(vmain == 10) {
     if(!expecting) {
 
       int result;
@@ -751,7 +757,7 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
 	  return;
 	}
       }
-      
+
       // Close the tty. This prevents the QTimer::singleShot() in
       // Modem::readtty() from re-enabling the socket notifier.
       // The port is still held open by the helper process.
@@ -774,7 +780,7 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
 
       if(result) {
         if(!gpppdata.autoDNS())
-          adddns(); 
+          adddns();
 
 	// O.K we are done here, let's change over to the if_waiting loop
 	// where we wait for the ppp if (interface) to come up.
@@ -782,7 +788,7 @@ void ConnectWidget::timerEvent(QTimerEvent *) {
 	emit if_waiting_signal();
       } else {
 
-	// starting pppd wasn't successful. Error messages were 
+	// starting pppd wasn't successful. Error messages were
 	// handled by execppp();
 	if_timeout_timer->stop();
 	this->hide();
@@ -830,7 +836,7 @@ void ConnectWidget::readChar(unsigned char c) {
     // for use in the prompt command
     if( scanning )
        scanbuffer += c;
- 
+
     // add to debug window
     emit debugPutChar(c);
 
@@ -896,6 +902,7 @@ void ConnectWidget::cancelbutton() {
   Modem::modem->stop();
   killTimer(main_timer_ID);
   timeout_timer->stop();
+  if_timer->stop();
   if_timeout_timer->stop();
 
   if (termwindow) {
@@ -910,10 +917,10 @@ void ConnectWidget::cancelbutton() {
   Requester::rq->removeSecret(AUTH_PAP);
   Requester::rq->removeSecret(AUTH_CHAP);
   removedns();
-  
+
   kapp->processEvents();
 
-  Requester::rq->killPPPDaemon();  
+  Requester::rq->killPPPDaemon();
   Modem::modem->hangup();
 
   this->hide();
@@ -931,7 +938,7 @@ void ConnectWidget::cancelbutton() {
   }
   prompt->setConsumed();
 
-  if(quit_on_disconnect) 
+  if(quit_on_disconnect)
     kapp->exit(0);
 }
 
@@ -946,7 +953,7 @@ void ConnectWidget::script_timed_out() {
 
   if (prompt->isVisible())
     prompt->hide();
-  
+
   prompt->setConsumed();
   messg->setText(i18n("Script timed out!"));
   Modem::modem->hangup();
@@ -989,7 +996,7 @@ void ConnectWidget::if_waiting_timed_out() {
   if_timer->stop();
   if_timeout_timer->stop();
   kdDebug(5002) << "if_waiting_timed_out()" << endl;
-  
+
   gpppdata.setpppdError(E_IF_TIMEOUT);
 
   // let's kill the stuck pppd
@@ -1000,10 +1007,15 @@ void ConnectWidget::if_waiting_timed_out() {
 
 
   // killing ppp will generate a SIGCHLD which will be caught in pppdie()
-  // in main.cpp what happens next will depend on the boolean 
+  // in main.cpp what happens next will depend on the boolean
   // reconnect_on_disconnect which is set in ConnectWidget::init();
 }
 
+void ConnectWidget::pppdDied()
+{
+  if_timer->stop();
+  if_timeout_timer->stop();
+}
 
 void ConnectWidget::if_waiting_slot() {
   messg->setText(i18n("Logging on to Network ..."));
@@ -1012,19 +1024,18 @@ void ConnectWidget::if_waiting_slot() {
 
     if(gpppdata.pppdError() != 0) {
       // we are here if pppd died immediately after starting it.
-
-      if_timer->stop();
+      pppdDied();
       // error message handled in main.cpp: sigPPPDDied()
       return;
     }
 
-    if_timer->start(100, TRUE); // single shot 
+    if_timer->start(100, TRUE); // single shot
     return;
   }
 
   // O.K the ppp interface is up and running
   // give it a few time to come up completly (0.2 seconds)
-  if_timeout_timer->stop(); 
+  if_timeout_timer->stop();
   if_timer->stop();
   usleep(200000);
 
@@ -1041,7 +1052,7 @@ void ConnectWidget::if_waiting_slot() {
     messg->setText(i18n("Running Startup Command ..."));
 
     // make sure that we don't get any async errors
-    kapp->flushX(); 
+    kapp->flushX();
     execute_command(gpppdata.command_on_connect());
     messg->setText(i18n("Done"));
   }
@@ -1068,10 +1079,10 @@ void ConnectWidget::if_waiting_slot() {
     DockWidget::dock_widget->show();
     DockWidget::dock_widget->take_stats();
     this->hide();
-  } 
+  }
   else {
     p_kppp->con_win->show();
-    
+
     if(gpppdata.get_iconify_on_connect()) {
       p_kppp->con_win->showMinimized();
     }
@@ -1101,7 +1112,7 @@ bool ConnectWidget::execppp() {
   if(gpppdata.ipaddr() != "0.0.0.0" ||
      gpppdata.gateway() != "0.0.0.0") {
     if(gpppdata.ipaddr() != "0.0.0.0") {
-      command += " "; 
+      command += " ";
       command += gpppdata.ipaddr();
       command +=  ":";
     }
@@ -1225,7 +1236,7 @@ void auto_hostname() {
     }
   }
 
-}  
+}
 
 // Replace the DNS domain entry in the /etc/resolv.conf file and
 // disable the nameserver entries if option is enabled
@@ -1261,9 +1272,9 @@ void add_domain(const QString &domain) {
 
       for(int j=0; j < i; j++) {
 	if((resolv[j].contains("domain") ||
-	      ( resolv[j].contains("nameserver") 
-		&& !resolv[j].contains("#kppp temp entry") 
-		&& gpppdata.exDNSDisabled())) 
+	      ( resolv[j].contains("nameserver")
+		&& !resolv[j].contains("#kppp temp entry")
+		&& gpppdata.exDNSDisabled()))
 	        && !resolv[j].contains("#entry disabled by kppp")) {
 
           write(fd, "# ", 2);
@@ -1280,7 +1291,7 @@ void add_domain(const QString &domain) {
     }
     close(fd);
   }
-}  
+}
 
 
 // adds the DNS entries in the /etc/resolv.conf file
@@ -1302,7 +1313,7 @@ void adddns()
     close(fd);
   }
   add_domain(gpppdata.domain());
-}  
+}
 
 void addpeerdns() {
   int fd, fd2;
@@ -1323,7 +1334,7 @@ void addpeerdns() {
     close(fd);
   }
   add_domain(gpppdata.domain());
-}  
+}
 
 // remove the dns entries from the /etc/resolv.conf file
 void removedns() {
@@ -1369,6 +1380,6 @@ void removedns() {
     modified_hostname = FALSE;
   }
 
-}  
+}
 
 #include "connect.moc"
