@@ -2,7 +2,7 @@
  *
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: general.h,v 1.30 1999/10/02 10:12:06 porten Exp $
+ * $Id: general.h,v 1.31 2000/10/12 18:14:24 porten Exp $
  * 
  *            Copyright (C) 1997 Bernd Johannes Wuebben 
  *                   wuebben@math.cornell.edu
@@ -115,7 +115,7 @@ public:
 
 private slots:
   void 	busywaitchanged(int);
-  void 	use_cdline_toggled(bool);
+//  void 	use_cdline_toggled(bool);
   void 	modemcmdsbutton();
   void 	terminal();
   void 	query_modem();
