@@ -1,6 +1,7 @@
 /*
  *            kPPP: A pppd front end for the KDE project
  *
+ * $Id: main.cpp,v 1.192 2001/02/19 12:34:20 faure Exp $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -34,6 +35,10 @@
 #include <fcntl.h>
 #include <stdlib.h>
 
+#ifdef _XPG4_2
+#define __xnet_connect	connect
+#endif
+
 #ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
 #endif
@@ -49,6 +54,7 @@
 #include <kaboutdata.h>
 #include <kconfig.h>
 #include <kmessagebox.h>
+#include <knotifyclient.h>
 #include <qdir.h>
 #include <qwhatsthis.h>
 #include <qmessagebox.h>
@@ -298,7 +304,7 @@ int main( int argc, char **argv ) {
     KPPPVERSION, description, KAboutData::License_GPL,
     "(c) 1999-2000, The KPPP Developers");
   aboutData.addAuthor("Bernd Wuebben",0, "wuebben@kde.org");
-  aboutData.addAuthor("Mario Weilguni",0, "mweilguni@kde.org");
+  aboutData.addAuthor("Mario Weilguni",0, "");
   aboutData.addAuthor("Harri Porten",0, "porten@kde.org");
 
   KCmdLineArgs::init( argc, argv, &aboutData );
@@ -386,6 +392,8 @@ int main( int argc, char **argv ) {
   KPPPWidget kppp;
   p_kppp = &kppp;
 
+  (void)new DockWidget(p_kppp->con_win, "dockw", p_kppp->stats);
+
 #if 0
   // keep user informed about recent changes
   if(!have_cmdl_account)
@@ -566,8 +574,10 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
 
   stats = new PPPStats;
 
-  con_win = new ConWindow(0, "conw", this, stats);
   KWin::setIcons(winId(), kapp->icon(), kapp->miniIcon());
+
+  con_win = new ConWindow(0, "conw", this, stats);
+  KWin::setIcons(con_win->winId(), kapp->icon(), kapp->miniIcon());
   con_win->setGeometry(QApplication::desktop()->width()/2-160,
 		    QApplication::desktop()->height()/2-55,
 		    320,110);
@@ -575,17 +585,15 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
   statdlg = new PPPStatsDlg(0, "stats", this, stats);
   statdlg->hide();
 
-  (void)new DockWidget(this, "dockw", stats);
-
   debugwindow = new DebugWidget(0,"debugwindow");
-  KWin::setIcons(winId(), kapp->icon(), kapp->miniIcon());
+  KWin::setIcons(debugwindow->winId(), kapp->icon(), kapp->miniIcon());
   debugwindow->hide();
 
   // load up the accounts combo box
 
   resetaccounts();
   con = new ConnectWidget(0, "con", stats);
-  KWin::setIcons(winId(), kapp->icon(), kapp->miniIcon());
+  KWin::setIcons(con->winId(), kapp->icon(), kapp->miniIcon() );
   connect(this, SIGNAL(begin_connect()),con, SLOT(preinit()));
   con->setGeometry(QApplication::desktop()->width()/2-175,
 		    QApplication::desktop()->height()/2-55,
@@ -663,7 +671,7 @@ bool KPPPWidget::eventFilter(QObject *o, QEvent *e) {
 void KPPPWidget::prepareSetupDialog() {
   if(tabWindow == 0) {
     tabWindow = new QTabDialog( kapp->mainWidget(), 0, TRUE );
-    KWin::setIcons(winId(), kapp->icon(), kapp->miniIcon());
+    KWin::setIcons(tabWindow->winId(), kapp->icon(), kapp->miniIcon());
     tabWindow->setCaption( i18n("kppp Configuration") );
     tabWindow->setOkButton(i18n("OK"));
     tabWindow->setCancelButton(i18n("Cancel"));
@@ -741,7 +749,7 @@ void KPPPWidget::resetaccounts() {
        if(gpppdata.defaultAccount() == connectto_c->text(i)) {
  	connectto_c->setCurrentItem(i);
 	gpppdata.setAccountbyIndex(i);
-	
+
 	ID_Edit->setText(gpppdata.storedUsername());
 	PW_Edit->setText(gpppdata.storedPassword());
     }
@@ -824,6 +832,7 @@ void KPPPWidget::sigPPPDDied() {
         gpppdata.setpppdError(E_PPPD_DIED);
       removedns();
       Modem::modem->unlockdevice();
+      con->pppdDied();
 
       if(!gpppdata.automatic_redial()) {
 	quit_b->setFocus();
@@ -834,8 +843,7 @@ void KPPPWidget::sigPPPDDied() {
 	con->hide();
 
         gpppdata.setpppdRunning(false);
-	
-	KApplication::beep();
+	KNotifyClient::beep();
 	QString msg;
 	if (gpppdata.pppdError() == E_IF_TIMEOUT)
 	    msg = i18n("Timeout expired while waiting for the PPP interface "
@@ -850,7 +858,7 @@ void KPPPWidget::sigPPPDDied() {
 			    "  http://devel-home.kde.org/~kppp/index.html");
 	    }
 	}
-	
+
 	if(QMessageBox::critical(0, i18n("Error"), msg, i18n("OK"), i18n("Details...")))
 	  PPPL_ShowLog();
       } else { /* reconnect on disconnect */
@@ -865,7 +873,7 @@ void KPPPWidget::sigPPPDDied() {
 	con_win->stopClock();
 	stopAccounting();
 	gpppdata.setpppdRunning(false);
-	KApplication::beep();
+	KNotifyClient::beep();
 	emit cmdl_start();
     }
   }
@@ -991,7 +999,7 @@ void KPPPWidget::beginConnect() {
     debugwindow->show();
     con->raise();
     con->debug->setText(i18n("Log")); // set Log/Hide button text to Hide
-  }	
+  }
 
   emit begin_connect();
 }
@@ -1188,7 +1196,7 @@ pid_t execute_command (const QString & cmd) {
 
     system(command);
     _exit(0);
-  }	
+  }
 
   return id;
 }
