@@ -1,7 +1,7 @@
 /*
  *            kPPP: A front end for pppd for the KDE project
  *
- * $Id: modemcmds.cpp,v 1.22 1999/10/09 00:26:50 kalle Exp $
+ * $Id: modemcmds.cpp,v 1.24 2000/07/30 21:09:57 bieker Exp $
  * 
  * Copyright (C) 1997 Bernd Johannes Wuebben 
  * wuebben@math.cornell.edu
@@ -32,7 +32,7 @@
 #include <klocale.h>
 #include "modemcmds.h"
 #include "pppdata.h"
-#include <kwm.h>
+#include <kwin.h>
 
 #define ADJUSTEDIT(e) e->setText("XXXXXXXXqy"); e->setMinimumSize(e->sizeHint()); e->setFixedHeight(e->sizeHint().height()); e->setText(""); e->setMaxLength(MODEMSTR_SIZE);
 
@@ -43,7 +43,7 @@ ModemCommands::ModemCommands(QWidget *parent, const char *name)
   : QDialog(parent, name, TRUE, WStyle_Customize|WStyle_NormalBorder)
 {
   setCaption(i18n("Edit Modem Commands"));
-  KWM::setMiniIcon(winId(), kapp->miniIcon());
+  KWin::setIcons(winId(), kapp->icon(), kapp->miniIcon());
 
   const int GRIDROWS = 20;
 
@@ -260,10 +260,10 @@ ModemCommands::ModemCommands(QWidget *parent, const char *name)
 
 
 void ModemCommands::okbutton() {
-  gpppdata.setModemPreInitDelay(atoi(lpreinitslider->text()));
+  gpppdata.setModemPreInitDelay(lpreinitslider->text().toInt());
   gpppdata.setModemInitStr(initstr->text());
   gpppdata.setModemInitResp(initresp->text());
-  gpppdata.setModemInitDelay(atoi(linitslider->text()));
+  gpppdata.setModemInitDelay(linitslider->text().toInt());
 
   gpppdata.setModemDialStr(dialstr->text());
   gpppdata.setModemConnectResp(connectresp->text());
@@ -273,7 +273,7 @@ void ModemCommands::okbutton() {
 
   gpppdata.setModemEscapeStr(escapestr->text());
   gpppdata.setModemEscapeResp(escaperesp->text());
-  gpppdata.setModemEscapeGuardTime(atoi(lslider->text()));
+  gpppdata.setModemEscapeGuardTime(lslider->text().toInt());
   gpppdata.setModemHangupStr(hangupstr->text());
   gpppdata.setModemHangupResp(hangupresp->text());
 
