@@ -2,7 +2,7 @@
  *
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: pppdata.h,v 1.62 2000/01/15 18:22:12 porten Exp $
+ * $Id: pppdata.h,v 1.66 2000/10/12 18:14:24 porten Exp $
  * 
  *            Copyright (C) 1997 Bernd Johannes Wuebben 
  *                   wuebben@math.cornell.edu
@@ -28,8 +28,11 @@
 #ifndef _PPPDATA_H_
 #define _PPPDATA_H_
 
+#include <unistd.h>
+#include <sys/types.h>
+
 #include <qstring.h>
-#include <qstrlist.h>
+#include <qstringlist.h>
 #include <qcolor.h>
 
 #include "kpppconfig.h"
@@ -159,11 +162,11 @@ public:
   QString readConfig(const QString &, const QString &, const QString &);
   int readNumConfig(const QString &, const QString &, int);
   bool readListConfig(const QString &, const QString &,
-                      QStrList &, char sep = ',');
+                      QStringList &, char sep = ',');
   void writeConfig(const QString &, const QString &, const QString &);
   void writeConfig(const QString &, const QString &, int);
   void writeListConfig(const QString &, const QString &,
-                       QStrList &, char sep = ',');
+                       QStringList &, char sep = ',');
 
   // return the current account group
   QString currentGroup() { return cgroup; }
@@ -289,8 +292,10 @@ public:
   const QString modemAnswerResp();
   void setModemAnswerResp(const QString &);
 
+#if 0
   void setUseCDLine(const int n);
   int  UseCDLine();
+#endif
 
   // functions to set/get account information
   int count() const;
@@ -307,7 +312,7 @@ public:
   const QString accname();
   void setAccname(const QString &);
   
-  QStrList &phonenumbers();
+  QStringList &phonenumbers();
   const QString phonenumber();
   void setPhonenumber(const QString &);
 
@@ -368,21 +373,21 @@ public:
   bool defaultroute();
   void setDefaultroute(bool set);
 
-  QStrList &dns();
-  void setDns(QStrList &);
+  QStringList &dns();
+  void setDns(QStringList &);
 
   const QString domain();
   void setDomain(const QString &);
 
-  QStrList &scriptType();
-  void setScriptType(QStrList &);
+  QStringList &scriptType();
+  void setScriptType(QStringList &);
 
-  QStrList &script();
-  void setScript(QStrList &);
+  QStringList &script();
+  void setScript(QStringList &);
 
-  QStrList &pppdArgument();
+  QStringList &pppdArgument();
   void setpppdArgumentDefaults();
-  void setpppdArgument(QStrList &);
+  void setpppdArgument(QStringList &);
 
   //functions to change/set the child pppd process info
   bool pppdRunning() const;
@@ -428,7 +433,7 @@ private:
   int pppderror;                         // error encounterd running pppd
   int pppdVer, pppdMod, pppdPatch;       // pppd version
 
-  QStrList phonelist;
+  QStringList phonelist;
 };
 
 extern PPPData gpppdata;
