@@ -8,23 +8,23 @@
 
 #include <kdebug.h>
 
-QDict<QObject> *objFinder::objList = new("QDict<QObject>") QDict<QObject>;
+QDict<QObject> *objFinder::objList = new QDict<QObject>;
 
 /*
  * So we can connect to the slots, etc
  */
-objFinder *objFind = new("objFinder") objFinder();
+objFinder *objFind = new objFinder();
 
-objFinder::objFinder() /*fold00*/
+objFinder::objFinder()
   : QObject()
 {
 }
 
-objFinder::~objFinder() /*fold00*/
+objFinder::~objFinder()
 {
 }
 
-void objFinder::insert(QObject *obj, const char *key){ /*FOLD00*/
+void objFinder::insert(QObject *obj, const char *key){
   QString name;
 
   if(obj == 0x0){
@@ -48,7 +48,7 @@ void objFinder::insert(QObject *obj, const char *key){ /*FOLD00*/
   emit objFind->inserted(obj);
 }
 
-QObject *objFinder::find(const char *name, const char *inherits){ /*FOLD00*/
+QObject *objFinder::find(const char *name, const char *inherits){
   QObject *found;
   QDictIterator<QObject> it(*objList);
   uint len = strlen(name);
@@ -86,7 +86,7 @@ QObject *objFinder::find(const char *name, const char *inherits){ /*FOLD00*/
   return 0x0;
 }
 
-void objFinder::dumpTree(){ /*fold00*/
+void objFinder::dumpTree(){
   QDictIterator<QObject> it(*objList);
   while(it.current()){
     it.current()->dumpObjectTree();
@@ -101,7 +101,7 @@ void objFinder::dumpTree(){ /*fold00*/
 
 }
 
-QStrList objFinder::allObjects(){ /*fold00*/
+QStrList objFinder::allObjects(){
   QStrList allNames;
   QDictIterator<QObject> it(*objList);
   while(it.current()){
@@ -132,7 +132,7 @@ QStrList objFinder::allObjects(){ /*fold00*/
   return allNames;
 }
 
-QString objFinder::randString(){ /*FOLD00*/
+QString objFinder::randString(){
   static bool runSrand = 0;
   QString str = "";
   if(runSrand == 0){
@@ -144,7 +144,7 @@ QString objFinder::randString(){ /*FOLD00*/
   return str;
 }
 
-void objFinder::objDest(){ /*fold00*/
+void objFinder::objDest(){
   if(sender() == 0x0){
     return;
   }
