@@ -96,7 +96,7 @@ PukeController::PukeController(QString sock, QObject *parent, const char *name)
   fcntl(iListenFd, F_SETFL, O_NONBLOCK);  // Set it non-block so that
                                           // accept() never blocks.
 
-  qsnListen = new("QSocketNotifier") QSocketNotifier(iListenFd, QSocketNotifier::Read, this, QString(name) + "_iListen");
+  qsnListen = new QSocketNotifier(iListenFd, QSocketNotifier::Read, this, QString(name) + "_iListen");
   connect(qsnListen, SIGNAL(activated(int)),
 	  this, SLOT(NewConnect(int)));
 
@@ -141,7 +141,7 @@ PukeController::slotInserted(QObject *obj)
   emit inserted(obj);
 }
 
-PukeController::~PukeController() /*fold00*/
+PukeController::~PukeController() 
 {
   close(iListenFd);
   disconnect(this); // We call disconnect this so don't listen to our own destroy() signal go out
@@ -153,7 +153,7 @@ QStrList PukeController::allObjects()
   return objFinder::allObjects();
 }
 
-void PukeController::NewConnect(int) /*FOLD00*/
+void PukeController::NewConnect(int) 
 {
   int cfd;
   ksize_t len = 0;
@@ -167,9 +167,9 @@ void PukeController::NewConnect(int) /*FOLD00*/
   fcntl(cfd, F_SETFL, O_NONBLOCK);  // Set it non-block so that
                                     // cfd() never blocks.
 
-  fdStatus *fds = new("fdStatus") fdStatus();
-  fds->sr = new("QSocketNotifier") QSocketNotifier(cfd, QSocketNotifier::Read, this);
-  fds->sw = new("QSocketNotifier") QSocketNotifier(cfd, QSocketNotifier::Write, this);
+  fdStatus *fds = new fdStatus();
+  fds->sr = new QSocketNotifier(cfd, QSocketNotifier::Read, this);
+  fds->sw = new QSocketNotifier(cfd, QSocketNotifier::Write, this);
   connect(fds->sr, SIGNAL(activated(int)),
 	  this, SLOT(Traffic(int)));
   connect(fds->sw, SIGNAL(activated(int)),
@@ -180,7 +180,7 @@ void PukeController::NewConnect(int) /*FOLD00*/
   /*
    * Now we add ourselves as a client to the fd so we can process messages going to us
    */
-  WidgetS *ws = new("WidgetS") WidgetS;
+  WidgetS *ws = new WidgetS;
   ws->pwidget = this;
   ws->type = 1;
   insertPObject(cfd, ControllerWinId, ws);
@@ -188,7 +188,7 @@ void PukeController::NewConnect(int) /*FOLD00*/
 }
 
 
-void PukeController::Writeable(int fd) /*fold00*/
+void PukeController::Writeable(int fd) 
 {
   if(qidConnectFd[fd]){
     qidConnectFd[fd]->writeable = TRUE;
@@ -202,7 +202,7 @@ void PukeController::Writeable(int fd) /*fold00*/
   }
 }
 
-void PukeController::writeBuffer(int fd, PukeMessage *message) /*FOLD00*/
+void PukeController::writeBuffer(int fd, PukeMessage *message) 
 {
   if(qidConnectFd[fd]){
     //    if(qidConnectFd[fd]->writeable == FALSE){
@@ -283,7 +283,7 @@ void PukeController::writeBuffer(int fd, PukeMessage *message) /*FOLD00*/
   }
 }
 
-void PukeController::Traffic(int fd) /*FOLD00*/
+void PukeController::Traffic(int fd) 
 {
   PukeMessage pm;
   int bytes = -1;
@@ -344,7 +344,7 @@ void PukeController::Traffic(int fd) /*FOLD00*/
 }
 
 
-void PukeController::ServMessage(QString, int, QString) /*fold00*/
+void PukeController::ServMessage(QString, int, QString) 
 {
 
 }
@@ -352,7 +352,7 @@ void PukeController::ServMessage(QString, int, QString) /*fold00*/
 // Message Dispatcher is in messagedispatcher.cpp
 
 
-void PukeController::MessageDispatch(int fd, PukeMessage *pm) /*FOLD00*/
+void PukeController::MessageDispatch(int fd, PukeMessage *pm) 
 {
     try {
 
@@ -386,76 +386,76 @@ void PukeController::MessageDispatch(int fd, PukeMessage *pm) /*FOLD00*/
     }
 }
 
-void PukeController::initHdlr() /*FOLD00*/
+void PukeController::initHdlr() 
 {
 
   widgetCreate *wc;
 
-  wc = new("widgetCreate") widgetCreate;
+  wc = new widgetCreate;
   wc->wc = PWidget::createWidget;
   widgetCF.insert(PWIDGET_WIDGET, wc);
 
-  wc = new("widgetCreate") widgetCreate;
+  wc = new widgetCreate;
   wc->wc = PObject::createWidget;
   widgetCF.insert(PWIDGET_OBJECT, wc);
 
-  wc = new("widgetCreate") widgetCreate;
+  wc = new widgetCreate;
   wc->wc = PLayout::createWidget;
   widgetCF.insert(POBJECT_LAYOUT, wc);
 
-  wc = new("widgetCreate") widgetCreate;
+  wc = new widgetCreate;
   wc->wc = PFrame::createWidget;
   widgetCF.insert(PWIDGET_FRAME, wc);
 
-  wc = new("widgetCreate") widgetCreate;
+  wc = new widgetCreate;
   wc->wc = PLineEdit::createWidget;
   widgetCF.insert(PWIDGET_LINED, wc);
 
-  wc = new("widgetCreate") widgetCreate;
+  wc = new widgetCreate;
   wc->wc = PButton::createWidget;
   widgetCF.insert(PWIDGET_BUTTON, wc);
 
-  wc = new("widgetCreate") widgetCreate;
+  wc = new widgetCreate;
   wc->wc = PPushButton::createWidget;
   widgetCF.insert(PWIDGET_PUSHBT, wc);
 
-  wc = new("widgetCreate") widgetCreate;
+  wc = new widgetCreate;
   wc->wc = PProgress::createWidget;
   widgetCF.insert(PWIDGET_KSPROGRESS, wc);
 
-  wc = new("widgetCreate") widgetCreate;
+  wc = new widgetCreate;
   wc->wc = PTableView::createWidget;
   widgetCF.insert(PWIDGET_TABLEVW, wc);
 
-  wc = new("widgetCreate") widgetCreate;
+  wc = new widgetCreate;
   wc->wc = PListBox::createWidget;
   widgetCF.insert(PWIDGET_LISTBOX, wc);
 
-  wc = new("widgetCreate") widgetCreate;
+  wc = new widgetCreate;
   wc->wc = PLabel::createWidget;
   widgetCF.insert(PWIDGET_LABEL, wc);
 
-  wc = new("widgetCreate") widgetCreate;
+  wc = new widgetCreate;
   wc->wc = PPopupMenu::createWidget;
   widgetCF.insert(PWIDGET_POPMENU, wc);
 
-  wc = new("widgetCreate") widgetCreate;
+  wc = new widgetCreate;
   wc->wc = PAListBox::createWidget;
   widgetCF.insert(PWIDGET_ALISTBOX, wc);
 
-  wc = new("widgetCreate") widgetCreate;
+  wc = new widgetCreate;
   wc->wc = PKSircListBox::createWidget;
   widgetCF.insert(PWIDGET_KSIRCLISTBOX, wc);
 
-  wc = new("widgetCreate") widgetCreate;
+  wc = new widgetCreate;
   wc->wc = PTabDialog::createWidget;
   widgetCF.insert(PWIDGET_TABDIALOG, wc);
 
-  wc = new("widgetCreate") widgetCreate;
+  wc = new widgetCreate;
   wc->wc = PKFileDialog::createWidget;
   widgetCF.insert(PWIDGET_KFILEDIALOG, wc);
 
-  wc = new("widgetCreate") widgetCreate;
+  wc = new widgetCreate;
   wc->wc = PObjFinder::createWidget;
   widgetCF.insert(PWIDGET_OBJFINDER, wc);
 
@@ -464,43 +464,43 @@ void PukeController::initHdlr() /*FOLD00*/
 
 
   // Invalid is the default invalid handler
-  cs = new("commandStruct") commandStruct;
+  cs = new commandStruct;
   cs->cmd = &PukeController::hdlrPukeInvalid;
   cs->library = 0;
   qidCommandTable.insert(PUKE_INVALID, cs);
 
 
   // Setup's handled by the setup handler
-  cs = new("commandStruct") commandStruct;
+  cs = new commandStruct;
   cs->cmd = &PukeController::hdlrPukeSetup;
   cs->library = 0;
   qidCommandTable.insert(PUKE_SETUP, cs);
 
   // We don't receive PUKE_SETUP_ACK's we send them.
-  cs = new("commandStruct") commandStruct;
+  cs = new commandStruct;
   cs->cmd = &PukeController::hdlrPukeInvalid;
   cs->library = 0;
   qidCommandTable.insert(PUKE_SETUP_ACK, cs);
 
-  cs = new("commandStruct") commandStruct;
+  cs = new commandStruct;
   cs->cmd = &PukeController::hdlrPukeEcho;
   cs->library = 0;
   qidCommandTable.insert(PUKE_ECHO, cs);
 
   // Fetch widget gets the requested widget from the ServerController
-  cs = new("commandStruct") commandStruct;
+  cs = new commandStruct;
   cs->cmd = &PukeController::hdlrPukeFetchWidget;
   cs->library = 0;
   qidCommandTable.insert(PUKE_FETCHWIDGET, cs);
 
   // Fetch widget gets the requested widget from the ServerController
-  cs = new("commandStruct") commandStruct;
+  cs = new commandStruct;
   cs->cmd = &PukeController::hdlrPukeDumpTree;
   cs->library = 0;
   qidCommandTable.insert(PUKE_DUMPTREE, cs);
 
   // Fetch widget gets the requested widget from the ServerController
-  cs = new("commandStruct") commandStruct;
+  cs = new commandStruct;
   cs->cmd = &PukeController::hdlrPukeDeleteWidget;
   cs->library = 0;
   qidCommandTable.insert(PUKE_WIDGET_DELETE, cs);
@@ -509,7 +509,7 @@ void PukeController::initHdlr() /*FOLD00*/
 
 // Start message handlers
 
-void PukeController::hdlrPukeInvalid(int fd, PukeMessage *) /*fold00*/
+void PukeController::hdlrPukeInvalid(int fd, PukeMessage *) 
 {
   PukeMessage pmOut;
   memset(&pmOut, 0, sizeof(pmOut));
@@ -517,7 +517,7 @@ void PukeController::hdlrPukeInvalid(int fd, PukeMessage *) /*fold00*/
 }
 
 
-void PukeController::hdlrPukeSetup(int fd, PukeMessage *pm) /*FOLD00*/
+void PukeController::hdlrPukeSetup(int fd, PukeMessage *pm) 
 {
   PukeMessage pmOut;
   memset(&pmOut, 0, sizeof(pmOut));
@@ -532,7 +532,7 @@ void PukeController::hdlrPukeSetup(int fd, PukeMessage *pm) /*FOLD00*/
   this->writeBuffer(fd, &pmOut);
 }
 
-void PukeController::hdlrPukeEcho(int fd, PukeMessage *pm) /*fold00*/
+void PukeController::hdlrPukeEcho(int fd, PukeMessage *pm) 
 {
   PukeMessage pmOut;
   memcpy(&pmOut, pm, sizeof(PukeMessage));
@@ -542,7 +542,7 @@ void PukeController::hdlrPukeEcho(int fd, PukeMessage *pm) /*fold00*/
   this->writeBuffer(fd, &pmOut);
 }
 
-void PukeController::hdlrPukeDumpTree(int fd, PukeMessage *pm) /*fold00*/
+void PukeController::hdlrPukeDumpTree(int fd, PukeMessage *pm) 
 {
   objFinder::dumpTree();
 
@@ -555,7 +555,7 @@ void PukeController::hdlrPukeDumpTree(int fd, PukeMessage *pm) /*fold00*/
 }
 
 
-void PukeController::hdlrPukeFetchWidget(int fd, PukeMessage *pm) /*FOLD00*/
+void PukeController::hdlrPukeFetchWidget(int fd, PukeMessage *pm) 
 {
   widgetId wIret;
 
@@ -572,7 +572,7 @@ void PukeController::hdlrPukeFetchWidget(int fd, PukeMessage *pm) /*FOLD00*/
       throw(errorCommandFailed(PUKE_INVALID,6));
   }
 
-  uiBaseWinId++; // Get a new("base") base win id
+  uiBaseWinId++; // Get a new base win id
 
   // wIret holds the current widget id for the new widget
   wIret.iWinId = uiBaseWinId;
@@ -599,7 +599,7 @@ void PukeController::hdlrPukeFetchWidget(int fd, PukeMessage *pm) /*FOLD00*/
 
   arg.fetchedObj = obj;
 
-  WidgetS *ws = new("WidgetS") WidgetS;
+  WidgetS *ws = new WidgetS;
   ws->pwidget = (widgetCF[iType]->wc)(arg);
   if (ws->pwidget->hasError())
   {
@@ -625,7 +625,7 @@ void PukeController::hdlrPukeFetchWidget(int fd, PukeMessage *pm) /*FOLD00*/
 
 }
 
-void PukeController::hdlrPukeDeleteWidget(int fd, PukeMessage *pm) /*FOLD00*/
+void PukeController::hdlrPukeDeleteWidget(int fd, PukeMessage *pm) 
 {
   widgetId wI;
   wI.fd = fd;
@@ -668,7 +668,7 @@ void PukeController::hdlrPukeDeleteWidget(int fd, PukeMessage *pm) /*FOLD00*/
   emit outputMessage(fd, &pmRet);
 }
 
-void PukeController::closefd(int fd) /*FOLD00*/
+void PukeController::closefd(int fd) 
 {
   if(bClosing == TRUE)
     return;
@@ -740,7 +740,7 @@ void PukeController::closefd(int fd) /*FOLD00*/
   bClosing = FALSE;
 }
 
-bool PukeController::checkWidgetId(widgetId *pwi) /*fold00*/
+bool PukeController::checkWidgetId(widgetId *pwi) 
 {
   if(WidgetList[pwi->fd] != NULL)
     if(WidgetList[pwi->fd]->find(pwi->iWinId) != NULL)
@@ -749,7 +749,7 @@ bool PukeController::checkWidgetId(widgetId *pwi) /*fold00*/
   return FALSE;
 }
 
-PObject *PukeController::id2pobject(widgetId *pwi){ /*FOLD00*/
+PObject *PukeController::id2pobject(widgetId *pwi){ 
   if(checkWidgetId(pwi) == TRUE){
     return WidgetList[pwi->fd]->find(pwi->iWinId)->pwidget;
   }
@@ -757,7 +757,7 @@ PObject *PukeController::id2pobject(widgetId *pwi){ /*FOLD00*/
   return 0; // never reached
 }
 
-PObject *PukeController::id2pobject(int fd, int iWinId){ /*fold00*/
+PObject *PukeController::id2pobject(int fd, int iWinId){ 
   widgetId wi;
   wi.fd = fd;
   wi.iWinId = iWinId;
@@ -765,7 +765,7 @@ PObject *PukeController::id2pobject(int fd, int iWinId){ /*fold00*/
   return id2pobject(&wi);
 }
 
-PWidget *PukeController::id2pwidget(widgetId *pwi){ /*FOLD00*/
+PWidget *PukeController::id2pwidget(widgetId *pwi){ 
   PObject *obj = id2pobject(pwi);
   if(obj->widget()->isWidgetType())
     return (PWidget *) obj;
@@ -773,10 +773,10 @@ PWidget *PukeController::id2pwidget(widgetId *pwi){ /*FOLD00*/
     throw(errorNoSuchWidget(*pwi));
   return NULL;
 }
-void PukeController::insertPObject(int fd, int iWinId, WidgetS *obj){ /*FOLD00*/
+void PukeController::insertPObject(int fd, int iWinId, WidgetS *obj){ 
   // If no widget list exists for this fd, create one
   if(WidgetList[fd] == NULL){
-    QIntDict<WidgetS> *qidWS = new("QIntDict<WidgetS>") QIntDict<WidgetS>;
+    QIntDict<WidgetS> *qidWS = new QIntDict<WidgetS>;
     qidWS->setAutoDelete(TRUE);
     WidgetList.insert(fd, qidWS);
   }
@@ -784,7 +784,7 @@ void PukeController::insertPObject(int fd, int iWinId, WidgetS *obj){ /*FOLD00*/
   WidgetList[fd]->insert(iWinId, obj);
 
   // Set reverse list used durring delete to remove the widget
-  widgetId *pwi = new("widgetId") widgetId;
+  widgetId *pwi = new widgetId;
   pwi->fd = fd;
   pwi->iWinId = iWinId;
   char key[keySize];
@@ -823,7 +823,7 @@ void PukeController::pobjectDestroyed(){
 
 }
 
-void PukeController::messageHandler(int fd, PukeMessage *pm) { /*FOLD00*/
+void PukeController::messageHandler(int fd, PukeMessage *pm) { 
   widgetId wI, wIret;
   wI.fd = fd;
   wI.iWinId = pm->iWinId;
@@ -878,7 +878,7 @@ void PukeController::messageHandler(int fd, PukeMessage *pm) { /*FOLD00*/
     wc =  (PObject *(*)(CreateArgs &ca) )
         library->symbol("createWidget");
 
-    wC = new("widgetCreate") widgetCreate;
+    wC = new widgetCreate;
     wC->wc = wc;
     wC->library = library;
     widgetCF.insert(pm->iArg, wC);
@@ -910,11 +910,11 @@ void PukeController::messageHandler(int fd, PukeMessage *pm) { /*FOLD00*/
   }
 }
 
-widgetId PukeController::createWidget(widgetId wI, PukeMessage *pm) /*FOLD00*/
+widgetId PukeController::createWidget(widgetId wI, PukeMessage *pm) 
 {
   widgetId wIret;
   PWidget *parent = 0; // Defaults to no parent
-  WidgetS *ws = new("WidgetS") WidgetS;
+  WidgetS *ws = new WidgetS;
 
   /*
    * The parent widget ID and type are packed into the iArg
@@ -934,7 +934,7 @@ widgetId PukeController::createWidget(widgetId wI, PukeMessage *pm) /*FOLD00*/
     throw(errorCommandFailed(PUKE_INVALID,1));
   }
 
-  uiBaseWinId++; // Get a new("base") base win id
+  uiBaseWinId++; // Get a new base win id
 
   // wIret holds the current widget id for the new widget
   wIret.iWinId = uiBaseWinId;
