@@ -3,7 +3,7 @@
 
 class PKSircListBox;
 
-#include "../irclistbox.h"
+#include "../KSircListBox/irclistbox.h"
 #include "pmessage.h"
 #include "plistbox.h"
 #include "controller.h"
