@@ -8,15 +8,12 @@ class PAListBox;
 #include "plistbox.h"
 #include "controller.h"
 
-// Init and setup code
-extern "C" {
-PObject *createWidget(CreateArgs &ca);
-}
-
 class PAListBox : public PListBox
 {
   Q_OBJECT
- public:
+public:
+  static PObject *createWidget(CreateArgs &ca);
+
   PAListBox ( PObject * parent );
   virtual ~PAListBox ();
   
@@ -25,10 +22,10 @@ class PAListBox : public PListBox
   virtual void setWidget(QObject *_lb = 0x0);
   virtual aListBox *widget();
 
-  public slots:
+public slots:
 
-  signals:
-    void outputMessage(int fd, PukeMessage *pm);
+signals:
+  void outputMessage(int fd, PukeMessage *pm);
 
 protected:
   bool checkWidget();
