@@ -8,15 +8,12 @@ class PLineEdit;
 #include "pwidget.h"
 #include "controller.h"
 
-// Init and setup code
-extern "C" {
-PObject *createWidget(CreateArgs &ca);
-}
-
 class PLineEdit : public PWidget
 {
   Q_OBJECT
- public:
+public:
+  static PObject *createWidget(CreateArgs &ca);
+
   PLineEdit ( PObject * parent );
   virtual ~PLineEdit ();
   
@@ -25,15 +22,14 @@ class PLineEdit : public PWidget
   virtual void setWidget(QObject *_f);
   virtual QLineEdit *widget();
 
- public slots:
+public slots:
   void updateText(const char *);
   void returnPress();
   
-
- signals:
+signals:
   void outputMessage(int fd, PukeMessage *pm);
 
- private:
+private:
   QLineEdit *lineedit;
 };
 
