@@ -8,15 +8,12 @@ class PListBox;
 #include "ptablevw.h"
 #include "controller.h"
 
-// Init and setup code
-extern "C" {
-PObject *createWidget(CreateArgs &ca);
-}
-
 class PListBox : public PFrame
 {
   Q_OBJECT
- public:
+public:
+  static PObject *createWidget(CreateArgs &ca);
+
   PListBox ( PObject * parent );
   virtual ~PListBox ();
   
@@ -25,12 +22,12 @@ class PListBox : public PFrame
   virtual void setWidget(QObject *_lb);
   virtual QListBox *widget();
 
-  public slots:
-    void highlighted(int);
-    void selected(int);
+public slots:
+  void highlighted(int);
+  void selected(int);
 
-  signals:
-    void outputMessage(int fd, PukeMessage *pm);
+signals:
+  void outputMessage(int fd, PukeMessage *pm);
 
 protected:
   bool checkWidget();
