@@ -36,7 +36,6 @@
 #include <qcheckbox.h> 
 
 #include <kcmodule.h>
-#include <kstddirs.h>
 
 class QDragMoveEvent;
 class QDragEnterEvent;
@@ -82,7 +81,6 @@ private:
     QListBox *sound_list;
     QLabel *sound_tip;
     QPushButton *btn_test;
-    KStandardDirs stddirs;
 
     int findInSound_List(QString sound);
     bool addToSound_List(QString sound);
